=== modified file '.testr.conf'
--- .testr.conf	2010-02-28 10:08:29 +0000
+++ .testr.conf	2010-12-20 11:57:14 +0000
@@ -1,3 +1,4 @@
 [DEFAULT]
-test_command=./bzr selftest --subunit $IDOPTION
+test_command=./bzr selftest --subunit $IDOPTION $LISTOPT
 test_id_option=--load-list $IDFILE
+test_list_option=--list

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2010-11-18 00:22:24 +0000
+++ bzrlib/branch.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -105,6 +105,13 @@
 
     def _activate_fallback_location(self, url):
         """Activate the branch/repository from url as a fallback repository."""
+        for existing_fallback_repo in self.repository._fallback_repositories:
+            if existing_fallback_repo.user_url == url:
+                # This fallback is already configured.  This probably only
+                # happens because BzrDir.sprout is a horrible mess.  To avoid
+                # confusing _unstack we don't add this a second time.
+                mutter('duplicate activation of fallback %r on %r', url, self)
+                return
         repo = self._get_fallback_repository(url)
         if repo.has_same_location(self.repository):
             raise errors.UnstackableLocationError(self.user_url, url)
@@ -809,7 +816,8 @@
             old_repository = self.repository
             if len(old_repository._fallback_repositories) != 1:
                 raise AssertionError("can't cope with fallback repositories "
-                    "of %r" % (self.repository,))
+                    "of %r (fallbacks: %r)" % (old_repository,
+                        old_repository._fallback_repositories))
             # Open the new repository object.
             # Repositories don't offer an interface to remove fallback
             # repositories today; take the conceptually simpler option and just
@@ -1266,7 +1274,8 @@
         return result
 
     @needs_read_lock
-    def sprout(self, to_bzrdir, revision_id=None, repository_policy=None):
+    def sprout(self, to_bzrdir, revision_id=None, repository_policy=None,
+            repository=None):
         """Create a new line of development from the branch, into to_bzrdir.
 
         to_bzrdir controls the branch format.
@@ -1277,7 +1286,7 @@
         if (repository_policy is not None and
             repository_policy.requires_stacking()):
             to_bzrdir._format.require_stacking(_skip_repo=True)
-        result = to_bzrdir.create_branch()
+        result = to_bzrdir.create_branch(repository=repository)
         result.lock_write()
         try:
             if repository_policy is not None:
@@ -1634,7 +1643,8 @@
             hook(params)
 
     def _initialize_helper(self, a_bzrdir, utf8_files, name=None,
-                           lock_type='metadir', set_format=True):
+                           repository=None, lock_type='metadir',
+                           set_format=True):
         """Initialize a branch in a bzrdir, with specified files
 
         :param a_bzrdir: The bzrdir to initialize the branch in
@@ -1674,11 +1684,12 @@
         finally:
             if lock_taken:
                 control_files.unlock()
-        branch = self.open(a_bzrdir, name, _found=True)
+        branch = self.open(a_bzrdir, name, _found=True,
+                found_repository=repository)
         self._run_post_branch_init_hooks(a_bzrdir, name, branch)
         return branch
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Create a branch of this format in a_bzrdir.
         
         :param name: Name of the colocated branch to create.
@@ -1718,7 +1729,8 @@
         """
         raise NotImplementedError(self.network_name)
 
-    def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False):
+    def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False,
+            found_repository=None):
         """Return the branch object for a_bzrdir
 
         :param a_bzrdir: A BzrDir that contains a branch.
@@ -2018,8 +2030,11 @@
         """See BranchFormat.get_format_description()."""
         return "Branch format 4"
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Create a branch of this format in a_bzrdir."""
+        if repository is not None:
+            raise NotImplementedError(
+                "initialize(repository=<not None>) on %r" % (self,))
         utf8_files = [('revision-history', ''),
                       ('branch-name', ''),
                       ]
@@ -2034,16 +2049,19 @@
         """The network name for this format is the control dirs disk label."""
         return self._matchingbzrdir.get_format_string()
 
-    def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False):
+    def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False,
+            found_repository=None):
         """See BranchFormat.open()."""
         if not _found:
             # we are being called directly and must probe.
             raise NotImplementedError
+        if found_repository is None:
+            found_repository = a_bzrdir.open_repository()
         return BzrBranch(_format=self,
                          _control_files=a_bzrdir._control_files,
                          a_bzrdir=a_bzrdir,
                          name=name,
-                         _repository=a_bzrdir.open_repository())
+                         _repository=found_repository)
 
     def __str__(self):
         return "Bazaar-NG branch format 4"
@@ -2063,7 +2081,8 @@
         """
         return self.get_format_string()
 
-    def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False):
+    def open(self, a_bzrdir, name=None, _found=False, ignore_fallbacks=False,
+            found_repository=None):
         """See BranchFormat.open()."""
         if not _found:
             format = BranchFormat.find_format(a_bzrdir, name=name)
@@ -2074,11 +2093,13 @@
         try:
             control_files = lockable_files.LockableFiles(transport, 'lock',
                                                          lockdir.LockDir)
+            if found_repository is None:
+                found_repository = a_bzrdir.find_repository()
             return self._branch_class()(_format=self,
                               _control_files=control_files,
                               name=name,
                               a_bzrdir=a_bzrdir,
-                              _repository=a_bzrdir.find_repository(),
+                              _repository=found_repository,
                               ignore_fallbacks=ignore_fallbacks)
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base, bzrdir=a_bzrdir)
@@ -2116,12 +2137,12 @@
         """See BranchFormat.get_format_description()."""
         return "Branch format 5"
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Create a branch of this format in a_bzrdir."""
         utf8_files = [('revision-history', ''),
                       ('branch-name', ''),
                       ]
-        return self._initialize_helper(a_bzrdir, utf8_files, name)
+        return self._initialize_helper(a_bzrdir, utf8_files, name, repository)
 
     def supports_tags(self):
         return False
@@ -2149,13 +2170,13 @@
         """See BranchFormat.get_format_description()."""
         return "Branch format 6"
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Create a branch of this format in a_bzrdir."""
         utf8_files = [('last-revision', '0 null:\n'),
                       ('branch.conf', ''),
                       ('tags', ''),
                       ]
-        return self._initialize_helper(a_bzrdir, utf8_files, name)
+        return self._initialize_helper(a_bzrdir, utf8_files, name, repository)
 
     def make_tags(self, branch):
         """See bzrlib.branch.BranchFormat.make_tags()."""
@@ -2179,14 +2200,14 @@
         """See BranchFormat.get_format_description()."""
         return "Branch format 8"
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Create a branch of this format in a_bzrdir."""
         utf8_files = [('last-revision', '0 null:\n'),
                       ('branch.conf', ''),
                       ('tags', ''),
                       ('references', '')
                       ]
-        return self._initialize_helper(a_bzrdir, utf8_files, name)
+        return self._initialize_helper(a_bzrdir, utf8_files, name, repository)
 
     def __init__(self):
         super(BzrBranchFormat8, self).__init__()
@@ -2215,13 +2236,13 @@
     This format was introduced in bzr 1.6.
     """
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Create a branch of this format in a_bzrdir."""
         utf8_files = [('last-revision', '0 null:\n'),
                       ('branch.conf', ''),
                       ('tags', ''),
                       ]
-        return self._initialize_helper(a_bzrdir, utf8_files, name)
+        return self._initialize_helper(a_bzrdir, utf8_files, name, repository)
 
     def _branch_class(self):
         return BzrBranch7
@@ -2269,7 +2290,8 @@
         transport = a_bzrdir.get_branch_transport(None, name=name)
         location = transport.put_bytes('location', to_branch.base)
 
-    def initialize(self, a_bzrdir, name=None, target_branch=None):
+    def initialize(self, a_bzrdir, name=None, target_branch=None,
+            repository=None):
         """Create a branch of this format in a_bzrdir."""
         if target_branch is None:
             # this format does not implement branch itself, thus the implicit
@@ -2303,7 +2325,8 @@
         return clone
 
     def open(self, a_bzrdir, name=None, _found=False, location=None,
-             possible_transports=None, ignore_fallbacks=False):
+             possible_transports=None, ignore_fallbacks=False,
+             found_repository=None):
         """Return the branch that the branch reference in a_bzrdir points at.
 
         :param a_bzrdir: A BzrDir that contains a branch.

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2010-11-30 05:49:40 +0000
+++ bzrlib/builtins.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -3328,27 +3328,62 @@
 
 
 class cmd_upgrade(Command):
-    __doc__ = """Upgrade branch storage to current format.
-
-    The check command or bzr developers may sometimes advise you to run
-    this command. When the default format has changed you may also be warned
-    during other operations to upgrade.
+    __doc__ = """Upgrade a repository, branch or working tree to a newer format.
+
+    When the default format has changed after a major new release of
+    Bazaar, you may be informed during certain operations that you
+    should upgrade. Upgrading to a newer format may improve performance
+    or make new features available. It may however limit interoperability
+    with older repositories or with older versions of Bazaar.
+
+    If you wish to upgrade to a particular format rather than the
+    current default, that can be specified using the --format option.
+    As a consequence, you can use the upgrade command this way to
+    "downgrade" to an earlier format, though some conversions are
+    a one way process (e.g. changing from the 1.x default to the
+    2.x default) so downgrading is not always possible.
+
+    A backup.bzr.~#~ directory is created at the start of the conversion
+    process (where # is a number). By default, this is left there on
+    completion. If the conversion fails, delete the new .bzr directory
+    and rename this one back in its place. Use the --clean option to ask
+    for the backup.bzr directory to be removed on successful conversion.
+    Alternatively, you can delete it by hand if everything looks good
+    afterwards.
+
+    If the location given is a shared repository, dependent branches
+    are also converted provided the repository converts successfully.
+    If the conversion of a branch fails, remaining branches are still
+    tried.
+
+    For more information on upgrades, see the Bazaar Upgrade Guide,
+    http://doc.bazaar.canonical.com/latest/en/upgrade-guide/.
     """
 
-    _see_also = ['check']
+    _see_also = ['check', 'reconcile', 'formats']
     takes_args = ['url?']
     takes_options = [
-                    RegistryOption('format',
-                        help='Upgrade to a specific format.  See "bzr help'
-                             ' formats" for details.',
-                        lazy_registry=('bzrlib.bzrdir', 'format_registry'),
-                        converter=lambda name: bzrdir.format_registry.make_bzrdir(name),
-                        value_switches=True, title='Branch format'),
-                    ]
+        RegistryOption('format',
+            help='Upgrade to a specific format.  See "bzr help'
+                 ' formats" for details.',
+            lazy_registry=('bzrlib.bzrdir', 'format_registry'),
+            converter=lambda name: bzrdir.format_registry.make_bzrdir(name),
+            value_switches=True, title='Branch format'),
+        Option('clean',
+            help='Remove the backup.bzr directory if successful.'),
+        Option('dry-run',
+            help="Show what would be done, but don't actually do anything."),
+    ]
 
-    def run(self, url='.', format=None):
+    def run(self, url='.', format=None, clean=False, dry_run=False):
         from bzrlib.upgrade import upgrade
-        upgrade(url, format)
+        exceptions = upgrade(url, format, clean_up=clean, dry_run=dry_run)
+        if exceptions:
+            if len(exceptions) == 1:
+                # Compatibility with historical behavior
+                raise exceptions[0]
+            else:
+                return 3
 
 
 class cmd_whoami(Command):
@@ -4208,9 +4243,10 @@
     last committed revision is used.
 
     To remove only some changes, without reverting to a prior version, use
-    merge instead.  For example, "merge . --revision -2..-3" will remove the
-    changes introduced by -2, without affecting the changes introduced by -1.
-    Or to remove certain changes on a hunk-by-hunk basis, see the Shelf plugin.
+    merge instead.  For example, "merge . -r -2..-3" (don't forget the ".")
+    will remove the changes introduced by the second last commit (-2), without
+    affecting the changes introduced by the last commit (-1).  To remove
+    certain changes on a hunk-by-hunk basis, see the shelve command.
 
     By default, any files that have been manually changed will be backed up
     first.  (Files changed only by merge are not backed up.)  Backup files have
@@ -4246,7 +4282,7 @@
     target branches.
     """
 
-    _see_also = ['cat', 'export']
+    _see_also = ['cat', 'export', 'merge', 'shelve']
     takes_options = [
         'revision',
         Option('no-backup', "Do not save backups of reverted files."),

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2010-12-02 10:41:05 +0000
+++ bzrlib/bzrdir.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -927,7 +927,6 @@
         return format.initialize_on_transport(t)
 
 
-
 class BzrDirHooks(hooks.Hooks):
     """Hooks for BzrDir operations."""
 
@@ -1027,8 +1026,11 @@
             tree.clone(result)
         return result
 
-    def create_branch(self, name=None):
+    def create_branch(self, name=None, repository=None):
         """See BzrDir.create_branch."""
+        if repository is not None:
+            raise NotImplementedError(
+                "create_branch(repository=<not None>) on %r" % (self,))
         return self._format.get_branch_format().initialize(self, name=name)
 
     def destroy_branch(self, name=None):
@@ -1264,9 +1266,10 @@
         """See BzrDir.can_convert_format()."""
         return True
 
-    def create_branch(self, name=None):
+    def create_branch(self, name=None, repository=None):
         """See BzrDir.create_branch."""
-        return self._format.get_branch_format().initialize(self, name=name)
+        return self._format.get_branch_format().initialize(self, name=name,
+                repository=repository)
 
     def destroy_branch(self, name=None):
         """See BzrDir.create_branch."""
@@ -1663,7 +1666,7 @@
         utf8_files = [('README',
                        "This is a Bazaar control directory.\n"
                        "Do not change any files in this directory.\n"
-                       "See http://bazaar-vcs.org/ for more information about Bazaar.\n"),
+                       "See http://bazaar.canonical.com/ for more information about Bazaar.\n"),
                       ('branch-format', self.get_format_string()),
                       ]
         # NB: no need to escape relative paths that are url safe.

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2010-11-07 16:09:43 +0000
+++ bzrlib/conflicts.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -626,6 +626,37 @@
     def associated_filenames(self):
         return [self.path + suffix for suffix in CONFLICT_SUFFIXES]
 
+    def _resolve(self, tt, winner_suffix):
+        """Resolve the conflict by copying one of .THIS or .OTHER into file.
+
+        :param tt: The TreeTransform where the conflict is resolved.
+        :param winner_suffix: Either 'THIS' or 'OTHER'
+
+        The resolution is symmetric, when taking THIS, item.THIS is renamed
+        into item and vice-versa. This takes one of the files as a whole
+        ignoring every difference that could have been merged cleanly.
+        """
+        # To avoid useless copies, we switch item and item.winner_suffix, only
+        # item will exist after the conflict has been resolved anyway.
+        item_tid = tt.trans_id_file_id(self.file_id)
+        item_parent_tid = tt.get_tree_parent(item_tid)
+        winner_path = self.path + '.' + winner_suffix
+        winner_tid = tt.trans_id_tree_path(winner_path)
+        winner_parent_tid = tt.get_tree_parent(winner_tid)
+        # Switch the paths to preserve the content
+        tt.adjust_path(self.path, winner_parent_tid, winner_tid)
+        tt.adjust_path(winner_path, item_parent_tid, item_tid)
+        # Associate the file_id to the right content
+        tt.unversion_file(item_tid)
+        tt.version_file(self.file_id, winner_tid)
+        tt.apply()
+
+    def action_take_this(self, tree):
+        self._resolve_with_cleanups(tree, 'THIS')
+
+    def action_take_other(self, tree):
+        self._resolve_with_cleanups(tree, 'OTHER')
+
 
 class HandledConflict(Conflict):
     """A path problem that has been provisionally resolved.

=== modified file 'bzrlib/controldir.py'
--- bzrlib/controldir.py	2010-09-10 09:46:15 +0000
+++ bzrlib/controldir.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,11 +27,10 @@
 import textwrap
 
 from bzrlib import (
+    cleanup,
     errors,
     graph,
-    registry,
     revision as _mod_revision,
-    symbol_versioning,
     urlutils,
     )
 from bzrlib.push import (
@@ -47,6 +46,8 @@
 
 """)
 
+from bzrlib import registry
+
 
 class ControlComponent(object):
     """Abstract base class for control directory components.
@@ -143,7 +144,7 @@
         """Destroy the repository in this ControlDir."""
         raise NotImplementedError(self.destroy_repository)
 
-    def create_branch(self, name=None):
+    def create_branch(self, name=None, repository=None):
         """Create a branch in this ControlDir.
 
         :param name: Name of the colocated branch to create, None for
@@ -364,6 +365,19 @@
         :param create_tree_if_local: If true, a working-tree will be created
             when working locally.
         """
+        operation = cleanup.OperationWithCleanups(self._sprout)
+        return operation.run(url, revision_id=revision_id,
+            force_new_repo=force_new_repo, recurse=recurse,
+            possible_transports=possible_transports,
+            accelerator_tree=accelerator_tree, hardlink=hardlink,
+            stacked=stacked, source_branch=source_branch,
+            create_tree_if_local=create_tree_if_local)
+
+    def _sprout(self, op, url, revision_id=None, force_new_repo=False,
+               recurse='down', possible_transports=None,
+               accelerator_tree=None, hardlink=False, stacked=False,
+               source_branch=None, create_tree_if_local=True):
+        add_cleanup = op.add_cleanup
         target_transport = get_transport(url, possible_transports)
         target_transport.ensure_base()
         cloning_format = self.cloning_metadir(stacked)
@@ -373,6 +387,7 @@
         # even if the origin was stacked
         stacked_branch_url = None
         if source_branch is not None:
+            add_cleanup(source_branch.lock_read().unlock)
             if stacked:
                 stacked_branch_url = self.root_transport.base
             source_repository = source_branch.repository
@@ -388,9 +403,14 @@
                     source_repository = self.open_repository()
                 except errors.NoRepositoryPresent:
                     source_repository = None
+                else:
+                    add_cleanup(source_repository.lock_read().unlock)
+            else:
+                add_cleanup(source_branch.lock_read().unlock)
         repository_policy = result.determine_repository_policy(
             force_new_repo, stacked_branch_url, require_stacking=stacked)
         result_repo, is_new_repo = repository_policy.acquire_repository()
+        add_cleanup(result_repo.lock_write().unlock)
         is_stacked = stacked or (len(result_repo._fallback_repositories) != 0)
         if is_new_repo and revision_id is not None and not is_stacked:
             fetch_spec = graph.PendingAncestryResult(
@@ -412,7 +432,8 @@
             result_branch = result.create_branch()
         else:
             result_branch = source_branch.sprout(result,
-                revision_id=revision_id, repository_policy=repository_policy)
+                revision_id=revision_id, repository_policy=repository_policy,
+                repository=result_repo)
         mutter("created new branch %r" % (result_branch,))
 
         # Create/update the result working tree
@@ -420,7 +441,7 @@
             isinstance(target_transport, local.LocalTransport) and
             (result_repo is None or result_repo.make_working_trees())):
             wt = result.create_workingtree(accelerator_tree=accelerator_tree,
-                hardlink=hardlink)
+                hardlink=hardlink, from_branch=result_branch)
             wt.lock_write()
             try:
                 if wt.path2id('') is None:

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2010-11-06 10:55:58 +0000
+++ bzrlib/errors.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -713,6 +713,9 @@
        self.bzrdir = bzrdir
        PathError.__init__(self, path=path)
 
+    def __repr__(self):
+        return '<%s %r>' % (self.__class__.__name__, self.__dict__)
+
     def _format(self):
         # XXX: Ideally self.detail would be a property, but Exceptions in
         # Python 2.4 have to be old-style classes so properties don't work.

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2010-09-17 04:35:23 +0000
+++ bzrlib/fetch.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -125,9 +125,6 @@
             pb.update("Inserting stream")
             resume_tokens, missing_keys = self.sink.insert_stream(
                 stream, from_format, [])
-            if self.to_repository._fallback_repositories:
-                missing_keys.update(
-                    self._parent_inventories(search.get_keys()))
             if missing_keys:
                 pb.update("Missing keys")
                 stream = source.get_stream_for_missing_keys(missing_keys)
@@ -163,18 +160,6 @@
             self.from_repository, self._last_revision,
             find_ghosts=self.find_ghosts)
 
-    def _parent_inventories(self, revision_ids):
-        # Find all the parent revisions referenced by the stream, but
-        # not present in the stream, and make sure we send their
-        # inventories.
-        parent_maps = self.to_repository.get_parent_map(revision_ids)
-        parents = set()
-        map(parents.update, parent_maps.itervalues())
-        parents.discard(NULL_REVISION)
-        parents.difference_update(revision_ids)
-        missing_keys = set(('inventories', rev_id) for rev_id in parents)
-        return missing_keys
-
 
 class Inter1and2Helper(object):
     """Helper for operations that convert data from model 1 and 2

=== modified file 'bzrlib/graph.py'
--- bzrlib/graph.py	2010-08-15 15:20:14 +0000
+++ bzrlib/graph.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1770,6 +1770,9 @@
     def merge_sort(self, tip_revision):
         return self._graph.merge_sort((tip_revision,))
 
+    def add_node(self, revision, parents):
+        self._graph.add_node((revision,), [(p,) for p in parents])
+
 
 _counters = [0,0,0,0,0,0,0]
 try:

=== modified file 'bzrlib/help_topics/en/configuration.txt'
--- bzrlib/help_topics/en/configuration.txt	2010-09-29 05:35:26 +0000
+++ bzrlib/help_topics/en/configuration.txt	2010-12-07 09:06:39 +0000
@@ -322,7 +322,7 @@
     create_signatures = always
     check_signatures  = always
 
-    [http://bazaar-vcs.org/bzr/*]
+    [http://example.com/bzr/*]
     check_signatures  = require
 
 The authentication configuration file, authentication.conf

=== modified file 'bzrlib/help_topics/en/conflict-types.txt'
--- bzrlib/help_topics/en/conflict-types.txt	2010-10-15 14:57:42 +0000
+++ bzrlib/help_topics/en/conflict-types.txt	2010-11-24 16:28:11 +0000
@@ -87,11 +87,11 @@
 
 The correct resolution would be "Martin Pool released Bazaar."
 
-You can handle text conflicts either by editing the main copy of the file, or
-by invoking external tools on the THIS, OTHER and BASE versions.  It's worth
-mentioning that resolving text conflicts rarely involves picking one set of
-changes over the other.  More often, the two sets of changes must be
-intelligently combined.
+You can handle text conflicts either by editing the main copy of the file,
+or by invoking external tools on the THIS, OTHER and BASE versions.  It's
+worth mentioning that resolving text conflicts rarely involves picking one
+set of changes over the other (but see below when you encounter these
+cases).  More often, the two sets of changes must be intelligently combined.
 
 If you edit the main copy, be sure to remove the herringbone markers.  When
 you are done editing, the file should look like it never had a conflict, and be
@@ -104,6 +104,16 @@
 ``.BASE``, ``.THIS`` and ``.OTHER`` files if they are still present in the
 working tree.
 
+
+When you want to pick one set of changes over the other, you can use ``bzr
+resolve`` with one of the following actions:
+
+* ``--action=take-this`` will issue ``mv FILE.THIS FILE``,
+* ``--action=take-other`` will issue ``mv FILE.OTHER FILE``.
+
+Note that if you have modified ``FILE.THIS`` or ``FILE.OTHER``, these
+modifications will be taken into account.
+
 Content conflicts
 -----------------
 

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2010-10-17 23:20:40 +0000
+++ bzrlib/mutabletree.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -418,7 +418,9 @@
 
         # expand any symlinks in the directory part, while leaving the
         # filename alone
-        file_list = map(osutils.normalizepath, file_list)
+        # only expanding if symlinks are supported avoids windows path bugs
+        if osutils.has_symlinks():
+            file_list = map(osutils.normalizepath, file_list)
 
         # validate user file paths and convert all paths to tree
         # relative : it's cheaper to make a tree relative path an abspath

=== modified file 'bzrlib/plugins/launchpad/__init__.py'
--- bzrlib/plugins/launchpad/__init__.py	2010-12-02 10:41:05 +0000
+++ bzrlib/plugins/launchpad/__init__.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 # The XMLRPC server address can be overridden by setting the environment
 # variable $BZR_LP_XMLRPC_URL
 
-# see http://bazaar-vcs.org/Specs/BranchRegistrationTool
+# see http://wiki.bazaar.canonical.com/Specs/BranchRegistrationTool
 
 # Since we are a built-in plugin we share the bzrlib version
 from bzrlib import version_info

=== modified file 'bzrlib/plugins/launchpad/test_lp_directory.py'
--- bzrlib/plugins/launchpad/test_lp_directory.py	2010-12-02 10:41:05 +0000
+++ bzrlib/plugins/launchpad/test_lp_directory.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -298,7 +298,7 @@
         self.server = self.server_class()
         self.server.start_server()
         # Ensure we don't clobber env
-        self._captureVar('BZR_LP_XMLRPC_URL', None)
+        self.overrideEnv('BZR_LP_XMLRPC_URL', None)
 
     def tearDown(self):
         self.server.stop_server()
@@ -361,7 +361,7 @@
     """Test expansions for ubuntu: and debianlp: schemes."""
 
     def setUp(self):
-        tests.TestCase.setUp(self)
+        super(TestDebuntuExpansions, self).setUp()
         self.directory = LaunchpadDirectory()
 
     def _make_factory(self, package='foo', distro='ubuntu', series=None):

=== modified file 'bzrlib/plugins/launchpad/test_lp_service.py'
--- bzrlib/plugins/launchpad/test_lp_service.py	2010-11-26 17:33:55 +0000
+++ bzrlib/plugins/launchpad/test_lp_service.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
     def setUp(self):
         super(LaunchpadServiceTests, self).setUp()
         # make sure we have a reproducible standard environment
-        self._captureVar('BZR_LP_XMLRPC_URL', None)
+        self.overrideEnv('BZR_LP_XMLRPC_URL', None)
 
     def test_default_service(self):
         service = LaunchpadService()

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2010-11-26 17:33:55 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -133,14 +133,11 @@
 
 
 class TestBranchRegistration(TestCaseWithTransport):
-    SAMPLE_URL = 'http://bazaar-vcs.org/bzr/bzr.dev/'
-    SAMPLE_OWNER = 'jhacker@foo.com'
-    SAMPLE_BRANCH_ID = 'bzr.dev'
 
     def setUp(self):
         super(TestBranchRegistration, self).setUp()
         # make sure we have a reproducible standard environment
-        self._captureVar('BZR_LP_XMLRPC_URL', None)
+        self.overrideEnv('BZR_LP_XMLRPC_URL', None)
 
     def test_register_help(self):
         """register-branch accepts --help"""
@@ -299,7 +296,7 @@
     def setUp(self):
         super(TestGatherUserCredentials, self).setUp()
         # make sure we have a reproducible standard environment
-        self._captureVar('BZR_LP_XMLRPC_URL', None)
+        self.overrideEnv('BZR_LP_XMLRPC_URL', None)
 
     def test_gather_user_credentials_has_password(self):
         service = LaunchpadService()

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2010-12-02 10:41:05 +0000
+++ bzrlib/remote.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
     revision as _mod_revision,
     static_tuple,
     symbol_versioning,
+    urlutils,
 )
 from bzrlib.branch import BranchReferenceFormat, BranchWriteLockResult
 from bzrlib.bzrdir import BzrDir, RemoteBzrDirFormat
@@ -246,14 +247,17 @@
         self._ensure_real()
         self._real_bzrdir.destroy_repository()
 
-    def create_branch(self, name=None):
+    def create_branch(self, name=None, repository=None):
         # as per meta1 formats - just delegate to the format object which may
         # be parameterised.
         real_branch = self._format.get_branch_format().initialize(self,
-            name=name)
+            name=name, repository=repository)
         if not isinstance(real_branch, RemoteBranch):
-            result = RemoteBranch(self, self.find_repository(), real_branch,
-                                  name=name)
+            if not isinstance(repository, RemoteRepository):
+                raise AssertionError(
+                    'need a RemoteRepository to use with RemoteBranch, got %r'
+                    % (repository,))
+            result = RemoteBranch(self, repository, real_branch, name=name)
         else:
             result = real_branch
         # BzrDir.clone_on_transport() uses the result of create_branch but does
@@ -2093,7 +2097,7 @@
                                   name=name)
         return result
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         # 1) get the network name to use.
         if self._custom_format:
             network_name = self._custom_format.network_name()
@@ -2127,13 +2131,25 @@
         # Turn the response into a RemoteRepository object.
         format = RemoteBranchFormat(network_name=response[1])
         repo_format = response_tuple_to_repo_format(response[3:])
-        if response[2] == '':
-            repo_bzrdir = a_bzrdir
+        repo_path = response[2]
+        if repository is not None:
+            remote_repo_url = urlutils.join(medium.base, repo_path)
+            url_diff = urlutils.relative_url(repository.user_url,
+                    remote_repo_url)
+            if url_diff != '.':
+                raise AssertionError(
+                    'repository.user_url %r does not match URL from server '
+                    'response (%r + %r)'
+                    % (repository.user_url, medium.base, repo_path))
+            remote_repo = repository
         else:
-            repo_bzrdir = RemoteBzrDir(
-                a_bzrdir.root_transport.clone(response[2]), a_bzrdir._format,
-                a_bzrdir._client)
-        remote_repo = RemoteRepository(repo_bzrdir, repo_format)
+            if repo_path == '':
+                repo_bzrdir = a_bzrdir
+            else:
+                repo_bzrdir = RemoteBzrDir(
+                    a_bzrdir.root_transport.clone(repo_path), a_bzrdir._format,
+                    a_bzrdir._client)
+            remote_repo = RemoteRepository(repo_bzrdir, repo_format)
         remote_branch = RemoteBranch(a_bzrdir, remote_repo,
             format=format, setup_stacking=False, name=name)
         # XXX: We know this is a new branch, so it must have revno 0, revid

=== modified file 'bzrlib/tests/TestUtil.py'
--- bzrlib/tests/TestUtil.py	2010-09-21 03:20:09 +0000
+++ bzrlib/tests/TestUtil.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #       Author: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -29,9 +29,11 @@
 
 
 class LogCollector(logging.Handler):
+
     def __init__(self):
         logging.Handler.__init__(self)
         self.records=[]
+
     def emit(self, record):
         self.records.append(record.getMessage())
 
@@ -60,7 +62,8 @@
                 visitor.visitSuite(test)
                 visitTests(test, visitor)
             else:
-                print "unvisitable non-unittest.TestCase element %r (%r)" % (test, test.__class__)
+                print "unvisitable non-unittest.TestCase element %r (%r)" % (
+                    test, test.__class__)
 
 
 class TestSuite(unittest.TestSuite):
@@ -183,7 +186,9 @@
 
 class TestVisitor(object):
     """A visitor for Tests"""
+
     def visitSuite(self, aTestSuite):
         pass
+
     def visitCase(self, aTestCase):
         pass

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/__init__.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -60,54 +60,40 @@
         % (testtools.__file__, _testtools_version))
 from testtools import content
 
+import bzrlib
 from bzrlib import (
     branchbuilder,
     bzrdir,
     chk_map,
+    commands as _mod_commands,
     config,
     debug,
     errors,
     hooks,
     lock as _mod_lock,
+    lockdir,
     memorytree,
     osutils,
+    plugin as _mod_plugin,
     pyutils,
     ui,
     urlutils,
     registry,
+    symbol_versioning,
+    trace,
     transport as _mod_transport,
     workingtree,
     )
-import bzrlib.branch
-import bzrlib.commands
-import bzrlib.timestamp
-import bzrlib.export
-import bzrlib.inventory
-import bzrlib.iterablefile
-import bzrlib.lockdir
 try:
     import bzrlib.lsprof
 except ImportError:
     # lsprof not available
     pass
-import bzrlib.merge3
-import bzrlib.plugin
 from bzrlib.smart import client, request
-import bzrlib.store
-from bzrlib import symbol_versioning
-from bzrlib.symbol_versioning import (
-    DEPRECATED_PARAMETER,
-    deprecated_function,
-    deprecated_in,
-    deprecated_method,
-    deprecated_passed,
-    )
-import bzrlib.trace
 from bzrlib.transport import (
     memory,
     pathfilter,
     )
-from bzrlib.trace import mutter, note
 from bzrlib.tests import (
     test_server,
     TestUtil,
@@ -115,7 +101,6 @@
     )
 from bzrlib.ui import NullProgressView
 from bzrlib.ui.text import TextUIFactory
-import bzrlib.version_info_formats.format_custom
 
 # Mark this python module as being part of the implementation
 # of unittest: this gives us better tracebacks where the last
@@ -301,10 +286,9 @@
         addOnException = getattr(test, "addOnException", None)
         if addOnException is not None:
             addOnException(self._record_traceback_from_test)
-        # Only check for thread leaks if the test case supports cleanups
-        addCleanup = getattr(test, "addCleanup", None)
-        if addCleanup is not None:
-            addCleanup(self._check_leaked_threads, test)
+        # Only check for thread leaks on bzrlib derived test cases
+        if isinstance(test, TestCase):
+            test.addCleanup(self._check_leaked_threads, test)
 
     def startTests(self):
         self.report_tests_starting()
@@ -851,6 +835,7 @@
         self.addDetail("log", content.Content(content.ContentType("text",
             "plain", {"charset": "utf8"}),
             lambda:[self._get_log(keep_log_file=True)]))
+        self._old_env = {}
         self._cleanEnvironment()
         self._silenceUI()
         self._startLogFile()
@@ -1126,7 +1111,7 @@
         except UnicodeError, e:
             # If we can't compare without getting a UnicodeError, then
             # obviously they are different
-            mutter('UnicodeError: %s', e)
+            trace.mutter('UnicodeError: %s', e)
         if message:
             message += '\n'
         raise AssertionError("%snot equal:\na = %s\nb = %s\n"
@@ -1192,7 +1177,6 @@
     def assertLogsError(self, exception_class, func, *args, **kwargs):
         """Assert that func(*args, **kwargs) quietly logs a specific exception.
         """
-        from bzrlib import trace
         captured = []
         orig_log_exception_quietly = trace.log_exception_quietly
         try:
@@ -1492,7 +1476,7 @@
         The file is removed as the test is torn down.
         """
         self._log_file = StringIO()
-        self._log_memento = bzrlib.trace.push_log_file(self._log_file)
+        self._log_memento = trace.push_log_file(self._log_file)
         self.addCleanup(self._finishLogFile)
 
     def _finishLogFile(self):
@@ -1500,10 +1484,10 @@
 
         Close the file and delete it, unless setKeepLogfile was called.
         """
-        if bzrlib.trace._trace_file:
+        if trace._trace_file:
             # flush the log file, to get all content
-            bzrlib.trace._trace_file.flush()
-        bzrlib.trace.pop_log_file(self._log_memento)
+            trace._trace_file.flush()
+        trace.pop_log_file(self._log_memento)
         # Cache the log result and delete the file on disk
         self._get_log(False)
 
@@ -1539,6 +1523,20 @@
             setattr(obj, attr_name, new)
         return value
 
+    def overrideEnv(self, name, new):
+        """Set an environment variable, and reset it after the test.
+
+        :param name: The environment variable name.
+
+        :param new: The value to set the variable to. If None, the 
+            variable is deleted from the environment.
+
+        :returns: The actual variable value.
+        """
+        value = osutils.set_or_unset_env(name, new)
+        self.addCleanup(osutils.set_or_unset_env, name, value)
+        return value
+
     def _cleanEnvironment(self):
         new_env = {
             'BZR_HOME': None, # Don't inherit BZR_HOME to all the tests.
@@ -1588,19 +1586,13 @@
             # use an env var so it propagates to subprocesses.
             'APPORT_DISABLE': '1',
         }
-        self._old_env = {}
-        self.addCleanup(self._restoreEnvironment)
         for name, value in new_env.iteritems():
-            self._captureVar(name, value)
+            self.overrideEnv(name, value)
 
     def _captureVar(self, name, newvalue):
         """Set an environment variable, and reset it when finished."""
         self._old_env[name] = osutils.set_or_unset_env(name, newvalue)
 
-    def _restoreEnvironment(self):
-        for name, value in self._old_env.iteritems():
-            osutils.set_or_unset_env(name, value)
-
     def _restoreHooks(self):
         for klass, (name, hooks) in self._preserved_hooks.items():
             setattr(klass, name, hooks)
@@ -1699,7 +1691,7 @@
             self._benchtime += time.time() - start
 
     def log(self, *args):
-        mutter(*args)
+        trace.mutter(*args)
 
     def _get_log(self, keep_log_file=False):
         """Internal helper to get the log from bzrlib.trace for this test.
@@ -1790,9 +1782,10 @@
 
         try:
             try:
-                result = self.apply_redirected(ui.ui_factory.stdin,
+                result = self.apply_redirected(
+                    ui.ui_factory.stdin,
                     stdout, stderr,
-                    bzrlib.commands.run_bzr_catch_user_errors,
+                    _mod_commands.run_bzr_catch_user_errors,
                     args)
             except KeyboardInterrupt:
                 # Reraise KeyboardInterrupt with contents of redirected stdout
@@ -2048,8 +2041,8 @@
         if retcode is not None and retcode != process.returncode:
             if process_args is None:
                 process_args = "(unknown args)"
-            mutter('Output of bzr %s:\n%s', process_args, out)
-            mutter('Error for bzr %s:\n%s', process_args, err)
+            trace.mutter('Output of bzr %s:\n%s', process_args, out)
+            trace.mutter('Error for bzr %s:\n%s', process_args, err)
             self.fail('Command bzr %s failed with retcode %s != %s'
                       % (process_args, retcode, process.returncode))
         return [out, err]
@@ -2112,7 +2105,7 @@
 
         Tests that expect to provoke LockContention errors should call this.
         """
-        self.overrideAttr(bzrlib.lockdir, '_DEFAULT_TIMEOUT_SECONDS', 0)
+        self.overrideAttr(lockdir, '_DEFAULT_TIMEOUT_SECONDS', 0)
 
     def make_utf8_encoded_stringio(self, encoding_type=None):
         """Return a StringIOWrapper instance, that will encode Unicode
@@ -2442,8 +2435,8 @@
         test_home_dir = self.test_home_dir
         if isinstance(test_home_dir, unicode):
             test_home_dir = test_home_dir.encode(sys.getfilesystemencoding())
-        os.environ['HOME'] = test_home_dir
-        os.environ['BZR_HOME'] = test_home_dir
+        self.overrideEnv('HOME', test_home_dir)
+        self.overrideEnv('BZR_HOME', test_home_dir)
 
     def setUp(self):
         super(TestCaseWithMemoryTransport, self).setUp()
@@ -3599,8 +3592,9 @@
                 key, obj, help=help, info=info, override_existing=False)
         except KeyError:
             actual = self.get(key)
-            note('Test prefix alias %s is already used for %s, ignoring %s'
-                 % (key, actual, obj))
+            trace.note(
+                'Test prefix alias %s is already used for %s, ignoring %s'
+                % (key, actual, obj))
 
     def resolve_alias(self, id_start):
         """Replace the alias by the prefix in the given string.
@@ -3842,7 +3836,13 @@
         return []
     return [
         'bzrlib',
-        'bzrlib.branchbuilder',
+        # FIXME: Fixing bug #690563 revealed an isolation problem in the single
+        # doctest for branchbuilder. Uncomment this when bug #321320 is fixed
+        # to ensure the issue is addressed (note that to reproduce the bug in
+        # the doctest below, one should comment the 'email' config var in
+        # bazaar.conf (or anywhere else). This means an setup where *no* user
+        # is being set at all in the environment.
+#       'bzrlib.branchbuilder',
         'bzrlib.decorators',
         'bzrlib.export',
         'bzrlib.inventory',
@@ -3924,7 +3924,7 @@
         suite.addTest(doc_suite)
 
     default_encoding = sys.getdefaultencoding()
-    for name, plugin in bzrlib.plugin.plugins().items():
+    for name, plugin in _mod_plugin.plugins().items():
         if not interesting_module(plugin.module.__name__):
             continue
         plugin_suite = plugin.test_suite()
@@ -3936,7 +3936,7 @@
         if plugin_suite is not None:
             suite.addTest(plugin_suite)
         if default_encoding != sys.getdefaultencoding():
-            bzrlib.trace.warning(
+            trace.warning(
                 'Plugin "%s" tried to reset default encoding to: %s', name,
                 sys.getdefaultencoding())
             reload(sys)
@@ -3957,9 +3957,9 @@
             # Some tests mentioned in the list are not in the test suite. The
             # list may be out of date, report to the tester.
             for id in not_found:
-                bzrlib.trace.warning('"%s" not found in the test suite', id)
+                trace.warning('"%s" not found in the test suite', id)
         for id in duplicates:
-            bzrlib.trace.warning('"%s" is used as an id by several tests', id)
+            trace.warning('"%s" is used as an id by several tests', id)
 
     return suite
 
@@ -4303,13 +4303,6 @@
         return self.module_name
 
 
-# This is kept here for compatibility, it is recommended to use
-# 'bzrlib.tests.feature.paramiko' instead
-ParamikoFeature = _CompatabilityThunkFeature(
-    deprecated_in((2,1,0)),
-    'bzrlib.tests.features', 'ParamikoFeature', 'paramiko')
-
-
 def probe_unicode_in_user_encoding():
     """Try to encode several unicode strings to use in unicode-aware tests.
     Return first successfull match.
@@ -4502,10 +4495,6 @@
 case_sensitive_filesystem_feature = _CaseSensitiveFilesystemFeature()
 
 
-# Kept for compatibility, use bzrlib.tests.features.subunit instead
-SubUnitFeature = _CompatabilityThunkFeature(
-    deprecated_in((2,1,0)),
-    'bzrlib.tests.features', 'SubUnitFeature', 'subunit')
 # Only define SubUnitBzrRunner if subunit is available.
 try:
     from subunit import TestProtocolClient

=== modified file 'bzrlib/tests/blackbox/test_add.py'
--- bzrlib/tests/blackbox/test_add.py	2010-11-22 03:35:24 +0000
+++ bzrlib/tests/blackbox/test_add.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,20 +26,18 @@
 from bzrlib.tests import (
     script,
     )
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize tests for view-aware vs not."""
-    to_adapt, result = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance(TestAdd))
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
+
+
+class TestAdd(tests.TestCaseWithTransport):
+
     scenarios = [
         ('pre-views', {'branch_tree_format': 'pack-0.92'}),
         ('view-aware', {'branch_tree_format': '2a'}),
         ]
-    return tests.multiply_tests(to_adapt, scenarios, result)
-
-
-class TestAdd(tests.TestCaseWithTransport):
 
     def make_branch_and_tree(self, dir):
         return super(TestAdd, self).make_branch_and_tree(
@@ -231,3 +229,12 @@
         $ bzr add tree1/a tree2/b
         2>bzr: ERROR: Path "...tree2/b" is not a child of path "...tree1"
         ''')
+
+    def test_add_multiple_files_in_unicode_cwd(self):
+        """Adding multiple files in a non-ascii cwd, see lp:686611"""
+        self.requireFeature(tests.UnicodeFilename)
+        self.make_branch_and_tree(u"\xA7")
+        self.build_tree([u"\xA7/a", u"\xA7/b"])
+        out, err = self.run_bzr(["add", "a", "b"], working_dir=u"\xA7")
+        self.assertEquals(out, "adding a\n" "adding b\n")
+        self.assertEquals(err, "")

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -414,7 +414,7 @@
         # being too low. If rpc_count increases, more network roundtrips have
         # become necessary for this use case. Please do not adjust this number
         # upwards without agreement from bzr's network support maintainers.
-        self.assertLength(37, self.hpss_calls)
+        self.assertLength(36, self.hpss_calls)
 
     def test_branch_from_trivial_branch_streaming_acceptance(self):
         self.setup_smart_server_with_call_log()

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2010-12-02 09:23:10 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -719,13 +719,13 @@
             f = file('fed.bat', 'w')
             f.write('@rem dummy fed')
             f.close()
-            osutils.set_or_unset_env('BZR_EDITOR', "fed.bat")
+            self.overrideEnv('BZR_EDITOR', "fed.bat")
         else:
             f = file('fed.sh', 'wb')
             f.write('#!/bin/sh\n')
             f.close()
             os.chmod('fed.sh', 0755)
-            osutils.set_or_unset_env('BZR_EDITOR', "./fed.sh")
+            self.overrideEnv('BZR_EDITOR', "./fed.sh")
 
     def setup_commit_with_template(self):
         self.setup_editor()
@@ -756,8 +756,8 @@
         os.chdir('foo')
         open('foo.txt', 'w').write('hello')
         self.run_bzr(['add'])
-        osutils.set_or_unset_env('EMAIL', None)
-        osutils.set_or_unset_env('BZR_EMAIL', None)
+        self.overrideEnv('EMAIL', None)
+        self.overrideEnv('BZR_EMAIL', None)
         out, err = self.run_bzr(['commit', '-m', 'initial'], 3)
         self.assertContainsRe(err, 'Unable to determine your name')
 

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2010-07-22 13:19:48 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -386,8 +386,7 @@
         # subprocess.py that we had to workaround).
         # However, if 'diff' may not be available
         self.make_example_branch()
-        # this will be automatically restored by the base bzr test class
-        os.environ['BZR_PROGRESS_BAR'] = 'none'
+        self.overrideEnv('BZR_PROGRESS_BAR', 'none')
         out, err = self.run_bzr_subprocess('diff -r 1 --diff-options -ub',
                                            universal_newlines=True,
                                            retcode=None)

=== modified file 'bzrlib/tests/blackbox/test_dpush.py'
--- bzrlib/tests/blackbox/test_dpush.py	2010-09-14 09:47:23 +0000
+++ bzrlib/tests/blackbox/test_dpush.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,30 +33,12 @@
     test_foreign,
     )
 from bzrlib.tests.blackbox import test_push
-
-
-def load_tests(standard_tests, module, loader):
-    """Multiply tests for the dpush command."""
-    result = loader.suiteClass()
-
-    # one for each king of change
-    changes_tests, remaining_tests = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance((
-                TestDpushStrictWithChanges,
-                )))
-    changes_scenarios = [
-        ('uncommitted',
-         dict(_changes_type= '_uncommitted_changes')),
-        ('pending-merges',
-         dict(_changes_type= '_pending_merges')),
-        ('out-of-sync-trees',
-         dict(_changes_type= '_out_of_sync_trees')),
-        ]
-    tests.multiply_tests(changes_tests, changes_scenarios, result)
-    # No parametrization for the remaining tests
-    result.addTests(remaining_tests)
-
-    return result
+from bzrlib.tests.scenarios import (
+    load_tests_apply_scenarios,
+    )
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestDpush(tests.TestCaseWithTransport):
@@ -180,6 +162,8 @@
 class TestDpushStrictWithChanges(TestDpushStrictMixin,
                                  test_push.TestPushStrictWithChanges):
 
+    scenarios = test_push.strict_push_change_scenarios
+
     _changes_type = None # Set by load_tests
 
     def setUp(self):
@@ -188,4 +172,3 @@
 
     def test_push_with_revision(self):
         raise tests.TestNotApplicable('dpush does not handle --revision')
-

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2010-10-12 09:46:37 +0000
+++ bzrlib/tests/blackbox/test_init.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -226,9 +226,9 @@
         # and uses whoami only in a lock file. Without whoami the login name
         # is used. This test is to ensure that init passes even when whoami
         # is not available.
-        osutils.set_or_unset_env('EMAIL', None)
-        osutils.set_or_unset_env('BZR_EMAIL', None)
+        self.overrideEnv('EMAIL', None)
+        self.overrideEnv('BZR_EMAIL', None)
         out, err = self.run_bzr(['init', 'foo'])
         self.assertEqual(err, '')
         self.assertTrue(os.path.exists('foo'))
-        
+

=== modified file 'bzrlib/tests/blackbox/test_non_ascii.py'
--- bzrlib/tests/blackbox/test_non_ascii.py	2010-10-29 17:11:02 +0000
+++ bzrlib/tests/blackbox/test_non_ascii.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,24 +25,24 @@
     urlutils,
     )
 from bzrlib.tests import EncodingAdapter
-
-
-def load_tests(standard_tests, module, loader):
-    return tests.multiply_tests(standard_tests,
-                                EncodingAdapter.encoding_scenarios,
-                                loader.suiteClass())
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestNonAscii(tests.TestCaseWithTransport):
     """Test that bzr handles files/committers/etc which are non-ascii."""
 
+    scenarios = EncodingAdapter.encoding_scenarios
+
     def setUp(self):
         super(TestNonAscii, self).setUp()
         self._check_can_encode_paths()
 
         self.overrideAttr(osutils, '_cached_user_encoding', self.encoding)
         email = self.info['committer'] + ' <joe@foo.com>'
-        os.environ['BZR_EMAIL'] = email.encode(osutils.get_user_encoding())
+        self.overrideEnv('BZR_EMAIL', email.encode(osutils.get_user_encoding()))
         self.create_base()
 
     def run_bzr_decode(self, args, encoding=None, fail=False, retcode=None,

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2010-09-29 02:57:33 +0000
+++ bzrlib/tests/blackbox/test_push.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,34 +34,14 @@
 from bzrlib.tests import (
     blackbox,
     http_server,
+    scenarios,
     test_foreign,
     test_server,
     )
 from bzrlib.transport import memory
 
 
-def load_tests(standard_tests, module, loader):
-    """Multiply tests for the push command."""
-    result = loader.suiteClass()
-
-    # one for each king of change
-    changes_tests, remaining_tests = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance((
-                TestPushStrictWithChanges,
-                )))
-    changes_scenarios = [
-        ('uncommitted',
-         dict(_changes_type= '_uncommitted_changes')),
-        ('pending-merges',
-         dict(_changes_type= '_pending_merges')),
-        ('out-of-sync-trees',
-         dict(_changes_type= '_out_of_sync_trees')),
-        ]
-    tests.multiply_tests(changes_tests, changes_scenarios, result)
-    # No parametrization for the remaining tests
-    result.addTests(remaining_tests)
-
-    return result
+load_tests = scenarios.load_tests_apply_scenarios
 
 
 class TestPush(tests.TestCaseWithTransport):
@@ -251,7 +231,7 @@
         # being too low. If rpc_count increases, more network roundtrips have
         # become necessary for this use case. Please do not adjust this number
         # upwards without agreement from bzr's network support maintainers.
-        self.assertLength(14, self.hpss_calls)
+        self.assertLength(13, self.hpss_calls)
         remote = branch.Branch.open('public')
         self.assertEndsWith(remote.get_stacked_on_url(), '/parent')
 
@@ -729,9 +709,20 @@
         self.assertPushSucceeds([])
 
 
+strict_push_change_scenarios = [
+    ('uncommitted',
+        dict(_changes_type= '_uncommitted_changes')),
+    ('pending-merges',
+        dict(_changes_type= '_pending_merges')),
+    ('out-of-sync-trees',
+        dict(_changes_type= '_out_of_sync_trees')),
+    ]
+
+
 class TestPushStrictWithChanges(tests.TestCaseWithTransport,
                                 TestPushStrictMixin):
 
+    scenarios = strict_push_change_scenarios 
     _changes_type = None # Set by load_tests
 
     def setUp(self):

=== modified file 'bzrlib/tests/blackbox/test_resolve.py'
--- bzrlib/tests/blackbox/test_resolve.py	2010-11-07 16:09:43 +0000
+++ bzrlib/tests/blackbox/test_resolve.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -91,48 +91,3 @@
         self.build_tree_contents([('tree/file', 'a\n')])
         note = self.run_bzr('resolve', working_dir='tree')[1]
         self.assertContainsRe(note, 'All conflicts resolved.')
-
-
-class TestResolveSilentlyIgnore(script.TestCaseWithTransportAndScript):
-
-    def test_bug_646961(self):
-        self.run_script("""\
-            $ bzr init base
-            Created a standalone tree (format: 2a)
-            $ cd base
-            $ echo >file1
-            $ bzr add
-            adding file1
-            $ bzr ci -m "stuff"
-            2>Committing to: .../base/
-            2>added file1
-            2>Committed revision 1.
-            $ cd ..
-            $ bzr branch base branch
-            2>Branched 1 revision(s).
-            $ cd base
-            $ echo "1" >> file1
-            $ bzr ci -m "branch 1"
-            2>Committing to: .../base/
-            2>modified file1
-            2>Committed revision 2.
-            $ cd ../branch
-            $ echo "2" >> file1
-            $ bzr ci -m "branch 2"
-            2>Committing to: .../branch/
-            2>modified file1
-            2>Committed revision 2.
-            $ cd ../base
-            $ bzr merge ../branch
-            2> M  file1
-            2>Text conflict in file1
-            2>1 conflicts encountered.
-            # The following succeeds silently without resolving the conflict
-            $ bzr resolve file1 --take-other
-            2>0 conflict(s) resolved, 1 remaining
-            # The following wil fail when --take-other is implemented
-            # for text conflicts
-            $ bzr conflicts
-            Text conflict in file1
-            """)
-

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2010-04-28 10:30:48 +0000
+++ bzrlib/tests/blackbox/test_send.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 # Authors: Aaron Bentley
 #
 # This program is free software; you can redistribute it and/or modify
@@ -27,30 +27,10 @@
     )
 from bzrlib.bundle import serializer
 from bzrlib.transport import memory
-
-
-def load_tests(standard_tests, module, loader):
-    """Multiply tests for the send command."""
-    result = loader.suiteClass()
-
-    # one for each king of change
-    changes_tests, remaining_tests = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance((
-                TestSendStrictWithChanges,
-                )))
-    changes_scenarios = [
-        ('uncommitted',
-         dict(_changes_type='_uncommitted_changes')),
-        ('pending_merges',
-         dict(_changes_type='_pending_merges')),
-        ('out-of-sync-trees',
-         dict(_changes_type='_out_of_sync_trees')),
-        ]
-    tests.multiply_tests(changes_tests, changes_scenarios, result)
-    # No parametrization for the remaining tests
-    result.addTests(remaining_tests)
-
-    return result
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestSendMixin(object):
@@ -368,6 +348,18 @@
 class TestSendStrictWithChanges(tests.TestCaseWithTransport,
                                    TestSendStrictMixin):
 
+    # These are textually the same as test_push.strict_push_change_scenarios,
+    # but since the functions are reimplemented here, the definitions are left
+    # here too.
+    scenarios = [
+        ('uncommitted',
+         dict(_changes_type='_uncommitted_changes')),
+        ('pending_merges',
+         dict(_changes_type='_pending_merges')),
+        ('out-of-sync-trees',
+         dict(_changes_type='_out_of_sync_trees')),
+        ]
+
     _changes_type = None # Set by load_tests
 
     def setUp(self):

=== modified file 'bzrlib/tests/blackbox/test_serve.py'
--- bzrlib/tests/blackbox/test_serve.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/blackbox/test_serve.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -225,7 +225,7 @@
         # -Dhpss, and does drop some hpss logging to the file.
         self.make_branch('.')
         log_fname = os.getcwd() + '/server.log'
-        self._captureVar('BZR_LOG', log_fname)
+        self.overrideEnv('BZR_LOG', log_fname)
         process, transport = self.start_server_inet(['-Dhpss'])
         branch = BzrDir.open_from_transport(transport).open_branch()
         self.make_read_requests(branch)

=== modified file 'bzrlib/tests/blackbox/test_shared_repository.py'
--- bzrlib/tests/blackbox/test_shared_repository.py	2010-05-05 14:02:53 +0000
+++ bzrlib/tests/blackbox/test_shared_repository.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -155,8 +155,8 @@
         # and uses whoami only in a lock file. Without whoami the login name
         # is used. This test is to ensure that init-repo passes even when whoami
         # is not available.
-        osutils.set_or_unset_env('EMAIL', None)
-        osutils.set_or_unset_env('BZR_EMAIL', None)
+        self.overrideEnv('EMAIL', None)
+        self.overrideEnv('BZR_EMAIL', None)
         out, err = self.run_bzr(['init-repo', 'foo'])
         self.assertEqual(err, '')
         self.assertTrue(os.path.exists('foo'))

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2010-06-11 07:32:12 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -315,37 +315,28 @@
         cmd_name = 'test-command'
         if sys.platform == 'win32':
             cmd_name += '.bat'
-        oldpath = os.environ.get('BZRPATH', None)
-        try:
-            if 'BZRPATH' in os.environ:
-                del os.environ['BZRPATH']
-
-            f = file(cmd_name, 'wb')
-            if sys.platform == 'win32':
-                f.write('@echo off\n')
-            else:
-                f.write('#!/bin/sh\n')
-            # f.write('echo Hello from test-command')
-            f.close()
-            os.chmod(cmd_name, 0755)
-
-            # It should not find the command in the local
-            # directory by default, since it is not in my path
-            self.run_bzr(cmd_name, retcode=3)
-
-            # Now put it into my path
-            os.environ['BZRPATH'] = '.'
-
-            self.run_bzr(cmd_name)
-
-            # Make sure empty path elements are ignored
-            os.environ['BZRPATH'] = os.pathsep
-
-            self.run_bzr(cmd_name, retcode=3)
-
-        finally:
-            if oldpath:
-                os.environ['BZRPATH'] = oldpath
+        self.overrideEnv('BZRPATH', None)
+
+        f = file(cmd_name, 'wb')
+        if sys.platform == 'win32':
+            f.write('@echo off\n')
+        else:
+            f.write('#!/bin/sh\n')
+        # f.write('echo Hello from test-command')
+        f.close()
+        os.chmod(cmd_name, 0755)
+
+        # It should not find the command in the local
+        # directory by default, since it is not in my path
+        self.run_bzr(cmd_name, retcode=3)
+
+        # Now put it into my path
+        self.overrideEnv('BZRPATH', '.')
+        self.run_bzr(cmd_name)
+
+        # Make sure empty path elements are ignored
+        self.overrideEnv('BZRPATH', os.pathsep)
+        self.run_bzr(cmd_name, retcode=3)
 
 
 def listdir_sorted(dir):

=== modified file 'bzrlib/tests/blackbox/test_upgrade.py'
--- bzrlib/tests/blackbox/test_upgrade.py	2010-08-02 14:09:16 +0000
+++ bzrlib/tests/blackbox/test_upgrade.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,32 +58,39 @@
         self.make_format_5_branch()
         (out, err) = self.run_bzr(
             ['upgrade', self.get_readonly_url('format_5_branch')], retcode=3)
-        self.assertEqual(out, "")
-        self.assertEqual(err, "bzr: ERROR: Upgrade URL cannot work with readonly URLs.\n")
+        err_msg = 'Upgrade URL cannot work with readonly URLs.'
+        self.assertEqualDiff('conversion error: %s\nbzr: ERROR: %s\n'
+                             % (err_msg, err_msg),
+                             err)
 
     def test_upgrade_up_to_date(self):
         self.make_current_format_branch_and_checkout()
         # when up to date we should get a message to that effect
         (out, err) = self.run_bzr('upgrade current_format_branch', retcode=3)
-        self.assertEqual("", out)
-        self.assertEqualDiff("bzr: ERROR: The branch format Meta "
-                             "directory format 1 is already at the most "
-                             "recent format.\n", err)
+        err_msg = ('The branch format %s is already at the most recent format.'
+                   % ('Meta directory format 1'))
+        self.assertEqualDiff('conversion error: %s\nbzr: ERROR: %s\n'
+                             % (err_msg, err_msg),
+                             err)
 
     def test_upgrade_up_to_date_checkout_warns_branch_left_alone(self):
         self.make_current_format_branch_and_checkout()
         # when upgrading a checkout, the branch location and a suggestion
         # to upgrade it should be emitted even if the checkout is up to
         # date
+        burl = self.get_transport('current_format_branch').base
+        curl = self.get_transport('current_format_checkout').base
         (out, err) = self.run_bzr('upgrade current_format_checkout', retcode=3)
-        self.assertEqual("This is a checkout. The branch (%s) needs to be "
-                         "upgraded separately.\n"
-                         % transport.get_transport(
-                self.get_url('current_format_branch')).base,
-                         out)
-        self.assertEqualDiff("bzr: ERROR: The branch format Meta "
-                             "directory format 1 is already at the most "
-                             "recent format.\n", err)
+        self.assertEqual(
+            'Upgrading branch %s ...\nThis is a checkout.'
+            ' The branch (%s) needs to be upgraded separately.\n'
+            % (curl, burl),
+            out)
+        msg = 'The branch format %s is already at the most recent format.' % (
+            'Meta directory format 1')
+        self.assertEqualDiff('conversion error: %s\nbzr: ERROR: %s\n'
+                             % (msg, msg),
+                             err)
 
     def test_upgrade_checkout(self):
         # upgrading a checkout should work
@@ -107,7 +114,8 @@
         backup_dir = 'backup.bzr.~1~'
         (out, err) = self.run_bzr(
             ['upgrade', '--format=metaweave', url])
-        self.assertEqualDiff("""starting upgrade of %s
+        self.assertEqualDiff("""Upgrading branch %s ...
+starting upgrade of %s
 making backup of %s.bzr
   to %s%s
 starting upgrade from format 5 to 6
@@ -115,7 +123,7 @@
 adding prefixes to revision-store
 starting upgrade from format 6 to metadir
 finished
-""" % (url, url, url, backup_dir), out)
+""" % (url, url, url, url, backup_dir), out)
         self.assertEqualDiff("", err)
         self.assertTrue(isinstance(
             bzrdir.BzrDir.open(self.get_url('format_5_branch'))._format,
@@ -131,13 +139,15 @@
         backup_dir = 'backup.bzr.~1~'
         (out, err) = self.run_bzr(
             ['upgrade', '--format=knit', url])
-        self.assertEqualDiff("""starting upgrade of %s
+        self.assertEqualDiff("""Upgrading branch %s ...
+starting upgrade of %s
 making backup of %s.bzr
   to %s%s
 starting repository conversion
 repository converted
 finished
-""" % (url, url, url, backup_dir), out)
+""" % (url, url, url, url, backup_dir),
+                             out)
         self.assertEqualDiff("", err)
         converted_dir = bzrdir.BzrDir.open(self.get_url('metadir_weave_branch'))
         self.assertTrue(isinstance(converted_dir._format,
@@ -149,6 +159,29 @@
         self.run_bzr('init-repository --format=metaweave repo')
         self.run_bzr('upgrade --format=knit repo')
 
+    def assertLegalOption(self, option_str):
+        # Confirm that an option is legal. (Lower level tests are
+        # expected to validate the actual functionality.)
+        self.run_bzr('init --format=pack-0.92 branch-foo')
+        self.run_bzr('upgrade --format=2a branch-foo %s' % (option_str,))
+
+    def assertBranchFormat(self, dir, format):
+        branch = bzrdir.BzrDir.open_tree_or_branch(self.get_url(dir))[1]
+        branch_format = branch._format
+        meta_format = bzrdir.format_registry.make_bzrdir(format)
+        expected_format = meta_format.get_branch_format()
+        self.assertEqual(expected_format, branch_format)
+
+    def test_upgrade_clean_supported(self):
+        self.assertLegalOption('--clean')
+        self.assertBranchFormat('branch-foo', '2a')
+        backup_bzr_dir = os.path.join("branch-foo", "backup.bzr.~1~")
+        self.assertFalse(os.path.exists(backup_bzr_dir))
+
+    def test_upgrade_dry_run_supported(self):
+        self.assertLegalOption('--dry-run')
+        self.assertBranchFormat('branch-foo', 'pack-0.92')
+
     def test_upgrade_permission_check(self):
         """'backup.bzr' should retain permissions of .bzr. Bug #262450"""
         self.requireFeature(features.posix_permissions_feature)
@@ -173,7 +206,8 @@
         t.mkdir(backup_dir1)
         (out, err) = self.run_bzr(
             ['upgrade', '--format=metaweave', url])
-        self.assertEqualDiff("""starting upgrade of %s
+        self.assertEqualDiff("""Upgrading branch %s ...
+starting upgrade of %s
 making backup of %s.bzr
   to %s%s
 starting upgrade from format 5 to 6
@@ -181,7 +215,7 @@
 adding prefixes to revision-store
 starting upgrade from format 6 to metadir
 finished
-""" % (url, url, url, backup_dir2), out)
+""" % (url, url, url, url, backup_dir2), out)
         self.assertEqualDiff("", err)
         self.assertTrue(isinstance(
             bzrdir.BzrDir.open(self.get_url('format_5_branch'))._format,
@@ -197,14 +231,15 @@
         url = t.base
         out, err = self.run_bzr(['upgrade', '--format=knit', url])
         backup_dir = 'backup.bzr.~1~'
-        self.assertEqualDiff("""starting upgrade of %s
+        self.assertEqualDiff("""Upgrading branch %s ...
+starting upgrade of %s
 making backup of %s.bzr
   to %s%s
 starting upgrade from format 6 to metadir
 starting repository conversion
 repository converted
 finished
-""" % (url, url, url,backup_dir), out)
+""" % (url, url, url, url,backup_dir), out)
         self.assertEqual('', err)
 
 

=== modified file 'bzrlib/tests/blackbox/test_version.py'
--- bzrlib/tests/blackbox/test_version.py	2009-12-02 16:43:09 +0000
+++ bzrlib/tests/blackbox/test_version.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2008 Canonical Ltd
+# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -95,7 +95,7 @@
             raise TestSkipped('Cannot find a unicode character that works in'
                               ' encoding %s' % (osutils.get_user_encoding(),))
 
-        osutils.set_or_unset_env('BZR_HOME', str_val)
+        self.overrideEnv('BZR_HOME', str_val)
         self.permit_source_tree_branch_repo()
         out = self.run_bzr("version")[0]
         self.assertTrue(len(out) > 0)
@@ -106,7 +106,7 @@
 
     def test_simple(self):
         bzr_log = 'my.bzr.log'
-        osutils.set_or_unset_env('BZR_LOG', bzr_log)
+        self.overrideEnv('BZR_LOG', bzr_log)
         default_log = os.path.join(os.environ['BZR_HOME'], '.bzr.log')
         self.failIfExists([default_log, bzr_log])
         out = self.run_bzr_subprocess('version')[0]
@@ -122,7 +122,7 @@
             bzr_log = 'NUL'
         else:
             bzr_log = '/dev/null'
-        osutils.set_or_unset_env('BZR_LOG', bzr_log)
+        self.overrideEnv('BZR_LOG', bzr_log)
         default_log = os.path.join(os.environ['BZR_HOME'], '.bzr.log')
         self.failIfExists(default_log)
         out = self.run_bzr_subprocess('version')[0]

=== modified file 'bzrlib/tests/blackbox/test_whoami.py'
--- bzrlib/tests/blackbox/test_whoami.py	2010-06-23 08:19:28 +0000
+++ bzrlib/tests/blackbox/test_whoami.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@
 
         # Verify that the environment variable overrides the value
         # in the file
-        os.environ['BZR_EMAIL'] = 'Different ID <other@environ.ment>'
+        self.overrideEnv('BZR_EMAIL', 'Different ID <other@environ.ment>')
         whoami = self.run_bzr("whoami")[0]
         self.assertEquals('Different ID <other@environ.ment>\n', whoami)
         whoami_email = self.run_bzr("whoami --email")[0]
@@ -94,8 +94,8 @@
     def test_whoami_not_set(self):
         """Ensure whoami error if username is not set.
         """
-        osutils.set_or_unset_env('EMAIL', None)
-        osutils.set_or_unset_env('BZR_EMAIL', None)
+        self.overrideEnv('EMAIL', None)
+        self.overrideEnv('BZR_EMAIL', None)
         out, err = self.run_bzr(['whoami'], 3)
         self.assertContainsRe(err, 'Unable to determine your name')
 

=== modified file 'bzrlib/tests/doc_generate/__init__.py'
--- bzrlib/tests/doc_generate/__init__.py	2010-07-21 08:07:14 +0000
+++ bzrlib/tests/doc_generate/__init__.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,6 +52,11 @@
 
     _test_needs_features = [features.sphinx]
 
+    def sphinx_version(self):
+        # Convert to a tuple to avoid traps in string comparison
+        # ( '1.12' < '1.6' but (1, 12) > (1, 6) )
+        return tuple(map(int, features.sphinx.module.__version__.split('.')))
+
     def make_sphinx(self):
         out = tests.StringIOWrapper()
         err = tests.StringIOWrapper()

=== modified file 'bzrlib/tests/doc_generate/builders/test_texinfo.py'
--- bzrlib/tests/doc_generate/builders/test_texinfo.py	2010-07-06 13:22:32 +0000
+++ bzrlib/tests/doc_generate/builders/test_texinfo.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,6 +43,8 @@
 class TestFileProduction(test_dg.TestSphinx):
 
     def test_files_generated(self):
+        if self.sphinx_version() >= (1, 0):
+            raise tests.TestSkipped('Not compatible with sphinx >= 1.0')
         self.build_tree_contents(
             [('index.txt', """
 Table of Contents

=== modified file 'bzrlib/tests/doc_generate/writers/test_texinfo.py'
--- bzrlib/tests/doc_generate/writers/test_texinfo.py	2010-07-21 08:07:14 +0000
+++ bzrlib/tests/doc_generate/writers/test_texinfo.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 
 """sphinx texinfo writer tests."""
 
+from bzrlib import tests
 from bzrlib.tests import (
     doc_generate as test_dg, # Avoid clash with from bzrlib import doc_generate
     )
@@ -176,6 +177,8 @@
 class TestTocTreeGeneration(test_dg.TestSphinx):
 
     def test_toctree(self):
+        if self.sphinx_version() >= (1, 0):
+            raise tests.TestSkipped('Not compatible with sphinx >= 1.0')
         self.build_tree_contents(
             [('index.txt', """
 Table of Contents

=== modified file 'bzrlib/tests/https_server.py'
--- bzrlib/tests/https_server.py	2010-07-01 06:40:14 +0000
+++ bzrlib/tests/https_server.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 """HTTPS test server, available when ssl python module is available"""
 
 import ssl
+import sys
 
 from bzrlib.tests import (
     http_server,
@@ -51,6 +52,17 @@
             request.do_handshake()
         return serving
 
+    def ignored_exceptions_during_shutdown(self, e):
+        if (sys.version < (2, 7) and isinstance(e, TypeError)
+            and e.args[0] == "'member_descriptor' object is not callable"):
+            # Fixed in python-2.7 (and some Ubuntu 2.6) there is a bug where
+            # the ssl socket fail to raise a socket.error when trying to read
+            # from a closed socket. This is rarely observed in practice but
+            # still make valid selftest runs fail if not caught.
+            return True
+        base = test_server.TestingTCPServerMixin
+        return base.ignored_exceptions_during_shutdown(self, e)
+
 
 class TestingHTTPSServer(TestingHTTPSServerMixin,
                          http_server.TestingHTTPServer):

=== modified file 'bzrlib/tests/per_branch/test_branch.py'
--- bzrlib/tests/per_branch/test_branch.py	2010-08-29 14:32:45 +0000
+++ bzrlib/tests/per_branch/test_branch.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -187,7 +187,7 @@
         self.assertEqual(branch_b.get_parent(), branch_c.get_parent())
 
         # We can also set a specific parent, and it should be honored
-        random_parent = 'http://bazaar-vcs.org/path/to/branch'
+        random_parent = 'http://example.com/path/to/branch'
         branch_b.set_parent(random_parent)
         repo_d = self.make_repository('d')
         branch_b.repository.copy_content_into(repo_d)

=== modified file 'bzrlib/tests/per_branch/test_parent.py'
--- bzrlib/tests/per_branch/test_parent.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/per_branch/test_parent.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
     def test_set_get_parent(self):
         """Set, re-get and reset the parent"""
         b = self.make_branch('subdir')
-        url = 'http://bazaar-vcs.org/bzr/bzr.dev'
+        url = 'http://example.com/bzr/bzr.dev'
         b.set_parent(url)
         self.assertEqual(url, b.get_parent())
         self.assertEqual(url, b._get_parent_location())

=== modified file 'bzrlib/tests/per_controldir/test_controldir.py'
--- bzrlib/tests/per_controldir/test_controldir.py	2010-11-26 17:59:08 +0000
+++ bzrlib/tests/per_controldir/test_controldir.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -257,7 +257,7 @@
 
     def test_clone_bzrdir_branch_and_repo_fixed_user_id(self):
         # Bug #430868 is about an email containing '.sig'
-        os.environ['BZR_EMAIL'] = 'murphy@host.sighup.org'
+        self.overrideEnv('BZR_EMAIL', 'murphy@host.sighup.org')
         tree = self.make_branch_and_tree('commit_tree')
         self.build_tree(['commit_tree/foo'])
         tree.add('foo')

=== modified file 'bzrlib/tests/per_repository/test_check.py'
--- bzrlib/tests/per_repository/test_check.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/per_repository/test_check.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -135,7 +135,7 @@
         repo.lock_write()
         self.addCleanup(repo.unlock)
         config = _mod_config.Config()
-        os.environ['BZR_EMAIL'] = 'foo@sample.com'
+        self.overrideEnv('BZR_EMAIL', 'foo@sample.com')
         builder = repo.get_commit_builder(None, [], config)
         list(builder.record_iter_changes(None, _mod_revision.NULL_REVISION, [
             ('TREE_ROOT', (None, ''), True, (False, True), (None, None),

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2010-10-15 16:43:03 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1317,7 +1317,7 @@
     def test_committer_no_username(self):
         # Ensure that when no username is available but a committer is
         # supplied, commit works.
-        del os.environ['EMAIL']
+        self.overrideEnv('EMAIL', None)
         tree = self.make_branch_and_tree(".")
         tree.lock_write()
         try:

=== modified file 'bzrlib/tests/per_transport.py'
--- bzrlib/tests/per_transport.py	2010-09-21 03:20:09 +0000
+++ bzrlib/tests/per_transport.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -98,7 +98,7 @@
 
     def setUp(self):
         super(TransportTests, self).setUp()
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
 
     def check_transport_contents(self, content, transport, relpath):
         """Check that transport.get(relpath).read() == content."""

=== modified file 'bzrlib/tests/per_uifactory/__init__.py'
--- bzrlib/tests/per_uifactory/__init__.py	2010-09-09 07:49:00 +0000
+++ bzrlib/tests/per_uifactory/__init__.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -190,7 +190,7 @@
 
         # Remove 'TERM' == 'dumb' which causes us to *not* treat output as a
         # real terminal, even though isatty returns True
-        self._captureVar('TERM', None)
+        self.overrideEnv('TERM', None)
         self.stderr = TTYStringIO()
         self.stdout = TTYStringIO()
         self.factory = ui.text.TextUIFactory(self.stdin, self.stdout,

=== modified file 'bzrlib/tests/per_versionedfile.py'
--- bzrlib/tests/per_versionedfile.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/per_versionedfile.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # Authors:
 #   Johan Rydberg <jrydberg@gnu.org>
@@ -51,9 +51,6 @@
     TestCaseWithMemoryTransport,
     TestNotApplicable,
     TestSkipped,
-    condition_isinstance,
-    split_suite_by_condition,
-    multiply_tests,
     )
 from bzrlib.tests.http_utils import TestCaseWithWebserver
 from bzrlib.trace import mutter
@@ -70,100 +67,10 @@
     )
 from bzrlib.weave import WeaveFile
 from bzrlib.weavefile import read_weave, write_weave
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize VersionedFiles tests for different implementations."""
-    to_adapt, result = split_suite_by_condition(
-        standard_tests, condition_isinstance(TestVersionedFiles))
-    # We want to be sure of behaviour for:
-    # weaves prefix layout (weave texts)
-    # individually named weaves (weave inventories)
-    # annotated knits - prefix|hash|hash-escape layout, we test the third only
-    #                   as it is the most complex mapper.
-    # individually named knits
-    # individual no-graph knits in packs (signatures)
-    # individual graph knits in packs (inventories)
-    # individual graph nocompression knits in packs (revisions)
-    # plain text knits in packs (texts)
-    len_one_scenarios = [
-        ('weave-named', {
-            'cleanup':None,
-            'factory':make_versioned_files_factory(WeaveFile,
-                ConstantMapper('inventory')),
-            'graph':True,
-            'key_length':1,
-            'support_partial_insertion': False,
-            }),
-        ('named-knit', {
-            'cleanup':None,
-            'factory':make_file_factory(False, ConstantMapper('revisions')),
-            'graph':True,
-            'key_length':1,
-            'support_partial_insertion': False,
-            }),
-        ('named-nograph-nodelta-knit-pack', {
-            'cleanup':cleanup_pack_knit,
-            'factory':make_pack_factory(False, False, 1),
-            'graph':False,
-            'key_length':1,
-            'support_partial_insertion': False,
-            }),
-        ('named-graph-knit-pack', {
-            'cleanup':cleanup_pack_knit,
-            'factory':make_pack_factory(True, True, 1),
-            'graph':True,
-            'key_length':1,
-            'support_partial_insertion': True,
-            }),
-        ('named-graph-nodelta-knit-pack', {
-            'cleanup':cleanup_pack_knit,
-            'factory':make_pack_factory(True, False, 1),
-            'graph':True,
-            'key_length':1,
-            'support_partial_insertion': False,
-            }),
-        ('groupcompress-nograph', {
-            'cleanup':groupcompress.cleanup_pack_group,
-            'factory':groupcompress.make_pack_factory(False, False, 1),
-            'graph': False,
-            'key_length':1,
-            'support_partial_insertion':False,
-            }),
-        ]
-    len_two_scenarios = [
-        ('weave-prefix', {
-            'cleanup':None,
-            'factory':make_versioned_files_factory(WeaveFile,
-                PrefixMapper()),
-            'graph':True,
-            'key_length':2,
-            'support_partial_insertion': False,
-            }),
-        ('annotated-knit-escape', {
-            'cleanup':None,
-            'factory':make_file_factory(True, HashEscapedPrefixMapper()),
-            'graph':True,
-            'key_length':2,
-            'support_partial_insertion': False,
-            }),
-        ('plain-knit-pack', {
-            'cleanup':cleanup_pack_knit,
-            'factory':make_pack_factory(True, True, 2),
-            'graph':True,
-            'key_length':2,
-            'support_partial_insertion': True,
-            }),
-        ('groupcompress', {
-            'cleanup':groupcompress.cleanup_pack_group,
-            'factory':groupcompress.make_pack_factory(True, False, 1),
-            'graph': True,
-            'key_length':1,
-            'support_partial_insertion':False,
-            }),
-        ]
-    scenarios = len_one_scenarios + len_two_scenarios
-    return multiply_tests(to_adapt, scenarios, result)
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 def get_diamond_vf(f, trailing_eol=True, left_only=False):
@@ -1475,6 +1382,95 @@
 class TestVersionedFiles(TestCaseWithMemoryTransport):
     """Tests for the multiple-file variant of VersionedFile."""
 
+    # We want to be sure of behaviour for:
+    # weaves prefix layout (weave texts)
+    # individually named weaves (weave inventories)
+    # annotated knits - prefix|hash|hash-escape layout, we test the third only
+    #                   as it is the most complex mapper.
+    # individually named knits
+    # individual no-graph knits in packs (signatures)
+    # individual graph knits in packs (inventories)
+    # individual graph nocompression knits in packs (revisions)
+    # plain text knits in packs (texts)
+    len_one_scenarios = [
+        ('weave-named', {
+            'cleanup':None,
+            'factory':make_versioned_files_factory(WeaveFile,
+                ConstantMapper('inventory')),
+            'graph':True,
+            'key_length':1,
+            'support_partial_insertion': False,
+            }),
+        ('named-knit', {
+            'cleanup':None,
+            'factory':make_file_factory(False, ConstantMapper('revisions')),
+            'graph':True,
+            'key_length':1,
+            'support_partial_insertion': False,
+            }),
+        ('named-nograph-nodelta-knit-pack', {
+            'cleanup':cleanup_pack_knit,
+            'factory':make_pack_factory(False, False, 1),
+            'graph':False,
+            'key_length':1,
+            'support_partial_insertion': False,
+            }),
+        ('named-graph-knit-pack', {
+            'cleanup':cleanup_pack_knit,
+            'factory':make_pack_factory(True, True, 1),
+            'graph':True,
+            'key_length':1,
+            'support_partial_insertion': True,
+            }),
+        ('named-graph-nodelta-knit-pack', {
+            'cleanup':cleanup_pack_knit,
+            'factory':make_pack_factory(True, False, 1),
+            'graph':True,
+            'key_length':1,
+            'support_partial_insertion': False,
+            }),
+        ('groupcompress-nograph', {
+            'cleanup':groupcompress.cleanup_pack_group,
+            'factory':groupcompress.make_pack_factory(False, False, 1),
+            'graph': False,
+            'key_length':1,
+            'support_partial_insertion':False,
+            }),
+        ]
+    len_two_scenarios = [
+        ('weave-prefix', {
+            'cleanup':None,
+            'factory':make_versioned_files_factory(WeaveFile,
+                PrefixMapper()),
+            'graph':True,
+            'key_length':2,
+            'support_partial_insertion': False,
+            }),
+        ('annotated-knit-escape', {
+            'cleanup':None,
+            'factory':make_file_factory(True, HashEscapedPrefixMapper()),
+            'graph':True,
+            'key_length':2,
+            'support_partial_insertion': False,
+            }),
+        ('plain-knit-pack', {
+            'cleanup':cleanup_pack_knit,
+            'factory':make_pack_factory(True, True, 2),
+            'graph':True,
+            'key_length':2,
+            'support_partial_insertion': True,
+            }),
+        ('groupcompress', {
+            'cleanup':groupcompress.cleanup_pack_group,
+            'factory':groupcompress.make_pack_factory(True, False, 1),
+            'graph': True,
+            'key_length':1,
+            'support_partial_insertion':False,
+            }),
+        ]
+
+    scenarios = len_one_scenarios + len_two_scenarios
+
     def get_versionedfiles(self, relpath='files'):
         transport = self.get_transport(relpath)
         if relpath != '.':

=== modified file 'bzrlib/tests/test__dirstate_helpers.py'
--- bzrlib/tests/test__dirstate_helpers.py	2010-06-02 04:50:35 +0000
+++ bzrlib/tests/test__dirstate_helpers.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,60 +28,34 @@
     )
 from bzrlib.tests import (
     test_dirstate,
-    test_osutils,
-    )
-
-try:
-    from bzrlib import _dirstate_helpers_pyx
-    has_dirstate_helpers_pyx = True
-except ImportError:
-    has_dirstate_helpers_pyx = False
+    )
+from bzrlib.tests.test_osutils import dir_reader_scenarios
+from bzrlib.tests.scenarios import (
+    load_tests_apply_scenarios,
+    multiply_scenarios,
+    )
+
+
+load_tests = load_tests_apply_scenarios
 
 
 compiled_dirstate_helpers_feature = tests.ModuleAvailableFeature(
-                                'bzrlib._dirstate_helpers_pyx')
-
-
-def load_tests(basic_tests, module, loader):
-    # FIXME: we should also parametrize against SHA1Provider !
-    suite = loader.suiteClass()
-    remaining_tests = basic_tests
-
-    dir_reader_scenarios = test_osutils.dir_reader_scenarios()
-
-    ue_scenarios = [('dirstate_Python',
-                     {'update_entry': dirstate.py_update_entry})]
-    if compiled_dirstate_helpers_feature.available():
-        update_entry = compiled_dirstate_helpers_feature.module.update_entry
-        pyrex_scenario = ('dirstate_Pyrex', {'update_entry': update_entry})
-        ue_scenarios.append(pyrex_scenario)
-    process_entry_tests, remaining_tests = tests.split_suite_by_condition(
-        remaining_tests, tests.condition_isinstance(TestUpdateEntry))
-    tests.multiply_tests(process_entry_tests,
-                         tests.multiply_scenarios(dir_reader_scenarios,
-                                                  ue_scenarios),
-                         suite)
-
-    pe_scenarios = [('dirstate_Python',
-                     {'_process_entry': dirstate.ProcessEntryPython})]
-    if compiled_dirstate_helpers_feature.available():
-        process_entry = compiled_dirstate_helpers_feature.module.ProcessEntryC
-        pyrex_scenario = ('dirstate_Pyrex', {'_process_entry': process_entry})
-        pe_scenarios.append(pyrex_scenario)
-    process_entry_tests, remaining_tests = tests.split_suite_by_condition(
-        remaining_tests, tests.condition_isinstance(TestProcessEntry))
-    tests.multiply_tests(process_entry_tests,
-                         tests.multiply_scenarios(dir_reader_scenarios,
-                                                  pe_scenarios),
-                         suite)
-
-    dir_reader_tests, remaining_tests = tests.split_suite_by_condition(
-        remaining_tests, tests.condition_isinstance(
-            test_dirstate.TestCaseWithDirState))
-    tests.multiply_tests(dir_reader_tests, dir_reader_scenarios, suite)
-    suite.addTest(remaining_tests)
-
-    return suite
+    'bzrlib._dirstate_helpers_pyx')
+
+
+# FIXME: we should also parametrize against SHA1Provider !
+
+ue_scenarios = [('dirstate_Python',
+    {'update_entry': dirstate.py_update_entry})]
+if compiled_dirstate_helpers_feature.available():
+    update_entry = compiled_dirstate_helpers_feature.module.update_entry
+    ue_scenarios.append(('dirstate_Pyrex', {'update_entry': update_entry}))
+
+pe_scenarios = [('dirstate_Python',
+    {'_process_entry': dirstate.ProcessEntryPython})]
+if compiled_dirstate_helpers_feature.available():
+    process_entry = compiled_dirstate_helpers_feature.module.ProcessEntryC
+    pe_scenarios.append(('dirstate_Pyrex', {'_process_entry': process_entry}))
 
 
 class TestBisectPathMixin(object):
@@ -719,6 +693,8 @@
     implementation.
     """
 
+    # inherits scenarios from test_dirstate
+
     def get_read_dirblocks(self):
         from bzrlib._dirstate_helpers_py import _read_dirblocks
         return _read_dirblocks
@@ -826,6 +802,9 @@
 class TestUpdateEntry(test_dirstate.TestCaseWithDirState):
     """Test the DirState.update_entry functions"""
 
+    scenarios = multiply_scenarios(
+        dir_reader_scenarios(), ue_scenarios)
+
     # Set by load_tests
     update_entry = None
 
@@ -1269,6 +1248,8 @@
 
 class TestProcessEntry(test_dirstate.TestCaseWithDirState):
 
+    scenarios = multiply_scenarios(dir_reader_scenarios(), pe_scenarios)
+
     # Set by load_tests
     _process_entry = None
 

=== modified file 'bzrlib/tests/test__groupcompress.py'
--- bzrlib/tests/test__groupcompress.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test__groupcompress.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,14 +21,13 @@
     _groupcompress_py,
     tests,
     )
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize tests for all versions of groupcompress."""
-    two_way_scenarios = [
-        ('PP', {'make_delta': _groupcompress_py.make_delta,
-                'apply_delta': _groupcompress_py.apply_delta})
-        ]
+from bzrlib.tests.scenarios import (
+    load_tests_apply_scenarios,
+    multiply_scenarios,
+    )
+
+
+def module_scenarios():
     scenarios = [
         ('python', {'_gc_module': _groupcompress_py}),
         ]
@@ -36,7 +35,17 @@
         gc_module = compiled_groupcompress_feature.module
         scenarios.append(('C',
             {'_gc_module': gc_module}))
-        two_way_scenarios.extend([
+    return scenarios
+
+
+def two_way_scenarios():
+    scenarios = [
+        ('PP', {'make_delta': _groupcompress_py.make_delta,
+                'apply_delta': _groupcompress_py.apply_delta})
+        ]
+    if compiled_groupcompress_feature.available():
+        gc_module = compiled_groupcompress_feature.module
+        scenarios.extend([
             ('CC', {'make_delta': gc_module.make_delta,
                     'apply_delta': gc_module.apply_delta}),
             ('PC', {'make_delta': _groupcompress_py.make_delta,
@@ -44,14 +53,10 @@
             ('CP', {'make_delta': gc_module.make_delta,
                     'apply_delta': _groupcompress_py.apply_delta}),
             ])
-    to_adapt, result = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance((TestMakeAndApplyDelta,
-                                                    TestBase128Int)))
-    result = tests.multiply_tests(to_adapt, scenarios, result)
-    to_adapt, result = tests.split_suite_by_condition(result,
-        tests.condition_isinstance(TestMakeAndApplyCompatible))
-    result = tests.multiply_tests(to_adapt, two_way_scenarios, result)
-    return result
+    return scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 compiled_groupcompress_feature = tests.ModuleAvailableFeature(
@@ -116,6 +121,7 @@
 
 class TestMakeAndApplyDelta(tests.TestCase):
 
+    scenarios = module_scenarios()
     _gc_module = None # Set by load_tests
 
     def setUp(self):
@@ -226,6 +232,8 @@
 
 class TestMakeAndApplyCompatible(tests.TestCase):
 
+    scenarios = two_way_scenarios()
+
     make_delta = None # Set by load_tests
     apply_delta = None # Set by load_tests
 
@@ -457,6 +465,8 @@
 
 class TestBase128Int(tests.TestCase):
 
+    scenarios = module_scenarios()
+
     _gc_module = None # Set by load_tests
 
     def assertEqualEncode(self, bytes, val):

=== modified file 'bzrlib/tests/test__known_graph.py'
--- bzrlib/tests/test__known_graph.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test__known_graph.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,41 +26,35 @@
     )
 from bzrlib.tests import test_graph
 from bzrlib.revision import NULL_REVISION
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize tests for all versions of groupcompress."""
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+def caching_scenarios():
     scenarios = [
         ('python', {'module': _known_graph_py, 'do_cache': True}),
     ]
-    caching_scenarios = [
-        ('python-nocache', {'module': _known_graph_py, 'do_cache': False}),
-    ]
-    suite = loader.suiteClass()
     if compiled_known_graph_feature.available():
         scenarios.append(('C', {'module': compiled_known_graph_feature.module,
                                 'do_cache': True}))
-        caching_scenarios.append(
+    return scenarios
+
+
+def non_caching_scenarios():
+    scenarios = [
+        ('python-nocache', {'module': _known_graph_py, 'do_cache': False}),
+    ]
+    if compiled_known_graph_feature.available():
+        scenarios.append(
             ('C-nocache', {'module': compiled_known_graph_feature.module,
                            'do_cache': False}))
-    else:
-        # the compiled module isn't available, so we add a failing test
-        class FailWithoutFeature(tests.TestCase):
-            def test_fail(self):
-                self.requireFeature(compiled_known_graph_feature)
-        suite.addTest(loader.loadTestsFromTestCase(FailWithoutFeature))
-    # TestKnownGraphHeads needs to be permutated with and without caching.
-    # All other TestKnownGraph tests only need to be tested across module
-    heads_suite, other_suite = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance(TestKnownGraphHeads))
-    suite = tests.multiply_tests(other_suite, scenarios, suite)
-    suite = tests.multiply_tests(heads_suite, scenarios + caching_scenarios,
-                                 suite)
-    return suite
+    return scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 compiled_known_graph_feature = tests.ModuleAvailableFeature(
-                                    'bzrlib._known_graph_pyx')
+    'bzrlib._known_graph_pyx')
 
 
 #  a
@@ -75,6 +69,7 @@
 
 class TestCaseWithKnownGraph(tests.TestCase):
 
+    scenarios = caching_scenarios()
     module = None # Set by load_tests
 
     def make_known_graph(self, ancestry):
@@ -214,6 +209,7 @@
 
 class TestKnownGraphHeads(TestCaseWithKnownGraph):
 
+    scenarios = caching_scenarios() + non_caching_scenarios()
     do_cache = None # Set by load_tests
 
     def test_heads_null(self):

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2010-09-09 00:32:58 +0000
+++ bzrlib/tests/test_branch.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@
         """See BzrBranchFormat.get_format_string()."""
         return "Sample branch format."
 
-    def initialize(self, a_bzrdir, name=None):
+    def initialize(self, a_bzrdir, name=None, repository=None):
         """Format 4 branches cannot be created."""
         t = a_bzrdir.get_branch_transport(self, name=name)
         t.put_bytes('format', self.get_format_string())
@@ -267,16 +267,16 @@
     def test_config(self):
         """Ensure that all configuration data is stored in the branch"""
         branch = self.make_branch('a', format=self.get_format_name())
-        branch.set_parent('http://bazaar-vcs.org')
+        branch.set_parent('http://example.com')
         self.failIfExists('a/.bzr/branch/parent')
-        self.assertEqual('http://bazaar-vcs.org', branch.get_parent())
-        branch.set_push_location('sftp://bazaar-vcs.org')
+        self.assertEqual('http://example.com', branch.get_parent())
+        branch.set_push_location('sftp://example.com')
         config = branch.get_config()._get_branch_data_config()
-        self.assertEqual('sftp://bazaar-vcs.org',
+        self.assertEqual('sftp://example.com',
                          config.get_user_option('push_location'))
-        branch.set_bound_location('ftp://bazaar-vcs.org')
+        branch.set_bound_location('ftp://example.com')
         self.failIfExists('a/.bzr/branch/bound')
-        self.assertEqual('ftp://bazaar-vcs.org', branch.get_bound_location())
+        self.assertEqual('ftp://example.com', branch.get_bound_location())
 
     def test_set_revision_history(self):
         builder = self.make_branch_builder('.', format=self.get_format_name())

=== modified file 'bzrlib/tests/test_btree_index.py'
--- bzrlib/tests/test_btree_index.py	2010-08-03 20:56:39 +0000
+++ bzrlib/tests/test_btree_index.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,26 +31,24 @@
     )
 from bzrlib.tests import (
     TestCaseWithTransport,
-    condition_isinstance,
-    multiply_tests,
-    split_suite_by_condition,
+    scenarios,
     )
 
 
-def load_tests(standard_tests, module, loader):
-    # parameterise the TestBTreeNodes tests
-    node_tests, others = split_suite_by_condition(standard_tests,
-        condition_isinstance(TestBTreeNodes))
+load_tests = scenarios.load_tests_apply_scenarios
+
+
+def btreeparser_scenarios():
     import bzrlib._btree_serializer_py as py_module
     scenarios = [('python', {'parse_btree': py_module})]
     if compiled_btreeparser_feature.available():
-        scenarios.append(('C', {'parse_btree':
-                                compiled_btreeparser_feature.module}))
-    return multiply_tests(node_tests, scenarios, others)
+        scenarios.append(('C', 
+            {'parse_btree': compiled_btreeparser_feature.module}))
+    return scenarios
 
 
 compiled_btreeparser_feature = tests.ModuleAvailableFeature(
-                                'bzrlib._btree_serializer_pyx')
+    'bzrlib._btree_serializer_pyx')
 
 
 class BTreeTestCase(TestCaseWithTransport):
@@ -1185,6 +1183,8 @@
 
 class TestBTreeNodes(BTreeTestCase):
 
+    scenarios = btreeparser_scenarios()
+
     def setUp(self):
         BTreeTestCase.setUp(self)
         self.overrideAttr(btree_index, '_btree_serializer', self.parse_btree)

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2010-10-15 14:21:03 +0000
+++ bzrlib/tests/test_bzrdir.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
     controldir,
     errors,
     help_topics,
+    lock,
     repository,
     osutils,
     remote,
@@ -1349,6 +1350,12 @@
     def set_parent(self, parent):
         self._parent = parent
 
+    def lock_read(self):
+        return lock.LogicalLockResult(self.unlock)
+
+    def unlock(self):
+        return
+
 
 class TestBzrDirSprout(TestCaseWithMemoryTransport):
 

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2010-11-29 01:23:53 +0000
+++ bzrlib/tests/test_config.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -402,11 +402,11 @@
 
     def setUp(self):
         super(TestConfigPath, self).setUp()
-        os.environ['HOME'] = '/home/bogus'
-        os.environ['XDG_CACHE_DIR'] = ''
+        self.overrideEnv('HOME', '/home/bogus')
+        self.overrideEnv('XDG_CACHE_DIR', '')
         if sys.platform == 'win32':
-            os.environ['BZR_HOME'] = \
-                r'C:\Documents and Settings\bogus\Application Data'
+            self.overrideEnv(
+                'BZR_HOME', r'C:\Documents and Settings\bogus\Application Data')
             self.bzr_home = \
                 'C:/Documents and Settings/bogus/Application Data/bazaar/2.0'
         else:
@@ -441,9 +441,9 @@
             raise tests.TestNotApplicable(
                 'XDG config dir not used on this platform')
         super(TestXDGConfigDir, self).setUp()
-        os.environ['HOME'] = self.test_home_dir
+        self.overrideEnv('HOME', self.test_home_dir)
         # BZR_HOME overrides everything we want to test so unset it.
-        del os.environ['BZR_HOME']
+        self.overrideEnv('BZR_HOME', None)
 
     def test_xdg_config_dir_exists(self):
         """When ~/.config/bazaar exists, use it as the config dir."""
@@ -454,7 +454,7 @@
     def test_xdg_config_home(self):
         """When XDG_CONFIG_HOME is set, use it."""
         xdgconfigdir = osutils.pathjoin(self.test_home_dir, 'xdgconfig')
-        os.environ['XDG_CONFIG_HOME'] = xdgconfigdir
+        self.overrideEnv('XDG_CONFIG_HOME', xdgconfigdir)
         newdir = osutils.pathjoin(xdgconfigdir, 'bazaar')
         os.makedirs(newdir)
         self.assertEqual(config.config_dir(), newdir)
@@ -1308,7 +1308,7 @@
         self.assertEqual('bzr', my_config.get_bzr_remote_path())
         my_config.set_user_option('bzr_remote_path', '/path-bzr')
         self.assertEqual('/path-bzr', my_config.get_bzr_remote_path())
-        os.environ['BZR_REMOTE_PATH'] = '/environ-bzr'
+        self.overrideEnv('BZR_REMOTE_PATH', '/environ-bzr')
         self.assertEqual('/environ-bzr', my_config.get_bzr_remote_path())
 
 
@@ -1360,7 +1360,7 @@
         self.assertEqual("John", my_config._get_user_id())
 
     def test_BZR_EMAIL_OVERRIDES(self):
-        os.environ['BZR_EMAIL'] = "Robert Collins <robertc@example.org>"
+        self.overrideEnv('BZR_EMAIL', "Robert Collins <robertc@example.org>")
         branch = FakeBranch()
         my_config = config.BranchConfig(branch)
         self.assertEqual("Robert Collins <robertc@example.org>",

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2010-11-10 11:15:50 +0000
+++ bzrlib/tests/test_conflicts.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -197,11 +197,6 @@
         self.run_script(self.preamble)
 
 
-class TestResolveTextConflicts(TestResolveConflicts):
-    # TBC
-    pass
-
-
 def mirror_scenarios(base_scenarios):
     """Return a list of mirrored scenarios.
 
@@ -372,6 +367,50 @@
         check_other()
 
 
+class TestResolveTextConflicts(TestParametrizedResolveConflicts):
+
+    _conflict_type = conflicts.TextConflict
+
+    # Set by the scenarios
+    # path and file-id for the file involved in the conflict
+    _path = None
+    _file_id = None
+
+    scenarios = mirror_scenarios(
+        [
+            # File modified/deleted
+            (dict(_base_actions='create_file',
+                  _path='file', _file_id='file-id'),
+             ('filed_modified_A',
+              dict(actions='modify_file_A', check='file_has_content_A')),
+             ('file_modified_B',
+              dict(actions='modify_file_B', check='file_has_content_B')),),
+            ])
+
+    def do_create_file(self):
+        return [('add', ('file', 'file-id', 'file', 'trunk content\n'))]
+
+    def do_modify_file_A(self):
+        return [('modify', ('file-id', 'trunk content\nfeature A\n'))]
+
+    def do_modify_file_B(self):
+        return [('modify', ('file-id', 'trunk content\nfeature B\n'))]
+
+    def check_file_has_content_A(self):
+        self.assertFileEqual('trunk content\nfeature A\n', 'branch/file')
+
+    def check_file_has_content_B(self):
+        self.assertFileEqual('trunk content\nfeature B\n', 'branch/file')
+
+    def _get_resolve_path_arg(self, wt, action):
+        return self._path
+
+    def assertTextConflict(self, wt, c):
+        self.assertEqual(self._file_id, c.file_id)
+        self.assertEqual(self._path, c.path)
+    _assert_conflict = assertTextConflict
+
+
 class TestResolveContentsConflict(TestParametrizedResolveConflicts):
 
     _conflict_type = conflicts.ContentsConflict

=== modified file 'bzrlib/tests/test_crash.py'
--- bzrlib/tests/test_crash.py	2010-04-08 04:34:03 +0000
+++ bzrlib/tests/test_crash.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
     def test_apport_report(self):
         crash_dir = osutils.joinpath((self.test_base_dir, 'crash'))
         os.mkdir(crash_dir)
-        os.environ['APPORT_CRASH_DIR'] = crash_dir
+        self.overrideEnv('APPORT_CRASH_DIR', crash_dir)
         self.assertEquals(crash_dir, config.crash_dir())
 
         stderr = StringIO()

=== modified file 'bzrlib/tests/test_diff.py'
--- bzrlib/tests/test_diff.py	2010-05-26 15:58:08 +0000
+++ bzrlib/tests/test_diff.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -144,31 +144,22 @@
         self.check_patch(lines)
 
     def test_external_diff_binary_lang_c(self):
-        old_env = {}
         for lang in ('LANG', 'LC_ALL', 'LANGUAGE'):
-            old_env[lang] = osutils.set_or_unset_env(lang, 'C')
-        try:
-            lines = external_udiff_lines(['\x00foobar\n'], ['foo\x00bar\n'])
-            # Older versions of diffutils say "Binary files", newer
-            # versions just say "Files".
-            self.assertContainsRe(lines[0],
-                                  '(Binary f|F)iles old and new differ\n')
-            self.assertEquals(lines[1:], ['\n'])
-        finally:
-            for lang, old_val in old_env.iteritems():
-                osutils.set_or_unset_env(lang, old_val)
+            self.overrideEnv(lang, 'C')
+        lines = external_udiff_lines(['\x00foobar\n'], ['foo\x00bar\n'])
+        # Older versions of diffutils say "Binary files", newer
+        # versions just say "Files".
+        self.assertContainsRe(lines[0], '(Binary f|F)iles old and new differ\n')
+        self.assertEquals(lines[1:], ['\n'])
 
     def test_no_external_diff(self):
         """Check that NoDiff is raised when diff is not available"""
-        # Use os.environ['PATH'] to make sure no 'diff' command is available
-        orig_path = os.environ['PATH']
-        try:
-            os.environ['PATH'] = ''
-            self.assertRaises(errors.NoDiff, diff.external_diff,
-                              'old', ['boo\n'], 'new', ['goo\n'],
-                              StringIO(), diff_opts=['-u'])
-        finally:
-            os.environ['PATH'] = orig_path
+        # Make sure no 'diff' command is available
+        # XXX: Weird, using None instead of '' breaks the test -- vila 20101216
+        self.overrideEnv('PATH', '')
+        self.assertRaises(errors.NoDiff, diff.external_diff,
+                          'old', ['boo\n'], 'new', ['goo\n'],
+                          StringIO(), diff_opts=['-u'])
 
     def test_internal_diff_default(self):
         # Default internal diff encoding is utf8

=== modified file 'bzrlib/tests/test_dirstate.py'
--- bzrlib/tests/test_dirstate.py	2010-09-13 06:36:59 +0000
+++ bzrlib/tests/test_dirstate.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
     tests,
     )
 from bzrlib.tests import test_osutils
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
 
 
 # TODO:
@@ -44,19 +45,14 @@
 # set_path_id  setting id when state is in memory modified
 
 
-def load_tests(basic_tests, module, loader):
-    suite = loader.suiteClass()
-    dir_reader_tests, remaining_tests = tests.split_suite_by_condition(
-        basic_tests, tests.condition_isinstance(TestCaseWithDirState))
-    tests.multiply_tests(dir_reader_tests,
-                         test_osutils.dir_reader_scenarios(), suite)
-    suite.addTest(remaining_tests)
-    return suite
+load_tests = load_tests_apply_scenarios
 
 
 class TestCaseWithDirState(tests.TestCaseWithTransport):
     """Helper functions for creating DirState objects with various content."""
 
+    scenarios = test_osutils.dir_reader_scenarios()
+
     # Set by load_tests
     _dir_reader_class = None
     _native_to_unicode = None # Not used yet

=== modified file 'bzrlib/tests/test_foreign.py'
--- bzrlib/tests/test_foreign.py	2010-08-02 18:36:31 +0000
+++ bzrlib/tests/test_foreign.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -173,17 +173,19 @@
         super(DummyForeignVcsBranchFormat, self).__init__()
         self._matchingbzrdir = DummyForeignVcsDirFormat()
 
-    def open(self, a_bzrdir, name=None, _found=False):
+    def open(self, a_bzrdir, name=None, _found=False, found_repository=None):
         if not _found:
             raise NotImplementedError
         try:
             transport = a_bzrdir.get_branch_transport(None, name=name)
             control_files = lockable_files.LockableFiles(transport, 'lock',
                                                          lockdir.LockDir)
+            if found_repository is None:
+                found_repository = a_bzrdir.find_repository()
             return DummyForeignVcsBranch(_format=self,
                               _control_files=control_files,
                               a_bzrdir=a_bzrdir,
-                              _repository=a_bzrdir.find_repository())
+                              _repository=found_repository)
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
 

=== modified file 'bzrlib/tests/test_graph.py'
--- bzrlib/tests/test_graph.py	2010-08-15 15:20:14 +0000
+++ bzrlib/tests/test_graph.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1654,6 +1654,14 @@
         self.assertEqual(['D'], sorted(graph_thunk.heads(['D', 'C'])))
         self.assertEqual(['B', 'C'], sorted(graph_thunk.heads(['B', 'C'])))
 
+    def test_add_node(self):
+        d = {('C',):[('A',)], ('B',): [('A',)], ('A',): []}
+        g = _mod_graph.KnownGraph(d)
+        graph_thunk = _mod_graph.GraphThunkIdsToKeys(g)
+        graph_thunk.add_node("D", ["A", "C"])
+        self.assertEqual(['B', 'D'],
+            sorted(graph_thunk.heads(['D', 'B', 'A'])))
+
 
 class TestPendingAncestryResultGetKeys(TestCaseWithMemoryTransport):
     """Tests for bzrlib.graph.PendingAncestryResult."""

=== modified file 'bzrlib/tests/test_groupcompress.py'
--- bzrlib/tests/test_groupcompress.py	2010-09-21 19:30:33 +0000
+++ bzrlib/tests/test_groupcompress.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,19 +30,20 @@
     )
 from bzrlib.osutils import sha_string
 from bzrlib.tests.test__groupcompress import compiled_groupcompress_feature
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize tests for all versions of groupcompress."""
-    to_adapt, result = tests.split_suite_by_condition(
-        standard_tests, tests.condition_isinstance(TestAllGroupCompressors))
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+def group_compress_implementation_scenarios():
     scenarios = [
         ('python', {'compressor': groupcompress.PythonGroupCompressor}),
         ]
     if compiled_groupcompress_feature.available():
         scenarios.append(('C',
             {'compressor': groupcompress.PyrexGroupCompressor}))
-    return tests.multiply_tests(to_adapt, scenarios, result)
+    return scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestGroupCompressor(tests.TestCase):
@@ -66,7 +67,8 @@
 class TestAllGroupCompressors(TestGroupCompressor):
     """Tests for GroupCompressor"""
 
-    compressor = None # Set by multiply_tests
+    scenarios = group_compress_implementation_scenarios()
+    compressor = None # Set by scenario
 
     def test_empty_delta(self):
         compressor = self.compressor()

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2010-11-06 10:55:58 +0000
+++ bzrlib/tests/test_http.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -354,27 +354,27 @@
 
     def test_abs_url(self):
         """Construction of absolute http URLs"""
-        t = self._transport('http://bazaar-vcs.org/bzr/bzr.dev/')
+        t = self._transport('http://example.com/bzr/bzr.dev/')
         eq = self.assertEqualDiff
-        eq(t.abspath('.'), 'http://bazaar-vcs.org/bzr/bzr.dev')
-        eq(t.abspath('foo/bar'), 'http://bazaar-vcs.org/bzr/bzr.dev/foo/bar')
-        eq(t.abspath('.bzr'), 'http://bazaar-vcs.org/bzr/bzr.dev/.bzr')
+        eq(t.abspath('.'), 'http://example.com/bzr/bzr.dev')
+        eq(t.abspath('foo/bar'), 'http://example.com/bzr/bzr.dev/foo/bar')
+        eq(t.abspath('.bzr'), 'http://example.com/bzr/bzr.dev/.bzr')
         eq(t.abspath('.bzr/1//2/./3'),
-           'http://bazaar-vcs.org/bzr/bzr.dev/.bzr/1/2/3')
+           'http://example.com/bzr/bzr.dev/.bzr/1/2/3')
 
     def test_invalid_http_urls(self):
         """Trap invalid construction of urls"""
-        self._transport('http://bazaar-vcs.org/bzr/bzr.dev/')
+        self._transport('http://example.com/bzr/bzr.dev/')
         self.assertRaises(errors.InvalidURL,
                           self._transport,
-                          'http://http://bazaar-vcs.org/bzr/bzr.dev/')
+                          'http://http://example.com/bzr/bzr.dev/')
 
     def test_http_root_urls(self):
         """Construction of URLs from server root"""
-        t = self._transport('http://bzr.ozlabs.org/')
+        t = self._transport('http://example.com/')
         eq = self.assertEqualDiff
         eq(t.abspath('.bzr/tree-version'),
-           'http://bzr.ozlabs.org/.bzr/tree-version')
+           'http://example.com/.bzr/tree-version')
 
     def test_http_impl_urls(self):
         """There are servers which ask for particular clients to connect"""
@@ -1073,19 +1073,6 @@
     Only the urllib implementation is tested here.
     """
 
-    def setUp(self):
-        tests.TestCase.setUp(self)
-        self._old_env = {}
-        self.addCleanup(self._restore_env)
-
-    def _install_env(self, env):
-        for name, value in env.iteritems():
-            self._old_env[name] = osutils.set_or_unset_env(name, value)
-
-    def _restore_env(self):
-        for name, value in self._old_env.iteritems():
-            osutils.set_or_unset_env(name, value)
-
     def _proxied_request(self):
         handler = _urllib2_wrappers.ProxyHandler()
         request = _urllib2_wrappers.Request('GET','http://baz/buzzle')
@@ -1093,13 +1080,13 @@
         return request
 
     def test_empty_user(self):
-        self._install_env({'http_proxy': 'http://bar.com'})
+        self.overrideEnv('http_proxy', 'http://bar.com')
         request = self._proxied_request()
         self.assertFalse(request.headers.has_key('Proxy-authorization'))
 
     def test_invalid_proxy(self):
         """A proxy env variable without scheme"""
-        self._install_env({'http_proxy': 'host:1234'})
+        self.overrideEnv('http_proxy', 'host:1234')
         self.assertRaises(errors.InvalidURL, self._proxied_request)
 
 
@@ -1136,39 +1123,23 @@
             self.no_proxy_host = self.server_host_port
         # The secondary server is the proxy
         self.proxy_url = self.get_secondary_url()
-        self._old_env = {}
 
     def _testing_pycurl(self):
         # TODO: This is duplicated for lots of the classes in this file
         return (features.pycurl.available()
                 and self._transport == PyCurlTransport)
 
-    def _install_env(self, env):
-        for name, value in env.iteritems():
-            self._old_env[name] = osutils.set_or_unset_env(name, value)
-
-    def _restore_env(self):
-        for name, value in self._old_env.iteritems():
-            osutils.set_or_unset_env(name, value)
-
-    def proxied_in_env(self, env):
-        self._install_env(env)
-        t = self.get_readonly_transport()
-        try:
-            self.assertEqual('proxied contents of foo\n', t.get('foo').read())
-        finally:
-            self._restore_env()
-
-    def not_proxied_in_env(self, env):
-        self._install_env(env)
-        t = self.get_readonly_transport()
-        try:
-            self.assertEqual('contents of foo\n', t.get('foo').read())
-        finally:
-            self._restore_env()
+    def assertProxied(self):
+        t = self.get_readonly_transport()
+        self.assertEqual('proxied contents of foo\n', t.get('foo').read())
+
+    def assertNotProxied(self):
+        t = self.get_readonly_transport()
+        self.assertEqual('contents of foo\n', t.get('foo').read())
 
     def test_http_proxy(self):
-        self.proxied_in_env({'http_proxy': self.proxy_url})
+        self.overrideEnv('http_proxy', self.proxy_url)
+        self.assertProxied()
 
     def test_HTTP_PROXY(self):
         if self._testing_pycurl():
@@ -1177,43 +1148,49 @@
             # about. Should we ?)
             raise tests.TestNotApplicable(
                 'pycurl does not check HTTP_PROXY for security reasons')
-        self.proxied_in_env({'HTTP_PROXY': self.proxy_url})
+        self.overrideEnv('HTTP_PROXY', self.proxy_url)
+        self.assertProxied()
 
     def test_all_proxy(self):
-        self.proxied_in_env({'all_proxy': self.proxy_url})
+        self.overrideEnv('all_proxy', self.proxy_url)
+        self.assertProxied()
 
     def test_ALL_PROXY(self):
-        self.proxied_in_env({'ALL_PROXY': self.proxy_url})
+        self.overrideEnv('ALL_PROXY', self.proxy_url)
+        self.assertProxied()
 
     def test_http_proxy_with_no_proxy(self):
-        self.not_proxied_in_env({'http_proxy': self.proxy_url,
-                                 'no_proxy': self.no_proxy_host})
+        self.overrideEnv('no_proxy', self.no_proxy_host)
+        self.overrideEnv('http_proxy', self.proxy_url)
+        self.assertNotProxied()
 
     def test_HTTP_PROXY_with_NO_PROXY(self):
         if self._testing_pycurl():
             raise tests.TestNotApplicable(
                 'pycurl does not check HTTP_PROXY for security reasons')
-        self.not_proxied_in_env({'HTTP_PROXY': self.proxy_url,
-                                 'NO_PROXY': self.no_proxy_host})
+        self.overrideEnv('NO_PROXY', self.no_proxy_host)
+        self.overrideEnv('HTTP_PROXY', self.proxy_url)
+        self.assertNotProxied()
 
     def test_all_proxy_with_no_proxy(self):
-        self.not_proxied_in_env({'all_proxy': self.proxy_url,
-                                 'no_proxy': self.no_proxy_host})
+        self.overrideEnv('no_proxy', self.no_proxy_host)
+        self.overrideEnv('all_proxy', self.proxy_url)
+        self.assertNotProxied()
 
     def test_ALL_PROXY_with_NO_PROXY(self):
-        self.not_proxied_in_env({'ALL_PROXY': self.proxy_url,
-                                 'NO_PROXY': self.no_proxy_host})
+        self.overrideEnv('NO_PROXY', self.no_proxy_host)
+        self.overrideEnv('ALL_PROXY', self.proxy_url)
+        self.assertNotProxied()
 
     def test_http_proxy_without_scheme(self):
+        self.overrideEnv('http_proxy', self.server_host_port)
         if self._testing_pycurl():
             # pycurl *ignores* invalid proxy env variables. If that ever change
             # in the future, this test will fail indicating that pycurl do not
             # ignore anymore such variables.
-            self.not_proxied_in_env({'http_proxy': self.server_host_port})
+            self.assertNotProxied()
         else:
-            self.assertRaises(errors.InvalidURL,
-                              self.proxied_in_env,
-                              {'http_proxy': self.server_host_port})
+            self.assertRaises(errors.InvalidURL, self.assertProxied)
 
 
 class TestRanges(http_utils.TestCaseWithWebserver):
@@ -1707,8 +1684,6 @@
 
     def setUp(self):
         super(TestProxyAuth, self).setUp()
-        self._old_env = {}
-        self.addCleanup(self._restore_env)
         # Override the contents to avoid false positives
         self.build_tree_contents([('a', 'not proxied contents of a\n'),
                                   ('b', 'not proxied contents of b\n'),
@@ -1717,17 +1692,9 @@
                                   ])
 
     def get_user_transport(self, user, password):
-        self._install_env({'all_proxy': self.get_user_url(user, password)})
+        self.overrideEnv('all_proxy', self.get_user_url(user, password))
         return TestAuth.get_user_transport(self, user, password)
 
-    def _install_env(self, env):
-        for name, value in env.iteritems():
-            self._old_env[name] = osutils.set_or_unset_env(name, value)
-
-    def _restore_env(self):
-        for name, value in self._old_env.iteritems():
-            osutils.set_or_unset_env(name, value)
-
     def test_empty_pass(self):
         if self._testing_pycurl():
             import pycurl
@@ -1770,7 +1737,7 @@
     def setUp(self):
         super(SmartHTTPTunnellingTest, self).setUp()
         # We use the VFS layer as part of HTTP tunnelling tests.
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         self.transport_readonly_server = http_utils.HTTPServerWithSmarts
         self.http_server = self.get_readonly_server()
 

=== modified file 'bzrlib/tests/test_https_ca_bundle.py'
--- bzrlib/tests/test_https_ca_bundle.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_https_ca_bundle.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,19 +31,9 @@
 class TestGetCAPath(TestCaseInTempDir):
 
     def setUp(self):
-        TestCaseInTempDir.setUp(self)
-        new_env = {
-            'CURL_CA_BUNDLE': None,
-            'PATH': None,
-            }
-        self._old_env = {}
-        self.addCleanup(self._restore)
-        for name, value in new_env.iteritems():
-            self._old_env[name] = osutils.set_or_unset_env(name, None)
-
-    def _restore(self):
-        for name, value in self._old_env.iteritems():
-            osutils.set_or_unset_env(name, value)
+        super(TestGetCAPath, self).setUp()
+        self.overrideEnv('CURL_CA_BUNDLE', None)
+        self.overrideEnv('PATH', None)
 
     def _make_file(self, in_dir='.'):
         fname = os.path.join(in_dir, 'curl-ca-bundle.crt')
@@ -55,7 +45,7 @@
         self.assertEqual('', ca_bundle.get_ca_path(use_cache=False))
 
     def test_env_var(self):
-        osutils.set_or_unset_env('CURL_CA_BUNDLE', 'foo.bar')
+        self.overrideEnv('CURL_CA_BUNDLE', 'foo.bar')
         self._make_file()
         self.assertEqual('foo.bar', ca_bundle.get_ca_path(use_cache=False))
 
@@ -65,6 +55,6 @@
         os.mkdir('foo')
         in_dir = os.path.join(os.getcwd(), 'foo')
         self._make_file(in_dir=in_dir)
-        osutils.set_or_unset_env('PATH', in_dir)
+        self.overrideEnv('PATH', in_dir)
         shouldbe = os.path.join(in_dir, 'curl-ca-bundle.crt')
         self.assertEqual(shouldbe, ca_bundle.get_ca_path(use_cache=False))

=== modified file 'bzrlib/tests/test_import_tariff.py'
--- bzrlib/tests/test_import_tariff.py	2010-10-20 11:16:16 +0000
+++ bzrlib/tests/test_import_tariff.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 
 """Tests for how many modules are loaded in executing various commands."""
 
+import os
 from testtools import content
 
 from bzrlib.plugin import (
@@ -29,12 +30,19 @@
 
 
 class TestImportTariffs(TestCaseWithTransport):
-
     """Check how many modules are loaded for some representative scenarios.
 
     See the Testing Guide in the developer documentation for more explanation.
     """
 
+    def setUp(self):
+        # Preserve some env vars as we want to escape the isolation for them
+        self.preserved_env_vars = {}
+        for name in ('BZR_HOME', 'BZR_PLUGIN_PATH', 'BZR_DISABLE_PLUGINS',
+                     'BZR_PLUGINS_AT', 'HOME'):
+            self.preserved_env_vars[name] = os.environ.get(name)
+        super(TestImportTariffs, self).setUp()
+
     def run_command_check_imports(self, args, forbidden_imports):
         """Run bzr ARGS in a subprocess and check its imports.
 
@@ -50,15 +58,11 @@
         # more likely to always show everything.  And we use the environment
         # variable rather than 'python -v' in the hope it will work even if
         # bzr is frozen and python is not explicitly specified. -- mbp 20100208
-        #
+
         # Normally we want test isolation from the real $HOME but here we
         # explicitly do want to test against things installed there, therefore
         # we pass it through.
-        env_changes = dict(PYTHONVERBOSE='1')
-        for name in ['BZR_HOME', 'BZR_PLUGIN_PATH',
-                     'BZR_DISABLE_PLUGINS', 'BZR_PLUGINS_AT',
-                     'HOME',]:
-            env_changes[name] = self._old_env.get(name)
+        env_changes = dict(PYTHONVERBOSE='1', **self.preserved_env_vars)
         out, err = self.run_bzr_subprocess(args,
             allow_plugins=(not are_plugins_disabled()),
             env_changes=env_changes)

=== modified file 'bzrlib/tests/test_inv.py'
--- bzrlib/tests/test_inv.py	2010-09-15 21:06:23 +0000
+++ bzrlib/tests/test_inv.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,15 +32,15 @@
     TestCaseWithTransport,
     condition_isinstance,
     multiply_tests,
-    split_suite_by_condition,
     )
 from bzrlib.tests.per_workingtree import workingtree_formats
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterise some inventory tests."""
-    to_adapt, result = split_suite_by_condition(standard_tests,
-        condition_isinstance(TestDeltaApplication))
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
+
+
+def delta_application_scenarios():
     scenarios = [
         ('Inventory', {'apply_delta':apply_inventory_Inventory}),
         ]
@@ -63,7 +63,7 @@
             (str(format.__class__.__name__) + ".apply_inventory_delta", {
             'apply_delta':apply_inventory_WT,
             'format':format}))
-    return multiply_tests(to_adapt, scenarios, result)
+    return scenarios
 
 
 def create_texts_for_inv(repo, inv):
@@ -73,6 +73,7 @@
         else:
             lines = []
         repo.texts.add_lines((ie.file_id, ie.revision), [], lines)
+
     
 def apply_inventory_Inventory(self, basis, delta):
     """Apply delta to basis and return the result.
@@ -329,6 +330,8 @@
 
 
 class TestDeltaApplication(TestCaseWithTransport):
+
+    scenarios = delta_application_scenarios()
  
     def get_empty_inventory(self, reference_inv=None):
         """Get an empty inventory.

=== modified file 'bzrlib/tests/test_lock.py'
--- bzrlib/tests/test_lock.py	2009-07-31 16:51:48 +0000
+++ bzrlib/tests/test_lock.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Canonical Ltd
+# Copyright (C) 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,29 +17,26 @@
 """Tests for OS Locks."""
 
 
-
 from bzrlib import (
     debug,
     errors,
     lock,
     tests,
     )
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize tests for all versions of groupcompress."""
-    scenarios = []
-    for name, write_lock, read_lock in lock._lock_classes:
-        scenarios.append((name, {'write_lock': write_lock,
-                                 'read_lock': read_lock}))
-    suite = loader.suiteClass()
-    result = tests.multiply_tests(standard_tests, scenarios, suite)
-    return result
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestOSLock(tests.TestCaseInTempDir):
 
-    # Set by load_tests
+    scenarios = [(
+        name, {
+            'write_lock': write_lock,
+            'read_lock': read_lock})
+        for name, write_lock, read_lock in lock._lock_classes]
+
     read_lock = None
     write_lock = None
 

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2010-11-11 13:45:02 +0000
+++ bzrlib/tests/test_msgeditor.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -157,7 +157,7 @@
             return './fed.sh'
 
     def test_run_editor(self):
-        os.environ['BZR_EDITOR'] = self.make_do_nothing_editor()
+        self.overrideEnv('BZR_EDITOR', self.make_do_nothing_editor())
         self.assertEqual(True, msgeditor._run_editor(''),
                          'Unable to run dummy fake editor')
 
@@ -191,11 +191,11 @@
 "%s" fed.py %%1
 """ % sys.executable)
             f.close()
-            os.environ['BZR_EDITOR'] = 'fed.bat'
+            self.overrideEnv('BZR_EDITOR', 'fed.bat')
         else:
             # [non-win32] make python script executable and set BZR_EDITOR
             os.chmod('fed.py', 0755)
-            os.environ['BZR_EDITOR'] = './fed.py'
+            self.overrideEnv('BZR_EDITOR', './fed.py')
 
     def test_edit_commit_message(self):
         working_tree = self.make_uncommitted_tree()
@@ -230,16 +230,17 @@
         working_tree = self.make_uncommitted_tree()
 
         if sys.platform == 'win32':
-            os.environ['BZR_EDITOR'] = 'cmd.exe /c del'
+            editor = 'cmd.exe /c del'
         else:
-            os.environ['BZR_EDITOR'] = 'rm'
+            editor = 'rm'
+        self.overrideEnv('BZR_EDITOR', editor)
 
         self.assertRaises((IOError, OSError), msgeditor.edit_commit_message, '')
 
     def test__get_editor(self):
-        os.environ['BZR_EDITOR'] = 'bzr_editor'
-        os.environ['VISUAL'] = 'visual'
-        os.environ['EDITOR'] = 'editor'
+        self.overrideEnv('BZR_EDITOR', 'bzr_editor')
+        self.overrideEnv('VISUAL', 'visual')
+        self.overrideEnv('EDITOR', 'editor')
 
         conf = config.GlobalConfig.from_string('editor = config_editor\n',
                                                save=True)
@@ -259,7 +260,7 @@
 
     def test__run_editor_EACCES(self):
         """If running a configured editor raises EACESS, the user is warned."""
-        os.environ['BZR_EDITOR'] = 'eacces.py'
+        self.overrideEnv('BZR_EDITOR', 'eacces.py')
         f = file('eacces.py', 'wb')
         f.write('# Not a real editor')
         f.close()
@@ -267,7 +268,7 @@
         os.chmod('eacces.py', 0)
         # Set $EDITOR so that _run_editor will terminate before trying real
         # editors.
-        os.environ['EDITOR'] = self.make_do_nothing_editor()
+        self.overrideEnv('EDITOR', self.make_do_nothing_editor())
         # Call _run_editor, capturing mutter.warning calls.
         warnings = []
         def warning(*args):
@@ -319,23 +320,20 @@
         self.assertFileEqual('', msgfilename)
 
     def test_unsupported_encoding_commit_message(self):
-        old_env = osutils.set_or_unset_env('LANG', 'C')
-        try:
-            # LANG env variable has no effect on Windows
-            # but some characters anyway cannot be represented
-            # in default user encoding
-            char = probe_bad_non_ascii(osutils.get_user_encoding())
-            if char is None:
-                raise TestSkipped('Cannot find suitable non-ascii character '
-                    'for user_encoding (%s)' % osutils.get_user_encoding())
-
-            self.make_fake_editor(message=char)
-
-            working_tree = self.make_uncommitted_tree()
-            self.assertRaises(errors.BadCommitMessageEncoding,
-                              msgeditor.edit_commit_message, '')
-        finally:
-            osutils.set_or_unset_env('LANG', old_env)
+        self.overrideEnv('LANG', 'C')
+        # LANG env variable has no effect on Windows
+        # but some characters anyway cannot be represented
+        # in default user encoding
+        char = probe_bad_non_ascii(osutils.get_user_encoding())
+        if char is None:
+            raise TestSkipped('Cannot find suitable non-ascii character '
+                'for user_encoding (%s)' % osutils.get_user_encoding())
+
+        self.make_fake_editor(message=char)
+
+        working_tree = self.make_uncommitted_tree()
+        self.assertRaises(errors.BadCommitMessageEncoding,
+                          msgeditor.edit_commit_message, '')
 
     def test_generate_commit_message_template_no_hooks(self):
         commit_obj = commit.Commit()

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/test_osutils.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
     file_utils,
     test__walkdirs_win32,
     )
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
 
 
 class _UTF8DirReaderFeature(tests.Feature):
@@ -96,13 +97,7 @@
     return scenarios
 
 
-def load_tests(basic_tests, module, loader):
-    suite = loader.suiteClass()
-    dir_reader_tests, remaining_tests = tests.split_suite_by_condition(
-        basic_tests, tests.condition_isinstance(TestDirReader))
-    tests.multiply_tests(dir_reader_tests, dir_reader_scenarios(), suite)
-    suite.addTest(remaining_tests)
-    return suite
+load_tests = load_tests_apply_scenarios
 
 
 class TestContainsWhitespace(tests.TestCase):
@@ -1107,6 +1102,8 @@
 
         # rename the 1file to a latin-1 filename
         os.rename("./1file", "\xe8file")
+        if "\xe8file" not in os.listdir("."):
+            self.skip("Lack filesystem that preserves arbitrary bytes")
 
         self._save_platform_info()
         win32utils.winver = None # Avoid the win32 detection code
@@ -1733,6 +1730,8 @@
 
 class TestDirReader(tests.TestCaseInTempDir):
 
+    scenarios = dir_reader_scenarios()
+
     # Set by load_tests
     _dir_reader_class = None
     _native_to_unicode = None
@@ -1900,17 +1899,17 @@
         self.assertIsInstance(concurrency, int)
 
     def test_local_concurrency_environment_variable(self):
-        os.environ['BZR_CONCURRENCY'] = '2'
+        self.overrideEnv('BZR_CONCURRENCY', '2')
         self.assertEqual(2, osutils.local_concurrency(use_cache=False))
-        os.environ['BZR_CONCURRENCY'] = '3'
+        self.overrideEnv('BZR_CONCURRENCY', '3')
         self.assertEqual(3, osutils.local_concurrency(use_cache=False))
-        os.environ['BZR_CONCURRENCY'] = 'foo'
+        self.overrideEnv('BZR_CONCURRENCY', 'foo')
         self.assertEqual(1, osutils.local_concurrency(use_cache=False))
 
     def test_option_concurrency(self):
-        os.environ['BZR_CONCURRENCY'] = '1'
+        self.overrideEnv('BZR_CONCURRENCY', '1')
         self.run_bzr('rocks --concurrency 42')
-        # Command line overrides envrionment variable
+        # Command line overrides environment variable
         self.assertEquals('42', os.environ['BZR_CONCURRENCY'])
         self.assertEquals(42, osutils.local_concurrency(use_cache=False))
 
@@ -1986,19 +1985,19 @@
     def test_defaults_to_BZR_COLUMNS(self):
         # BZR_COLUMNS is set by the test framework
         self.assertNotEqual('12', os.environ['BZR_COLUMNS'])
-        os.environ['BZR_COLUMNS'] = '12'
+        self.overrideEnv('BZR_COLUMNS', '12')
         self.assertEqual(12, osutils.terminal_width())
 
     def test_falls_back_to_COLUMNS(self):
-        del os.environ['BZR_COLUMNS']
+        self.overrideEnv('BZR_COLUMNS', None)
         self.assertNotEqual('42', os.environ['COLUMNS'])
         self.set_fake_tty()
-        os.environ['COLUMNS'] = '42'
+        self.overrideEnv('COLUMNS', '42')
         self.assertEqual(42, osutils.terminal_width())
 
     def test_tty_default_without_columns(self):
-        del os.environ['BZR_COLUMNS']
-        del os.environ['COLUMNS']
+        self.overrideEnv('BZR_COLUMNS', None)
+        self.overrideEnv('COLUMNS', None)
 
         def terminal_size(w, h):
             return 42, 42
@@ -2011,8 +2010,8 @@
         self.assertEqual(42, osutils.terminal_width())
 
     def test_non_tty_default_without_columns(self):
-        del os.environ['BZR_COLUMNS']
-        del os.environ['COLUMNS']
+        self.overrideEnv('BZR_COLUMNS', None)
+        self.overrideEnv('COLUMNS', None)
         self.replace_stdout(None)
         self.assertEqual(None, osutils.terminal_width())
 
@@ -2028,8 +2027,8 @@
         else:
             self.overrideAttr(termios, 'TIOCGWINSZ')
             del termios.TIOCGWINSZ
-        del os.environ['BZR_COLUMNS']
-        del os.environ['COLUMNS']
+        self.overrideEnv('BZR_COLUMNS', None)
+        self.overrideEnv('COLUMNS', None)
         # Whatever the result is, if we don't raise an exception, it's ok.
         osutils.terminal_width()
 
@@ -2071,7 +2070,7 @@
 class TestGetuserUnicode(tests.TestCase):
 
     def test_ascii_user(self):
-        osutils.set_or_unset_env('LOGNAME', 'jrandom')
+        self.overrideEnv('LOGNAME', 'jrandom')
         self.assertEqual(u'jrandom', osutils.getuser_unicode())
 
     def test_unicode_user(self):
@@ -2083,9 +2082,9 @@
                 % (osutils.get_user_encoding(),))
         uni_username = u'jrandom' + uni_val
         encoded_username = uni_username.encode(ue)
-        osutils.set_or_unset_env('LOGNAME', encoded_username)
+        self.overrideEnv('LOGNAME', encoded_username)
         self.assertEqual(uni_username, osutils.getuser_unicode())
-        osutils.set_or_unset_env('LOGNAME', u'jrandom\xb6'.encode(ue))
+        self.overrideEnv('LOGNAME', u'jrandom\xb6'.encode(ue))
         self.assertEqual(u'jrandom\xb6', osutils.getuser_unicode())
 
 class TestBackupNames(tests.TestCase):

=== modified file 'bzrlib/tests/test_osutils_encodings.py'
--- bzrlib/tests/test_osutils_encodings.py	2010-06-29 16:21:13 +0000
+++ bzrlib/tests/test_osutils_encodings.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -171,8 +171,6 @@
     def setUp(self):
         TestCase.setUp(self)
         self.overrideAttr(locale, 'getpreferredencoding')
-        self.addCleanup(osutils.set_or_unset_env,
-                        'LANG', os.environ.get('LANG'))
         self.overrideAttr(sys, 'stderr', StringIOWrapper())
 
     def test_get_user_encoding(self):
@@ -181,7 +179,8 @@
 
         locale.getpreferredencoding = f
         fake_codec.add('user_encoding')
-        self.assertEquals('user_encoding', osutils.get_user_encoding(use_cache=False))
+        self.assertEquals('user_encoding',
+                          osutils.get_user_encoding(use_cache=False))
         self.assertEquals('', sys.stderr.getvalue())
 
     def test_user_cp0(self):
@@ -216,7 +215,7 @@
             raise locale.Error, 'unsupported locale'
 
         locale.getpreferredencoding = f
-        os.environ['LANG'] = 'BOGUS'
+        self.overrideEnv('LANG', 'BOGUS')
         self.assertEquals('ascii', osutils.get_user_encoding(use_cache=False))
         self.assertEquals('bzr: warning: unsupported locale\n'
                           '  Could not determine what text encoding to use.\n'

=== modified file 'bzrlib/tests/test_plugins.py'
--- bzrlib/tests/test_plugins.py	2010-06-11 08:02:42 +0000
+++ bzrlib/tests/test_plugins.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -656,7 +656,7 @@
                     self.fail('No path to global plugins')
 
     def test_get_standard_plugins_path_env(self):
-        os.environ['BZR_PLUGIN_PATH'] = 'foo/'
+        self.overrideEnv('BZR_PLUGIN_PATH', 'foo/')
         path = plugin.get_standard_plugins_path()
         for directory in path:
             self.assertNotContainsRe(directory, r'\\/$')
@@ -692,7 +692,7 @@
 
     def _set_path(self, *args):
         path = os.pathsep.join(self._list2paths(*args))
-        osutils.set_or_unset_env('BZR_PLUGIN_PATH', path)
+        self.overrideEnv('BZR_PLUGIN_PATH', path)
 
     def check_path(self, expected_dirs, setting_dirs):
         if setting_dirs:
@@ -779,7 +779,7 @@
         self.addCleanup(self._unregister_plugin, 'test_foo')
 
     def test_cannot_import(self):
-        osutils.set_or_unset_env('BZR_DISABLE_PLUGINS', 'test_foo')
+        self.overrideEnv('BZR_DISABLE_PLUGINS', 'test_foo')
         plugin.set_plugins_path(['.'])
         try:
             import bzrlib.plugins.test_foo
@@ -801,7 +801,7 @@
         self.overrideAttr(trace, 'warning', captured_warning)
         # Reset the flag that protect against double loading
         self.overrideAttr(plugin, '_loaded', False)
-        osutils.set_or_unset_env('BZR_DISABLE_PLUGINS', 'test_foo')
+        self.overrideEnv('BZR_DISABLE_PLUGINS', 'test_foo')
         plugin.load_plugins(['.'])
         self.assertPluginUnknown('test_foo')
         # Make sure we don't warn about the plugin ImportError since this has
@@ -859,7 +859,7 @@
         self.assertTestFooLoadedFrom('standard/test_foo')
 
     def test_import(self):
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
         plugin.set_plugins_path(['standard'])
         try:
             import bzrlib.plugins.test_foo
@@ -868,12 +868,12 @@
         self.assertTestFooLoadedFrom('non-standard-dir')
 
     def test_loading(self):
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
         plugin.load_plugins(['standard'])
         self.assertTestFooLoadedFrom('non-standard-dir')
 
     def test_compiled_loaded(self):
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
         plugin.load_plugins(['standard'])
         self.assertTestFooLoadedFrom('non-standard-dir')
         self.assertIsSameRealPath('non-standard-dir/__init__.py',
@@ -896,7 +896,7 @@
         self.create_plugin_package('test_bar', dir='non-standard-dir/test_bar')
         self.addCleanup(self._unregister_plugin_submodule,
                         'test_foo', 'test_bar')
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
         plugin.set_plugins_path(['standard'])
         import bzrlib.plugins.test_foo
         self.assertEqual('bzrlib.plugins.test_foo',
@@ -913,7 +913,7 @@
         self.create_plugin_package('test_bar', dir='another-dir/test_bar')
         self.addCleanup(self._unregister_plugin_submodule,
                         'test_foo', 'test_bar')
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@another-dir')
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@another-dir')
         plugin.set_plugins_path(['standard'])
         import bzrlib.plugins.test_foo
         self.assertEqual('bzrlib.plugins.test_foo',
@@ -928,7 +928,7 @@
         random = 'non-standard-dir/setup.py'
         os.rename(init, random)
         self.addCleanup(os.rename, random, init)
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@non-standard-dir')
         plugin.load_plugins(['standard'])
         self.assertPluginUnknown('test_foo')
 
@@ -942,6 +942,6 @@
 ''' % ('test_foo', plugin_path)
         self.create_plugin('test_foo', source=source,
                            dir=plugin_dir, file_name=plugin_file_name)
-        osutils.set_or_unset_env('BZR_PLUGINS_AT', 'test_foo@%s' % plugin_path)
+        self.overrideEnv('BZR_PLUGINS_AT', 'test_foo@%s' % plugin_path)
         plugin.load_plugins(['standard'])
         self.assertTestFooLoadedFrom(plugin_path)

=== modified file 'bzrlib/tests/test_read_bundle.py'
--- bzrlib/tests/test_read_bundle.py	2010-07-15 12:53:44 +0000
+++ bzrlib/tests/test_read_bundle.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,15 +30,10 @@
 import bzrlib.transport
 from bzrlib.transport.memory import MemoryTransport
 import bzrlib.urlutils
-
-
-def load_tests(standard_tests, module, loader):
-    """Multiply tests for tranport implementations."""
-    transport_tests, remaining_tests = tests.split_suite_by_condition(
-        standard_tests,
-        tests.condition_isinstance(TestReadMergeableBundleFromURL))
-    return tests.multiply_tests(transport_tests, transport_test_permutations(),
-        remaining_tests)
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 def create_bundle_file(test_case):
@@ -64,6 +59,8 @@
 class TestReadMergeableBundleFromURL(TestTransportImplementation):
     """Test that read_bundle works properly across multiple transports"""
 
+    scenarios = transport_test_permutations()
+
     def setUp(self):
         super(TestReadMergeableBundleFromURL, self).setUp()
         self.bundle_name = 'test_bundle'
@@ -72,7 +69,7 @@
         # from the one we want to test, so we must inject a correct transport
         # into possible_transports first).
         self.possible_transports = [self.get_transport(self.bundle_name)]
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         wt = self.create_test_bundle()
 
     def read_mergeable_from_url(self, url):

=== modified file 'bzrlib/tests/test_remote.py'
--- bzrlib/tests/test_remote.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/test_remote.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -62,10 +62,10 @@
 from bzrlib.smart.repository import SmartServerRepositoryGetParentMap
 from bzrlib.tests import (
     condition_isinstance,
-    split_suite_by_condition,
     multiply_tests,
     test_server,
     )
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
 from bzrlib.transport.memory import MemoryTransport
 from bzrlib.transport.remote import (
     RemoteTransport,
@@ -73,18 +73,18 @@
     RemoteTCPTransport,
 )
 
-def load_tests(standard_tests, module, loader):
-    to_adapt, result = split_suite_by_condition(
-        standard_tests, condition_isinstance(BasicRemoteObjectTests))
-    smart_server_version_scenarios = [
+
+load_tests = load_tests_apply_scenarios
+
+
+class BasicRemoteObjectTests(tests.TestCaseWithTransport):
+
+    scenarios = [
         ('HPSS-v2',
-         {'transport_server': test_server.SmartTCPServer_for_testing_v2_only}),
+            {'transport_server': test_server.SmartTCPServer_for_testing_v2_only}),
         ('HPSS-v3',
-         {'transport_server': test_server.SmartTCPServer_for_testing})]
-    return multiply_tests(to_adapt, smart_server_version_scenarios, result)
-
-
-class BasicRemoteObjectTests(tests.TestCaseWithTransport):
+            {'transport_server': test_server.SmartTCPServer_for_testing})]
+
 
     def setUp(self):
         super(BasicRemoteObjectTests, self).setUp()

=== modified file 'bzrlib/tests/test_rules.py'
--- bzrlib/tests/test_rules.py	2010-01-14 15:24:04 +0000
+++ bzrlib/tests/test_rules.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -118,10 +118,10 @@
 
     def setUp(self):
         super(TestRulesPath, self).setUp()
-        os.environ['HOME'] = '/home/bogus'
+        self.overrideEnv('HOME', '/home/bogus')
         if sys.platform == 'win32':
-            os.environ['BZR_HOME'] = \
-                r'C:\Documents and Settings\bogus\Application Data'
+            self.overrideEnv(
+                'BZR_HOME', r'C:\Documents and Settings\bogus\Application Data')
             self.bzr_home = \
                 'C:/Documents and Settings/bogus/Application Data/bazaar/2.0'
         else:

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2010-11-19 23:03:19 +0000
+++ bzrlib/tests/test_selftest.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -3251,10 +3251,8 @@
         class Test(unittest.TestCase):
             def runTest(self):
                 pass
-            addCleanup = None # for when on Python 2.7 with native addCleanup
         result = self.LeakRecordingResult()
         test = Test()
-        self.assertIs(getattr(test, "addCleanup", None), None)
         result.startTestRun()
         test.run(result)
         result.stopTestRun()
@@ -3387,10 +3385,9 @@
         result = tests.ExtendedTestResult(StringIO(), 0, 1)
         post_mortem_calls = []
         self.overrideAttr(pdb, "post_mortem", post_mortem_calls.append)
-        self.addCleanup(osutils.set_or_unset_env, "BZR_TEST_PDB",
-            osutils.set_or_unset_env("BZR_TEST_PDB", None))
+        self.overrideEnv('BZR_TEST_PDB', None)
         result._post_mortem(1)
-        os.environ["BZR_TEST_PDB"] = "on"
+        self.overrideEnv('BZR_TEST_PDB', 'on')
         result._post_mortem(2)
         self.assertEqual([2], post_mortem_calls)
 
@@ -3411,3 +3408,48 @@
                                                 self.verbosity)
         tests.run_suite(suite, runner_class=MyRunner, stream=StringIO())
         self.assertLength(1, calls)
+
+
+class TestEnvironHandling(tests.TestCase):
+
+    def test__captureVar_None_called_twice_leaks(self):
+        self.failIf('MYVAR' in os.environ)
+        self._captureVar('MYVAR', '42')
+        # We need an embedded test to observe the bug
+        class Test(tests.TestCase):
+            def test_me(self):
+                # The first call save the 42 value
+                self._captureVar('MYVAR', None)
+                self.assertEquals(None, os.environ.get('MYVAR'))
+                self.assertEquals('42', self._old_env.get('MYVAR'))
+                # But the second one erases it !
+                self._captureVar('MYVAR', None)
+                self.assertEquals(None, self._old_env.get('MYVAR'))
+        output = StringIO()
+        result = tests.TextTestResult(output, 0, 1)
+        Test('test_me').run(result)
+        if not result.wasStrictlySuccessful():
+            self.fail(output.getvalue())
+        # And we have lost all trace of the original value
+        self.assertEquals(None, os.environ.get('MYVAR'))
+        self.assertEquals(None, self._old_env.get('MYVAR'))
+
+    def test_overrideEnv_None_called_twice_doesnt_leak(self):
+        self.failIf('MYVAR' in os.environ)
+        self.overrideEnv('MYVAR', '42')
+        # We use an embedded test to make sure we fix the _captureVar bug
+        class Test(tests.TestCase):
+            def test_me(self):
+                # The first call save the 42 value
+                self.overrideEnv('MYVAR', None)
+                self.assertEquals(None, os.environ.get('MYVAR'))
+                # Make sure we can call it twice
+                self.overrideEnv('MYVAR', None)
+                self.assertEquals(None, os.environ.get('MYVAR'))
+        output = StringIO()
+        result = tests.TextTestResult(output, 0, 1)
+        Test('test_me').run(result)
+        if not result.wasStrictlySuccessful():
+            self.fail(output.getvalue())
+        # We get our value back
+        self.assertEquals('42', os.environ.get('MYVAR'))

=== modified file 'bzrlib/tests/test_server.py'
--- bzrlib/tests/test_server.py	2010-08-31 08:24:17 +0000
+++ bzrlib/tests/test_server.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -531,8 +531,8 @@
         # Update the client description
         self.clients.pop()
         self.clients.append((request, client_address, t))
-        # Propagate the exception handler since we must use the same one for
-        # connections running in their own threads than TestingTCPServer.
+        # Propagate the exception handler since we must use the same one as
+        # TestingTCPServer for connections running in their own threads.
         t.set_ignored_exceptions(self.ignored_exceptions)
         t.start()
         started.wait()
@@ -634,7 +634,7 @@
                 # server thread, it may happen that it's not blocked or even
                 # not started.
                 pass
-            # We start shutting down the client while the server itself is
+            # We start shutting down the clients while the server itself is
             # shutting down.
             self.server.stop_client_connections()
             # Now we wait for the thread running self.server.serve() to finish

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2010-06-23 08:17:20 +0000
+++ bzrlib/tests/test_sftp_transport.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Robey Pointer <robey@lag.net>
+# Copyright (C) 2005-2011 Robey Pointer <robey@lag.net>
 # Copyright (C) 2005, 2006, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,6 @@
 from bzrlib.osutils import (
     pathjoin,
     lexists,
-    set_or_unset_env,
     )
 from bzrlib.tests import (
     features,
@@ -174,27 +173,21 @@
         """Test that if no 'ssh' is available we get builtin paramiko"""
         from bzrlib.transport import ssh
         # set '.' as the only location in the path, forcing no 'ssh' to exist
-        orig_vendor = ssh._ssh_vendor_manager._cached_ssh_vendor
-        orig_path = set_or_unset_env('PATH', '.')
-        try:
-            # No vendor defined yet, query for one
-            ssh._ssh_vendor_manager.clear_cache()
-            vendor = ssh._get_ssh_vendor()
-            self.assertIsInstance(vendor, ssh.ParamikoVendor)
-        finally:
-            set_or_unset_env('PATH', orig_path)
-            ssh._ssh_vendor_manager._cached_ssh_vendor = orig_vendor
+        self.overrideAttr(ssh, '_ssh_vendor_manager')
+        self.overrideEnv('PATH', '.')
+        ssh._ssh_vendor_manager.clear_cache()
+        vendor = ssh._get_ssh_vendor()
+        self.assertIsInstance(vendor, ssh.ParamikoVendor)
 
     def test_abspath_root_sibling_server(self):
         server = stub_sftp.SFTPSiblingAbsoluteServer()
         server.start_server()
-        try:
-            transport = _mod_transport.get_transport(server.get_url())
-            self.assertFalse(transport.abspath('/').endswith('/~/'))
-            self.assertTrue(transport.abspath('/').endswith('/'))
-            del transport
-        finally:
-            server.stop_server()
+        self.addCleanup(server.stop_server)
+
+        transport = _mod_transport.get_transport(server.get_url())
+        self.assertFalse(transport.abspath('/').endswith('/~/'))
+        self.assertTrue(transport.abspath('/').endswith('/'))
+        del transport
 
 
 class SFTPBranchTest(TestCaseWithSFTPServer):

=== modified file 'bzrlib/tests/test_smart_transport.py'
--- bzrlib/tests/test_smart_transport.py	2010-07-01 15:25:41 +0000
+++ bzrlib/tests/test_smart_transport.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -615,7 +615,7 @@
 
     def setUp(self):
         super(TestSmartServerStreamMedium, self).setUp()
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
 
     def portable_socket_pair(self):
         """Return a pair of TCP sockets connected to each other.
@@ -970,7 +970,7 @@
 
     def test_get_error_unexpected(self):
         """Error reported by server with no specific representation"""
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         class FlakyTransport(object):
             base = 'a_url'
             def external_url(self):
@@ -1077,14 +1077,14 @@
 
     def test_smart_transport_has(self):
         """Checking for file existence over smart."""
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         self.backing_transport.put_bytes("foo", "contents of foo\n")
         self.assertTrue(self.transport.has("foo"))
         self.assertFalse(self.transport.has("non-foo"))
 
     def test_smart_transport_get(self):
         """Read back a file over smart."""
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         self.backing_transport.put_bytes("foo", "contents\nof\nfoo\n")
         fp = self.transport.get("foo")
         self.assertEqual('contents\nof\nfoo\n', fp.read())
@@ -1094,7 +1094,7 @@
         # The path in a raised NoSuchFile exception should be the precise path
         # asked for by the client. This gives meaningful and unsurprising errors
         # for users.
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         err = self.assertRaises(
             errors.NoSuchFile, self.transport.get, 'not%20a%20file')
         self.assertSubset([err.path], ['not%20a%20file', './not%20a%20file'])
@@ -1119,7 +1119,7 @@
 
     def test_open_dir(self):
         """Test changing directory"""
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         transport = self.transport
         self.backing_transport.mkdir('toffee')
         self.backing_transport.mkdir('toffee/apple')
@@ -1147,7 +1147,7 @@
 
     def test_mkdir_error_readonly(self):
         """TransportNotPossible should be preserved from the backing transport."""
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         self.start_server(readonly=True)
         self.assertRaises(errors.TransportNotPossible, self.transport.mkdir,
             'foo')
@@ -1261,7 +1261,7 @@
 
     def setUp(self):
         super(SmartServerRequestHandlerTests, self).setUp()
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
 
     def build_handler(self, transport):
         """Returns a handler for the commands in protocol version one."""
@@ -1286,10 +1286,7 @@
         handler = vfs.HasRequest(None, '/')
         # set environment variable after construction to make sure it's
         # examined.
-        # Note that we can safely clobber BZR_NO_SMART_VFS here, because setUp
-        # has called _captureVar, so it will be restored to the right state
-        # afterwards.
-        os.environ['BZR_NO_SMART_VFS'] = ''
+        self.overrideEnv('BZR_NO_SMART_VFS', '')
         self.assertRaises(errors.DisabledMethod, handler.execute)
 
     def test_readonly_exception_becomes_transport_not_possible(self):
@@ -1602,7 +1599,7 @@
         self.assertTrue(self.end_received)
 
     def test_accept_request_and_body_all_at_once(self):
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         mem_transport = memory.MemoryTransport()
         mem_transport.put_bytes('foo', 'abcdefghij')
         out_stream = StringIO()
@@ -1868,7 +1865,7 @@
         self.assertTrue(self.end_received)
 
     def test_accept_request_and_body_all_at_once(self):
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
         mem_transport = memory.MemoryTransport()
         mem_transport.put_bytes('foo', 'abcdefghij')
         out_stream = StringIO()
@@ -3517,7 +3514,7 @@
     def setUp(self):
         super(HTTPTunnellingSmokeTest, self).setUp()
         # We use the VFS layer as part of HTTP tunnelling tests.
-        self._captureVar('BZR_NO_SMART_VFS', None)
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
 
     def test_smart_http_medium_request_accept_bytes(self):
         medium = FakeHTTPMedium()

=== modified file 'bzrlib/tests/test_test_server.py'
--- bzrlib/tests/test_test_server.py	2010-06-30 16:24:01 +0000
+++ bzrlib/tests/test_test_server.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,18 +24,10 @@
     tests,
     )
 from bzrlib.tests import test_server
-
-
-def load_tests(basic_tests, module, loader):
-    suite = loader.suiteClass()
-    server_tests, remaining_tests = tests.split_suite_by_condition(
-        basic_tests, tests.condition_isinstance(TestTCPServerInAThread))
-    server_scenarios = [ (name, {'server_class': getattr(test_server, name)})
-                         for name in
-                         ('TestingTCPServer', 'TestingThreadingTCPServer')]
-    tests.multiply_tests(server_tests, server_scenarios, suite)
-    suite.addTest(remaining_tests)
-    return suite
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestThreadWithException(tests.TestCase):
@@ -129,6 +121,11 @@
 
 class TestTCPServerInAThread(tests.TestCase):
 
+    scenarios = [ 
+        (name, {'server_class': getattr(test_server, name)})
+        for name in
+        ('TestingTCPServer', 'TestingThreadingTCPServer')]
+
     # Set by load_tests()
     server_class = None
 

=== modified file 'bzrlib/tests/test_timestamp.py'
--- bzrlib/tests/test_timestamp.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_timestamp.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,10 +14,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+import random
+import time
+
+
 from bzrlib import (
     tests,
     timestamp,
     )
+from bzrlib.osutils import local_time_offset
+
 
 class TestPatchHeader(tests.TestCase):
 
@@ -52,3 +58,38 @@
         # offset of three minutes
         self.assertEqual((1173193459, +3 * 60),
             timestamp.parse_patch_date('2007-03-06 15:07:19 +0003'))
+
+
+class UnpackHighresDateTests(tests.TestCase):
+
+    def test_unpack_highres_date(self):
+        self.assertEquals(
+            (1120153132.3508501, -18000),
+            timestamp.unpack_highres_date('Thu 2005-06-30 12:38:52.350850105 -0500'))
+        self.assertEquals(
+            (1120153132.3508501, 0),
+            timestamp.unpack_highres_date('Thu 2005-06-30 17:38:52.350850105 +0000'))
+        self.assertEquals(
+            (1120153132.3508501, 7200),
+            timestamp.unpack_highres_date('Thu 2005-06-30 19:38:52.350850105 +0200'))
+        self.assertEquals(
+            (1152428738.867522, 19800),
+            timestamp.unpack_highres_date('Sun 2006-07-09 12:35:38.867522001 +0530'))
+
+    def test_random(self):
+        t = time.time()
+        o = local_time_offset()
+        t2, o2 = timestamp.unpack_highres_date(timestamp.format_highres_date(t, o))
+        self.assertEquals(t, t2)
+        self.assertEquals(o, o2)
+        t -= 24*3600*365*2 # Start 2 years ago
+        o = -12*3600
+        for count in xrange(500):
+            t += random.random()*24*3600*30
+            o = ((o/3600 + 13) % 25 - 12)*3600 # Add 1 wrap around from [-12, 12]
+            date = timestamp.format_highres_date(t, o)
+            t2, o2 = timestamp.unpack_highres_date(date)
+            self.assertEquals(t, t2,
+                'Failed on date %r, %s,%s diff:%s' % (date, t, o, t2-t))
+            self.assertEquals(o, o2,
+                'Failed on date %r, %s,%s diff:%s' % (date, t, o, t2-t))

=== modified file 'bzrlib/tests/test_trace.py'
--- bzrlib/tests/test_trace.py	2010-10-11 09:53:16 +0000
+++ bzrlib/tests/test_trace.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -301,9 +301,7 @@
         # set up.
         self.overrideAttr(sys, 'stderr', StringIO())
         # Set the log file to something that cannot exist
-        # FIXME: A bit dangerous: we are not in an isolated dir here -- vilajam
-        # 20100125
-        os.environ['BZR_LOG'] = os.getcwd() + '/no-dir/bzr.log'
+        self.overrideEnv('BZR_LOG', os.getcwd() + '/no-dir/bzr.log')
         self.overrideAttr(trace, '_bzr_log_filename')
         logf = trace._open_bzr_log()
         self.assertIs(None, logf)

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2010-10-08 07:17:16 +0000
+++ bzrlib/tests/test_transport.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -967,7 +967,7 @@
             bzr_remote_path = sys.executable + ' ' + self.get_bzr_path()
         else:
             bzr_remote_path = self.get_bzr_path()
-        os.environ['BZR_REMOTE_PATH'] = bzr_remote_path
+        self.overrideEnv('BZR_REMOTE_PATH', bzr_remote_path)
 
         # Access the branch via a bzr+ssh URL.  The BZR_REMOTE_PATH environment
         # variable is used to tell bzr what command to run on the remote end.

=== modified file 'bzrlib/tests/test_ui.py'
--- bzrlib/tests/test_ui.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/test_ui.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -158,7 +158,7 @@
     def test_text_factory_prompts_and_clears(self):
         # a get_boolean call should clear the pb before prompting
         out = test_progress._TTYStringIO()
-        os.environ['TERM'] = 'xterm'
+        self.overrideEnv('TERM', 'xterm')
         factory = _mod_ui_text.TextUIFactory(
             stdin=tests.StringIOWrapper("yada\ny\n"),
             stdout=out, stderr=out)
@@ -226,7 +226,7 @@
             pb.finished()
 
     def test_quietness(self):
-        os.environ['BZR_PROGRESS_BAR'] = 'text'
+        self.overrideEnv('BZR_PROGRESS_BAR', 'text')
         ui_factory = _mod_ui_text.TextUIFactory(None,
             test_progress._TTYStringIO(),
             test_progress._TTYStringIO())
@@ -313,12 +313,8 @@
             # however, it can still be forced on
             (FileStringIO, 'dumb', 'text', _mod_ui_text.TextProgressView),
             ):
-            os.environ['TERM'] = term
-            if pb is None:
-                if 'BZR_PROGRESS_BAR' in os.environ:
-                    del os.environ['BZR_PROGRESS_BAR']
-            else:
-                os.environ['BZR_PROGRESS_BAR'] = pb
+            self.overrideEnv('TERM', term)
+            self.overrideEnv('BZR_PROGRESS_BAR', pb)
             stdin = file_class('')
             stderr = file_class()
             stdout = file_class()
@@ -335,10 +331,7 @@
         stderr = test_progress._NonTTYStringIO()
         stdout = test_progress._NonTTYStringIO()
         for term_type in ['dumb', None, 'xterm']:
-            if term_type is None:
-                del os.environ['TERM']
-            else:
-                os.environ['TERM'] = term_type
+            self.overrideEnv('TERM', term_type)
             uif = _mod_ui.make_ui_for_terminal(stdin, stdout, stderr)
             self.assertIsInstance(uif, _mod_ui_text.TextUIFactory,
                 'TERM=%r' % (term_type,))

=== modified file 'bzrlib/tests/test_upgrade.py'
--- bzrlib/tests/test_upgrade.py	2010-07-29 11:17:57 +0000
+++ bzrlib/tests/test_upgrade.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,32 +22,24 @@
 # TODO queue for upgrade:
 # test the error message when upgrading an unknown BzrDir format.
 
-import base64
-import os
-import sys
-
 from bzrlib import (
-    branch as _mod_branch,
+    branch,
     bzrdir,
-    progress,
     repository,
-    transport,
+    tests,
+    upgrade,
     workingtree,
     workingtree_4,
     )
-import bzrlib.branch
-from bzrlib.branch import Branch
-from bzrlib.tests import TestCaseWithTransport
-from bzrlib.upgrade import upgrade
-
-
-class TestUpgrade(TestCaseWithTransport):
+
+
+class TestUpgrade(tests.TestCaseWithTransport):
 
     def test_upgrade_simple(self):
         """Upgrade simple v0.0.4 format to latest format"""
         eq = self.assertEquals
         self.build_tree_contents(_upgrade1_template)
-        upgrade(u'.')
+        upgrade.upgrade(u'.')
         control = bzrdir.BzrDir.open('.')
         b = control.open_branch()
         # tsk, peeking under the covers.
@@ -74,7 +66,7 @@
             rt.unlock()
         # check a backup was made:
         backup_dir = 'backup.bzr.~1~'
-        t = transport.get_transport(b.base)
+        t = self.get_transport('.')
         t.stat(backup_dir)
         t.stat(backup_dir + '/README')
         t.stat(backup_dir + '/branch-format')
@@ -108,8 +100,8 @@
         its contents."""
         eq = self.assertEquals
         self.build_tree_contents(_ghost_template)
-        upgrade(u'.')
-        b = Branch.open(u'.')
+        upgrade.upgrade(u'.')
+        b = branch.Branch.open(u'.')
         revision_id = b.revision_history()[1]
         rev = b.repository.get_revision(revision_id)
         eq(len(rev.parent_ids), 2)
@@ -117,13 +109,13 @@
 
     def test_upgrade_makes_dir_weaves(self):
         self.build_tree_contents(_upgrade_dir_template)
-        old_repodir = bzrlib.bzrdir.BzrDir.open_unsupported('.')
+        old_repodir = bzrdir.BzrDir.open_unsupported('.')
         old_repo_format = old_repodir.open_repository()._format
-        upgrade('.')
+        upgrade.upgrade('.')
         # this is the path to the literal file. As format changes
         # occur it needs to be updated. FIXME: ask the store for the
         # path.
-        repo = bzrlib.repository.Repository.open('.')
+        repo = repository.Repository.open('.')
         # it should have changed the format
         self.assertNotEqual(old_repo_format.__class__, repo._format.__class__)
         # and we should be able to read the names for the file id
@@ -137,7 +129,7 @@
 
     def test_upgrade_to_meta_sets_workingtree_last_revision(self):
         self.build_tree_contents(_upgrade_dir_template)
-        upgrade('.', bzrdir.BzrDirMetaFormat1())
+        upgrade.upgrade('.', bzrdir.BzrDirMetaFormat1())
         tree = workingtree.WorkingTree.open('.')
         self.assertEqual([tree.branch.revision_history()[-1]],
             tree.get_parent_ids())
@@ -146,15 +138,15 @@
         # Some format6 branches do not have checkout files. Upgrading
         # such a branch to metadir must not setup a working tree.
         self.build_tree_contents(_upgrade1_template)
-        upgrade('.', bzrdir.BzrDirFormat6())
-        t = transport.get_transport('.')
+        upgrade.upgrade('.', bzrdir.BzrDirFormat6())
+        t = self.get_transport('.')
         t.delete_multi(['.bzr/pending-merges', '.bzr/inventory'])
         self.assertFalse(t.has('.bzr/stat-cache'))
         # XXX: upgrade fails if a backup.bzr is already present
         # -- David Allouche 2006-08-11
         t.delete_tree('backup.bzr.~1~')
         # At this point, we have a format6 branch without checkout files.
-        upgrade('.', bzrdir.BzrDirMetaFormat1())
+        upgrade.upgrade('.', bzrdir.BzrDirMetaFormat1())
         # The upgrade should not have set up a working tree.
         control = bzrdir.BzrDir.open('.')
         self.assertFalse(control.has_workingtree())
@@ -162,27 +154,27 @@
         # upgrade has not eaten our data, even if it's a bit redundant with
         # other tests.
         self.failUnless(isinstance(control._format, bzrdir.BzrDirMetaFormat1))
-        branch = control.open_branch()
-        self.assertEquals(branch.revision_history(),
+        b = control.open_branch()
+        self.assertEquals(b.revision_history(),
            ['mbp@sourcefrog.net-20051004035611-176b16534b086b3c',
             'mbp@sourcefrog.net-20051004035756-235f2b7dcdddd8dd'])
 
     def test_upgrade_rich_root(self):
         tree = self.make_branch_and_tree('tree', format='rich-root')
         rev_id = tree.commit('first post')
-        upgrade('tree')
+        upgrade.upgrade('tree')
 
     def test_convert_branch5_branch6(self):
-        branch = self.make_branch('branch', format='knit')
-        branch.set_revision_history(['AB', 'CD'])
-        branch.set_parent('file:///EF')
-        branch.set_bound_location('file:///GH')
-        branch.set_push_location('file:///IJ')
+        b = self.make_branch('branch', format='knit')
+        b.set_revision_history(['AB', 'CD'])
+        b.set_parent('file:///EF')
+        b.set_bound_location('file:///GH')
+        b.set_push_location('file:///IJ')
         target = bzrdir.format_registry.make_bzrdir('dirstate-with-subtree')
-        converter = branch.bzrdir._format.get_converter(target)
-        converter.convert(branch.bzrdir, None)
-        new_branch = _mod_branch.Branch.open(self.get_url('branch'))
-        self.assertIs(new_branch.__class__, _mod_branch.BzrBranch6)
+        converter = b.bzrdir._format.get_converter(target)
+        converter.convert(b.bzrdir, None)
+        new_branch = branch.Branch.open(self.get_url('branch'))
+        self.assertIs(new_branch.__class__, branch.BzrBranch6)
         self.assertEqual('CD', new_branch.last_revision())
         self.assertEqual('file:///EF', new_branch.get_parent())
         self.assertEqual('file:///GH', new_branch.get_bound_location())
@@ -190,21 +182,21 @@
         self.assertEqual('file:///IJ',
             branch_config.get_user_option('push_location'))
 
-        branch2 = self.make_branch('branch2', format='knit')
-        converter = branch2.bzrdir._format.get_converter(target)
-        converter.convert(branch2.bzrdir, None)
-        branch2 = _mod_branch.Branch.open(self.get_url('branch'))
-        self.assertIs(branch2.__class__, _mod_branch.BzrBranch6)
+        b2 = self.make_branch('branch2', format='knit')
+        converter = b2.bzrdir._format.get_converter(target)
+        converter.convert(b2.bzrdir, None)
+        b2 = branch.Branch.open(self.get_url('branch'))
+        self.assertIs(b2.__class__, branch.BzrBranch6)
 
     def test_convert_branch7_branch8(self):
-        branch = self.make_branch('branch', format='1.9')
+        b = self.make_branch('branch', format='1.9')
         target = bzrdir.format_registry.make_bzrdir('1.9')
-        target.set_branch_format(_mod_branch.BzrBranchFormat8())
-        converter = branch.bzrdir._format.get_converter(target)
-        converter.convert(branch.bzrdir, None)
-        branch = _mod_branch.Branch.open(self.get_url('branch'))
-        self.assertIs(branch.__class__, _mod_branch.BzrBranch8)
-        self.assertEqual({}, branch._get_all_reference_info())
+        target.set_branch_format(branch.BzrBranchFormat8())
+        converter = b.bzrdir._format.get_converter(target)
+        converter.convert(b.bzrdir, None)
+        b = branch.Branch.open(self.get_url('branch'))
+        self.assertIs(b.__class__, branch.BzrBranch8)
+        self.assertEqual({}, b._get_all_reference_info())
 
     def test_convert_knit_dirstate_empty(self):
         # test that asking for an upgrade from knit to dirstate works.
@@ -269,7 +261,7 @@
      ('.bzr/README',
       'This is a Bazaar control directory.\n'
       'Do not change any files in this directory.\n'
-      'See http://bazaar-vcs.org/ for more information about Bazaar.\n'),
+      'See http://bazaar.canonical.com/ for more information about Bazaar.\n'),
      ('.bzr/branch-format', 'Bazaar-NG branch, format 0.0.4\n'),
      ('.bzr/revision-history',
       'mbp@sourcefrog.net-20051004035611-176b16534b086b3c\n'
@@ -311,7 +303,7 @@
     ( './.bzr/README',
       'This is a Bazaar control directory.\n'
       'Do not change any files in this directory.\n'
-      'See http://bazaar-vcs.org/ for more information about Bazaar.\n'
+      'See http://bazaar.canonical.com/ for more information about Bazaar.\n'
     ),
     ( './.bzr/branch-format',
         'Bazaar-NG branch, format 0.0.4\n'
@@ -377,7 +369,7 @@
     ( './.bzr/README',
       'This is a Bazaar control directory.\n'
       'Do not change any files in this directory.\n'
-      'See http://bazaar-vcs.org/ for more information about Bazaar.\n'
+      'See http://bazaar.canonical.com/ for more information about Bazaar.\n'
     ),
     ( './.bzr/branch-format',
         'Bazaar-NG branch, format 0.0.4\n'
@@ -423,3 +415,88 @@
     ),
     ( './dir/', ),
 ]
+
+
+class TestSmartUpgrade(tests.TestCaseWithTransport):
+
+    from_format = bzrdir.format_registry.make_bzrdir("pack-0.92")
+    to_format = bzrdir.format_registry.make_bzrdir("2a")
+
+    def make_standalone_branch(self):
+        wt = self.make_branch_and_tree("branch1", format=self.from_format)
+        return wt.bzrdir
+
+    def test_upgrade_standalone_branch(self):
+        control = self.make_standalone_branch()
+        tried, worked, issues = upgrade.smart_upgrade(
+            [control], format=self.to_format)
+        self.assertLength(1, tried)
+        self.assertEqual(tried[0], control)
+        self.assertLength(1, worked)
+        self.assertEqual(worked[0], control)
+        self.assertLength(0, issues)
+        self.failUnlessExists('branch1/backup.bzr.~1~')
+        self.assertEqual(control.open_repository()._format,
+                         self.to_format._repository_format)
+
+    def test_upgrade_standalone_branch_cleanup(self):
+        control = self.make_standalone_branch()
+        tried, worked, issues = upgrade.smart_upgrade(
+            [control], format=self.to_format, clean_up=True)
+        self.assertLength(1, tried)
+        self.assertEqual(tried[0], control)
+        self.assertLength(1, worked)
+        self.assertEqual(worked[0], control)
+        self.assertLength(0, issues)
+        self.failUnlessExists('branch1')
+        self.failUnlessExists('branch1/.bzr')
+        self.failIfExists('branch1/backup.bzr.~1~')
+        self.assertEqual(control.open_repository()._format,
+                         self.to_format._repository_format)
+
+    def make_repo_with_branches(self):
+        repo = self.make_repository('repo', shared=True,
+            format=self.from_format)
+        # Note: self.make_branch() always creates a new repo at the location
+        # so we need to avoid using that here ...
+        b1 = bzrdir.BzrDir.create_branch_convenience("repo/branch1",
+            format=self.from_format)
+        b2 = bzrdir.BzrDir.create_branch_convenience("repo/branch2",
+            format=self.from_format)
+        return repo.bzrdir
+
+    def test_upgrade_repo_with_branches(self):
+        control = self.make_repo_with_branches()
+        tried, worked, issues = upgrade.smart_upgrade(
+            [control], format=self.to_format)
+        self.assertLength(3, tried)
+        self.assertEqual(tried[0], control)
+        self.assertLength(3, worked)
+        self.assertEqual(worked[0], control)
+        self.assertLength(0, issues)
+        self.failUnlessExists('repo/backup.bzr.~1~')
+        self.failUnlessExists('repo/branch1/backup.bzr.~1~')
+        self.failUnlessExists('repo/branch2/backup.bzr.~1~')
+        self.assertEqual(control.open_repository()._format,
+                         self.to_format._repository_format)
+        b1 = branch.Branch.open('repo/branch1')
+        self.assertEqual(b1._format, self.to_format._branch_format)
+
+    def test_upgrade_repo_with_branches_cleanup(self):
+        control = self.make_repo_with_branches()
+        tried, worked, issues = upgrade.smart_upgrade(
+            [control], format=self.to_format, clean_up=True)
+        self.assertLength(3, tried)
+        self.assertEqual(tried[0], control)
+        self.assertLength(3, worked)
+        self.assertEqual(worked[0], control)
+        self.assertLength(0, issues)
+        self.failUnlessExists('repo')
+        self.failUnlessExists('repo/.bzr')
+        self.failIfExists('repo/backup.bzr.~1~')
+        self.failIfExists('repo/branch1/backup.bzr.~1~')
+        self.failIfExists('repo/branch2/backup.bzr.~1~')
+        self.assertEqual(control.open_repository()._format,
+                         self.to_format._repository_format)
+        b1 = branch.Branch.open('repo/branch1')
+        self.assertEqual(b1._format, self.to_format._branch_format)

=== modified file 'bzrlib/tests/test_upgrade_stacked.py'
--- bzrlib/tests/test_upgrade_stacked.py	2009-08-05 02:30:59 +0000
+++ bzrlib/tests/test_upgrade_stacked.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Canonical Ltd
+# Copyright (C) 2008, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,12 +24,35 @@
     tests,
     )
 from bzrlib.upgrade import upgrade
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+
+def upgrade_scenarios():
+    scenario_pairs = [ # old format, new format, model_change
+#        ('knit', 'rich-root', True),
+        ('knit', '1.6', False),
+#        ('pack-0.92', '1.6', False),
+        ('1.6', '1.6.1-rich-root', True),
+        ]
+    scenarios = []
+    for (old_name, new_name, model_change) in scenario_pairs:
+        name = old_name + ', ' + new_name
+        scenarios.append((name,
+            dict(scenario_old_format=old_name,
+                scenario_new_format=new_name,
+                scenario_model_change=model_change)))
+    return scenarios
+
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestStackUpgrade(tests.TestCaseWithTransport):
     # TODO: This should possibly be repeated for all stacking repositories,
     # pairwise by rich/non-rich format; should possibly also try other kinds
     # of upgrades like knit->pack. -- mbp 20080804
+    
+    scenarios = upgrade_scenarios()
 
     def test_stack_upgrade(self):
         """Correct checks when stacked-on repository is upgraded.
@@ -65,25 +88,3 @@
         stacked = bzrdir.BzrDir.open('stacked')
         # And passes check.
         check.check_dwim('stacked', False, True, True)
-
-
-def load_tests(basic_tests, module, loader):
-    """Generate dynamic scenario tests.
-
-    Called by the bzrlib test framework.
-    """
-    scenario_pairs = [ # old format, new format, model_change
-#        ('knit', 'rich-root', True),
-        ('knit', '1.6', False),
-#        ('pack-0.92', '1.6', False),
-        ('1.6', '1.6.1-rich-root', True),
-        ]
-    scenarios = []
-    for (old_name, new_name, model_change) in scenario_pairs:
-        name = old_name + ', ' + new_name
-        scenarios.append((name,
-            dict(scenario_old_format=old_name,
-                scenario_new_format=new_name,
-                scenario_model_change=model_change)))
-    suite = loader.suiteClass()
-    return tests.multiply_tests(basic_tests, scenarios, suite)

=== modified file 'bzrlib/tests/test_win32utils.py'
--- bzrlib/tests/test_win32utils.py	2010-06-22 23:58:34 +0000
+++ bzrlib/tests/test_win32utils.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -120,7 +120,8 @@
             ])
 
     def test_case_insensitive_globbing(self):
-        self.requireFeature(tests.CaseInsCasePresFilenameFeature)
+        if os.path.normcase("AbC") == "AbC":
+            self.skip("Test requires case insensitive globbing function")
         self.build_ascii_tree()
         self._run_testset([
             [[u'A'], [u'A']],
@@ -216,7 +217,7 @@
     def test_appdata_not_using_environment(self):
         # Test that we aren't falling back to the environment
         first = win32utils.get_appdata_location()
-        self._captureVar("APPDATA", None)
+        self.overrideEnv("APPDATA", None)
         self.assertPathsEqual(first, win32utils.get_appdata_location())
 
     def test_appdata_matches_environment(self):
@@ -233,7 +234,7 @@
     def test_local_appdata_not_using_environment(self):
         # Test that we aren't falling back to the environment
         first = win32utils.get_local_appdata_location()
-        self._captureVar("LOCALAPPDATA", None)
+        self.overrideEnv("LOCALAPPDATA", None)
         self.assertPathsEqual(first, win32utils.get_local_appdata_location())
 
     def test_local_appdata_matches_environment(self):
@@ -326,7 +327,8 @@
             single_quotes_allowed=True)
 
     def test_case_insensitive_globs(self):
-        self.requireFeature(tests.CaseInsCasePresFilenameFeature)
+        if os.path.normcase("AbC") == "AbC":
+            self.skip("Test requires case insensitive globbing function")
         self.build_tree(['a/', 'a/b.c', 'a/c.c', 'a/c.h'])
         self.assertCommandLine([u'A/b.c'], 'A/B*')
 

=== modified file 'bzrlib/timestamp.py'
--- bzrlib/timestamp.py	2009-03-23 14:59:43 +0000
+++ bzrlib/timestamp.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007 Canonical Ltd
+# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -72,34 +72,6 @@
     :param date: A date formated by format_highres_date
     :type date: string
 
-    >>> import time, random
-    >>> unpack_highres_date('Thu 2005-06-30 12:38:52.350850105 -0500')
-    (1120153132.3508501, -18000)
-    >>> unpack_highres_date('Thu 2005-06-30 17:38:52.350850105 +0000')
-    (1120153132.3508501, 0)
-    >>> unpack_highres_date('Thu 2005-06-30 19:38:52.350850105 +0200')
-    (1120153132.3508501, 7200)
-    >>> unpack_highres_date('Sun 2006-07-09 12:35:38.867522001 +0530')
-    (1152428738.867522, 19800)
-    >>> from bzrlib.osutils import local_time_offset
-    >>> t = time.time()
-    >>> o = local_time_offset()
-    >>> t2, o2 = unpack_highres_date(format_highres_date(t, o))
-    >>> t == t2
-    True
-    >>> o == o2
-    True
-    >>> t -= 24*3600*365*2 # Start 2 years ago
-    >>> o = -12*3600
-    >>> for count in xrange(500):
-    ...   t += random.random()*24*3600*30
-    ...   o = ((o/3600 + 13) % 25 - 12)*3600 # Add 1 wrap around from [-12, 12]
-    ...   date = format_highres_date(t, o)
-    ...   t2, o2 = unpack_highres_date(date)
-    ...   if t != t2 or o != o2:
-    ...      print 'Failed on date %r, %s,%s diff:%s' % (date, t, o, t2-t)
-    ...      break
-
     """
     # Weekday parsing is locale sensitive, so drop the weekday
     space_loc = date.find(' ')

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2010-11-19 16:28:25 +0000
+++ bzrlib/transform.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@
             self._new_root = self.trans_id_tree_file_id(root_id)
         else:
             self._new_root = None
-        # Indictor of whether the transform has been applied
+        # Indicator of whether the transform has been applied
         self._done = False
         # A progress bar
         self._pb = pb

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2010-10-18 10:01:47 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -110,15 +110,19 @@
         self.report_activity(len(s), 'read')
         return s
 
-    def readline(self):
-        # This should be readline(self, size=-1), but httplib in python 2.4 and
-        #  2.5 defines a SSLFile wrapper whose readline method lacks the size
-        #  parameter.  So until we drop support for 2.4 and 2.5 and since we
-        #  don't *need* the size parameter we'll stay with readline(self)
-        #  --  vila 20090209
-        s = self.filesock.readline()
-        self.report_activity(len(s), 'read')
-        return s
+    # httplib in python 2.4 and 2.5 defines a SSLFile wrapper whose readline
+    # method lacks the size parameter. python2.6 provides a proper ssl socket
+    # and added it. python2.7 uses it, forcing us to provide it.
+    if sys.version_info < (2, 6):
+        def readline(self):
+            s = self.filesock.readline()
+            self.report_activity(len(s), 'read')
+            return s
+    else:
+        def readline(self, size=-1):
+            s = self.filesock.readline(size)
+            self.report_activity(len(s), 'read')
+            return s
 
     def __getattr__(self, name):
         return getattr(self.filesock, name)

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2010-04-21 11:27:04 +0000
+++ bzrlib/upgrade.py	2011-01-10 22:20:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2005, 2006, 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,20 +17,41 @@
 """bzr upgrade logic."""
 
 
+from bzrlib import (
+    errors,
+    osutils,
+    repository,
+    trace,
+    ui,
+    )
 from bzrlib.bzrdir import BzrDir, format_registry
-import bzrlib.errors as errors
 from bzrlib.remote import RemoteBzrDir
-import bzrlib.ui as ui
 
 
 class Convert(object):
 
-    def __init__(self, url, format=None):
+    def __init__(self, url=None, format=None, control_dir=None):
+        """Convert a Bazaar control directory to a given format.
+
+        Either the url or control_dir parameter must be given.
+
+        :param url: the URL of the control directory or None if the
+          control_dir is explicitly given instead
+        :param format: the format to convert to or None for the default
+        :param control_dir: the control directory or None if it is
+          specified via the URL parameter instead
+        """
         self.format = format
-        self.bzrdir = BzrDir.open_unsupported(url)
         # XXX: Change to cleanup
         warning_id = 'cross_format_fetch'
         saved_warning = warning_id in ui.ui_factory.suppressed_warnings
+        if url is None and control_dir is None:
+            raise AssertionError(
+                "either the url or control_dir parameter must be set.")
+        if control_dir is not None:
+            self.bzrdir = control_dir
+        else:
+            self.bzrdir = BzrDir.open_unsupported(url)
         if isinstance(self.bzrdir, RemoteBzrDir):
             self.bzrdir._ensure_real()
             self.bzrdir = self.bzrdir._real_bzrdir
@@ -48,9 +69,9 @@
         try:
             branch = self.bzrdir.open_branch()
             if branch.user_url != self.bzrdir.user_url:
-                ui.ui_factory.note("This is a checkout. The branch (%s) needs to be "
-                             "upgraded separately." %
-                             branch.user_url)
+                ui.ui_factory.note(
+                    'This is a checkout. The branch (%s) needs to be upgraded'
+                    ' separately.' % (branch.user_url,))
             del branch
         except (errors.NotBranchError, errors.IncompatibleRepositories):
             # might not be a format we can open without upgrading; see e.g.
@@ -76,13 +97,203 @@
         self.bzrdir.check_conversion_target(format)
         ui.ui_factory.note('starting upgrade of %s' % self.transport.base)
 
-        self.bzrdir.backup_bzrdir()
+        self.backup_oldpath, self.backup_newpath = self.bzrdir.backup_bzrdir()
         while self.bzrdir.needs_format_conversion(format):
             converter = self.bzrdir._format.get_converter(format)
             self.bzrdir = converter.convert(self.bzrdir, None)
-        ui.ui_factory.note("finished")
-
-
-def upgrade(url, format=None):
-    """Upgrade to format, or the default bzrdir format if not supplied."""
-    Convert(url, format)
+        ui.ui_factory.note('finished')
+
+    def clean_up(self):
+        """Clean-up after a conversion.
+
+        This removes the backup.bzr directory.
+        """
+        transport = self.transport
+        backup_relpath = transport.relpath(self.backup_newpath)
+        child_pb = ui.ui_factory.nested_progress_bar()
+        child_pb.update('Deleting backup.bzr')
+        try:
+            transport.delete_tree(backup_relpath)
+        finally:
+            child_pb.finished()
+
+
+def upgrade(url, format=None, clean_up=False, dry_run=False):
+    """Upgrade locations to format.
+ 
+    This routine wraps the smart_upgrade() routine with a nicer UI.
+    In particular, it ensures all URLs can be opened before starting
+    and reports a summary at the end if more than one upgrade was attempted.
+    This routine is useful for command line tools. Other bzrlib clients
+    probably ought to use smart_upgrade() instead.
+
+    :param url: a URL of the locations to upgrade.
+    :param format: the format to convert to or None for the best default
+    :param clean-up: if True, the backup.bzr directory is removed if the
+      upgrade succeeded for a given repo/branch/tree
+    :param dry_run: show what would happen but don't actually do any upgrades
+    :return: the list of exceptions encountered
+    """
+    control_dirs = [BzrDir.open_unsupported(url)]
+    attempted, succeeded, exceptions = smart_upgrade(control_dirs,
+        format, clean_up=clean_up, dry_run=dry_run)
+    if len(attempted) > 1:
+        attempted_count = len(attempted)
+        succeeded_count = len(succeeded)
+        failed_count = attempted_count - succeeded_count
+        ui.ui_factory.note(
+            '\nSUMMARY: %d upgrades attempted, %d succeeded, %d failed'
+            % (attempted_count, succeeded_count, failed_count))
+    return exceptions
+
+
+def smart_upgrade(control_dirs, format, clean_up=False,
+    dry_run=False):
+    """Convert control directories to a new format intelligently.
+
+    If the control directory is a shared repository, dependent branches
+    are also converted provided the repository converted successfully.
+    If the conversion of a branch fails, remaining branches are still tried.
+
+    :param control_dirs: the BzrDirs to upgrade
+    :param format: the format to convert to or None for the best default
+    :param clean_up: if True, the backup.bzr directory is removed if the
+      upgrade succeeded for a given repo/branch/tree
+    :param dry_run: show what would happen but don't actually do any upgrades
+    :return: attempted-control-dirs, succeeded-control-dirs, exceptions
+    """
+    all_attempted = []
+    all_succeeded = []
+    all_exceptions = []
+    for control_dir in control_dirs:
+        attempted, succeeded, exceptions = _smart_upgrade_one(control_dir,
+            format, clean_up=clean_up, dry_run=dry_run)
+        all_attempted.extend(attempted)
+        all_succeeded.extend(succeeded)
+        all_exceptions.extend(exceptions)
+    return all_attempted, all_succeeded, all_exceptions
+
+
+def _smart_upgrade_one(control_dir, format, clean_up=False,
+    dry_run=False):
+    """Convert a control directory to a new format intelligently.
+
+    See smart_upgrade for parameter details.
+    """
+    # If the URL is a shared repository, find the dependent branches
+    dependents = None
+    try:
+        repo = control_dir.open_repository()
+    except errors.NoRepositoryPresent:
+        # A branch or checkout using a shared repository higher up
+        pass
+    else:
+        # The URL is a repository. If it successfully upgrades,
+        # then upgrade the dependent branches as well.
+        if repo.is_shared():
+            dependents = repo.find_branches(using=True)
+
+    # Do the conversions
+    attempted = [control_dir]
+    succeeded, exceptions = _convert_items([control_dir], format, clean_up,
+                                           dry_run)
+    if succeeded and dependents:
+        ui.ui_factory.note('Found %d dependent branches - upgrading ...'
+                           % (len(dependents),))
+        # Convert dependent branches
+        branch_cdirs = [b.bzrdir for b in dependents]
+        successes, problems = _convert_items(branch_cdirs, format, clean_up,
+            dry_run, label="branch")
+        attempted.extend(branch_cdirs)
+        succeeded.extend(successes)
+        exceptions.extend(problems)
+
+    # Return the result
+    return attempted, succeeded, exceptions
+
+# FIXME: There are several problems below:
+# - RemoteRepository doesn't support _unsupported (really ?)
+# - raising AssertionError is rude and may not be necessary
+# - no tests
+# - the only caller uses only the label
+def _get_object_and_label(control_dir):
+    """Return the primary object and type label for a control directory.
+
+    :return: object, label where
+      object is a Branch, Repository or WorkingTree and
+      label is one of:
+        branch            - a branch
+        repository        - a repository
+        tree              - a lightweight checkout
+    """
+    try:
+        try:
+            br = control_dir.open_branch(unsupported=True,
+                                         ignore_fallbacks=True)
+        except NotImplementedError:
+            # RemoteRepository doesn't support the unsupported parameter
+            br = control_dir.open_branch(ignore_fallbacks=True)
+    except errors.NotBranchError:
+        pass
+    else:
+        return br, "branch"
+    try:
+        repo = control_dir.open_repository()
+    except errors.NoRepositoryPresent:
+        pass
+    else:
+        return repo, "repository"
+    try:
+        wt = control_dir.open_workingtree()
+    except (errors.NoWorkingTree, errors.NotLocalUrl):
+        pass
+    else:
+        return wt, "tree"
+    raise AssertionError("unknown type of control directory %s", control_dir)
+
+
+def _convert_items(items, format, clean_up, dry_run, label=None):
+    """Convert a sequence of control directories to the given format.
+ 
+    :param items: the control directories to upgrade
+    :param format: the format to convert to or None for the best default
+    :param clean-up: if True, the backup.bzr directory is removed if the
+      upgrade succeeded for a given repo/branch/tree
+    :param dry_run: show what would happen but don't actually do any upgrades
+    :param label: the label for these items or None to calculate one
+    :return: items successfully upgraded, exceptions
+    """
+    succeeded = []
+    exceptions = []
+    child_pb = ui.ui_factory.nested_progress_bar()
+    child_pb.update('Upgrading bzrdirs', 0, len(items))
+    for i, control_dir in enumerate(items):
+        # Do the conversion
+        location = control_dir.root_transport.base
+        bzr_object, bzr_label = _get_object_and_label(control_dir)
+        type_label = label or bzr_label
+        child_pb.update("Upgrading %s" % (type_label), i+1, len(items))
+        ui.ui_factory.note('Upgrading %s %s ...' % (type_label, location,))
+        try:
+            if not dry_run:
+                cv = Convert(control_dir=control_dir, format=format)
+        except Exception, ex:
+            trace.warning('conversion error: %s' % ex)
+            exceptions.append(ex)
+            continue
+
+        # Do any required post processing
+        succeeded.append(control_dir)
+        if clean_up:
+            try:
+                ui.ui_factory.note('Removing backup ...')
+                if not dry_run:
+                    cv.clean_up()
+            except Exception, ex:
+                trace.warning('failed to clean-up %s: %s' % (location, ex))
+                exceptions.append(ex)
+
+    child_pb.finished()
+
+    # Return the result
+    return succeeded, exceptions

=== modified file 'doc/developers/HACKING.txt'
--- doc/developers/HACKING.txt	2010-10-13 04:13:48 +0000
+++ doc/developers/HACKING.txt	2010-11-12 22:43:38 +0000
@@ -511,7 +511,7 @@
 Because Transports work in URLs (as defined earlier), printing the raw URL
 to the user is usually less than optimal. Characters outside the standard
 set are printed as escapes, rather than the real character, and local
-paths would be printed as ``file://`` urls. The function
+paths would be printed as ``file://`` URLs. The function
 ``unescape_for_display`` attempts to unescape a URL, such that anything
 that cannot be printed in the current encoding stays an escaped URL, but
 valid characters are generated where possible.

=== modified file 'doc/developers/authentication-ring.txt'
--- doc/developers/authentication-ring.txt	2009-12-02 20:34:07 +0000
+++ doc/developers/authentication-ring.txt	2010-11-12 22:46:28 +0000
@@ -61,12 +61,12 @@
 This specification describes a way to provide user and passwords to bzr while
 storing them in a relatively safe way.
 
-Note that ssh servers can be configured to use keys instead of (``user``,
+Note that SSH servers can be configured to use keys instead of (``user``,
 ``password``) and, when used with appropriate agents, provide the same kind of
-comfort this specification aims to provide for all other schemes. Since ssh
+comfort this specification aims to provide for all other schemes. Since SSH 
 agents provide a safer way to secure the passwords, this specification is
 restricted to providing ``user`` but does not provide ``password`` when used
-for ssh.
+for SSH.
 
 Authentication definitions
 --------------------------
@@ -77,8 +77,8 @@
 1. user and password
 
 ``FTP`` and ``SFTP`` needs a (``user``, ``password``) to authenticate against a
-``host`` (SFTP can use ssh keys too, but we don't talk about that in this
-specification as ssh agents provide a better solution).
+``host`` (SFTP can use SSH keys too, but we don't talk about that in this
+specification as SSH agents provide a better solution).
 
 2. user, realm and password
 
@@ -115,8 +115,8 @@
 
   * ``path``: can be empty (FTP or SFTP will never use it),
 
-  * ``user``: can be empty (``bzr`` will defaults to python's
-    ``getpass.get_user()`` for FTP, SFTP and ssh),
+  * ``user``: can be empty (``bzr`` will defaults to Python's
+    ``getpass.get_user()`` for FTP, SFTP and SSH),
 
   * ``password``: can be empty (for security reasons, a user may use the
     definitions without storing the passwords but want to be prompted ; or the
@@ -303,7 +303,7 @@
   * source hosting provider declaring sub-domains for each project::
 
         [sfnet domain]
-        # we use sftp, but ssh is the scheme used for authentication
+        # we use SFTP, but SSH is the scheme used for authentication
         scheme=ssh
         # The leading '.' ensures that 'sf.net' alone doesn't match
         host=.sf.net
@@ -347,7 +347,7 @@
 * No assumptions should be made about the clients of this service
   (i.e. Transport is the primary target but plugins must be able to use it as
   well, the definitions used: (``scheme, host, [port,] path``) are general
-  enough to described credentials for ``svn`` servers or LaunchPad xmlrpc
+  enough to described credentials for ``svn`` servers or LaunchPad XML-RPC
   calls).
 
 * Policies regarding default users may be taken into account by the
@@ -361,7 +361,7 @@
   a password.
 
 * As this specification proposes a matching between some credentials
-  definitions and real urls, the implementation provides an optional UI
+  definitions and real URLs, the implementation provides an optional UI
   feedback about which credential definition is used. Using ``-Dauth`` will
   output some traces in the ``.bzr.log`` file metionning the sections
   used. This allows the user to validate his definitions.
@@ -392,7 +392,7 @@
     * plugins can be written and registered to handle the associated
       ``password_encoding``.
 
-  * Could it be possible to encode the whole authentication file with a ssh key
+  * Could it be possible to encode the whole authentication file with an SSH key
     ?
 
     * yes and if the user configure a ssh-agent it will not be queried for

=== modified file 'doc/developers/bug-handling.txt'
--- doc/developers/bug-handling.txt	2010-12-02 09:46:15 +0000
+++ doc/developers/bug-handling.txt	2010-12-16 06:24:14 +0000
@@ -310,7 +310,7 @@
     needs changes to the test framework
 
 transport
-    virtual filesystem for http, sftp, etc
+    virtual filesystem for HTTP, SFTP, etc.
 
 trivial
     should be very easy to fix (10-20 minutes) and easily landed: typically 

=== modified file 'doc/developers/check.txt'
--- doc/developers/check.txt	2009-05-12 03:50:39 +0000
+++ doc/developers/check.txt	2010-11-12 22:43:38 +0000
@@ -35,7 +35,7 @@
 Things that can go wrong:
 * Tag or tip revision ids may be missing from the repo.
 * The revno tip cache may be wrong.
-* Various urls could be problematic (not inaccessible, just invalid)
+* Various URLS could be problematic (not inaccessible, just invalid)
 * Stacked-on branch could be inaccessible.
 
 Tree

=== modified file 'doc/developers/code-style.txt'
--- doc/developers/code-style.txt	2010-09-28 07:20:09 +0000
+++ doc/developers/code-style.txt	2010-12-14 23:39:41 +0000
@@ -364,6 +364,8 @@
 
 Because repr methods are often called when something has already gone
 wrong, they should be written somewhat more defensively than most code.
+They shouldn't have side effects like doing network or disk
+IO.
 The object may be half-initialized or in some other way in an illegal
 state.  The repr method shouldn't raise an exception, or it may hide the
 (probably more useful) underlying exception.
@@ -385,6 +387,13 @@
 ``Exception`` (which excludes system errors in Python2.5 and later) would
 be better.
 
+The ``__str__`` method on exceptions should be small and have no side
+effects, following the rules given for `Object string representations`_.
+In particular it should not do any network IO, or complicated
+introspection of other objects.  All the state needed to present the
+exception to the user should be gathered before the error is raised.
+In other words, exceptions should basically be value objects.
+
 
 Test coverage
 =============

=== modified file 'doc/developers/directory-fingerprints.txt'
--- doc/developers/directory-fingerprints.txt	2009-12-02 20:34:07 +0000
+++ doc/developers/directory-fingerprints.txt	2010-11-12 22:08:18 +0000
@@ -258,7 +258,7 @@
      as stored, or change the sort order for the inventory, or synthesize
      per-directory inventories in memory for hashing.
 
-     However, xml is somewhat redundant and slow to parse/generate; and
+     However, XML is somewhat redundant and slow to parse/generate; and
      reading the whole thing before comparing some sections is only a
      partial win.  It may be a smaller change but we'd be preserving
      things we want to change.

=== modified file 'doc/developers/ec2.txt'
--- doc/developers/ec2.txt	2010-12-02 09:42:45 +0000
+++ doc/developers/ec2.txt	2010-12-16 06:24:14 +0000
@@ -74,7 +74,7 @@
 password from Amazon, and ``ec2-add-keypair`` creates a named keypair at
 Amazon and returns the private path. One keypair is all that is needed.
 This is distinct from the account identifier - likely due to the different
-toolchains in use (the keypairs are used for unix ssh keys, and I (Robert)
+toolchains in use (the keypairs are used for unix SSH keys, and I (Robert)
 suspect a rather unix friendly core at Amazon).
 Once a custom image is made with a saved password, you can skip using
 ``ec2-get-password`` (which is only needed for Windows anyway).

=== modified file 'doc/developers/initial-push-pull.txt'
--- doc/developers/initial-push-pull.txt	2007-06-05 08:02:04 +0000
+++ doc/developers/initial-push-pull.txt	2010-11-12 22:08:18 +0000
@@ -65,5 +65,5 @@
 Wants
 -----
 - Read partial graph
-- Read multiple segments of multiple files on http and sftp
+- Read multiple segments of multiple files on HTTP and SFTP
 - Write multiple files over SFTP

=== modified file 'doc/developers/inventory.txt'
--- doc/developers/inventory.txt	2009-12-02 20:34:07 +0000
+++ doc/developers/inventory.txt	2010-11-12 22:08:18 +0000
@@ -26,7 +26,7 @@
 =============
 
 There are several variants of serialised tree shape in use by bzr. To date
-these have been mostly xml based, though plugins have offered non-xml versions.
+these have been mostly XML-based, though plugins have offered non-XML versions.
 
 dirstate
 --------
@@ -35,10 +35,10 @@
 for the working tree and one for each parent tree, interleaved to allow
 efficient diff and status operations.
 
-xml
+XML
 ---
 
-All the xml serialized forms write to and read from a single byte string, whose
+All the XML serialized forms write to and read from a single byte string, whose
 hash is then the inventory validator for the commit object.
 
 
@@ -82,14 +82,14 @@
 Current situation
 -----------------
 
-The xml based implementation we use today layers the inventory as a bytestring
+The XML-based implementation we use today layers the inventory as a bytestring
 which is stored under a single key; the bytestring is then compressed as a
 delta against the bytestring of its left hand parent by the knit code.
 
 Gap analysis:
 
  1. Succeeds
- 2. Fails - generating a new xml representation needs full tree data.
+ 2. Fails - generating a new XML representation needs full tree data.
  3. Succeeds - the inventory layer accesses the bytestring, which is
     deterministic
  4. Fails - we have to reconstruct both inventories as trees and then delta

=== modified file 'doc/developers/network-protocol.txt'
--- doc/developers/network-protocol.txt	2009-12-02 20:34:07 +0000
+++ doc/developers/network-protocol.txt	2010-11-12 22:46:28 +0000
@@ -317,7 +317,7 @@
 
   (Discussion) We're discussing having the byte segments be not just a
   method for sending a stream across the network, but actually having them
-  be preserved in the rpc from end to end.  This may be useful when
+  be preserved in the RPC from end to end.  This may be useful when
   there's an iterator on one side feeding in to an iterator on the other,
   if it avoids doing chunking and byte-counting at two levels, and if
   those iterators are a natural place to get good granularity.  Also, for
@@ -369,8 +369,8 @@
   sent.
 
   This relies on the client being able to read back from the server while
-  it's writing.  This is technically difficult for http but feasible over
-  a socket or ssh.
+  it's writing.  This is technically difficult for HTTP but feasible over
+  a socket or SSH.
 
   We'd need a clean way to pass this back to the request method, even
   though it's presumably in the middle of doing its body iterator.
@@ -400,8 +400,8 @@
   happening out of order, or mixed requests happening at the same time.
 
   Wonder how our network performance would have turned out now if we'd
-  done full-duplex from the start, and ignored hpss over http.  We have
-  pretty good (readonly) http support just over dumb http, and that may be
+  done full-duplex from the start, and ignored hpss over HTTP.  We have
+  pretty good (read-only) HTTP support just over dumb HTTP, and that may be
   better for many users.
 
 
@@ -422,9 +422,9 @@
 that includes any repository that might need to be referenced, and the
 client needs to know about a root directory beyond which it cannot ascend.
 
-Servers run over ssh will typically want to be able to access any path the
+Servers run over SSH will typically want to be able to access any path the
 user can access.  Public servers on the other hand (which might be over
-http, ssh or tcp) will typically want to restrict access to only a
+HTTP, SSH or TCP) will typically want to restrict access to only a
 particular directory and its children, so will want to do a software
 virtual root at that level.  In other words they'll want to rewrite
 incoming paths to be under that level (and prevent escaping using ../

=== modified file 'doc/developers/packrepo.txt'
--- doc/developers/packrepo.txt	2010-08-13 19:08:57 +0000
+++ doc/developers/packrepo.txt	2010-11-12 22:08:18 +0000
@@ -250,7 +250,7 @@
 
 The ``pack-names`` file gives the list of all finished non-obsolete
 packs.  (This should always be the same as the list of files in the
-``packs/`` directory, but the file is needed for readonly http clients
+``packs/`` directory, but the file is needed for read-only HTTP clients
 that can't easily list directories, and it includes other information.)
 The constraint on the ``pack-names`` list is that every file mentioned
 must exist in the ``packs/`` directory.

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2010-12-02 15:48:12 +0000
+++ doc/developers/releasing.txt	2010-12-17 08:35:38 +0000
@@ -271,13 +271,14 @@
 #. Now we'll try expanding this tarball and running the test suite
    to check for packaging problems::
 
-     make check-dist-tarball
+     make check-dist-tarball | subunit2pyunit
 
-   You may encounter failures while running the test suite caused
-   by your locally installed plugins. Use your own judgment to
-   decide if you can release with these failures. When in doubt,
-   disable the faulty plugins one by one until you get no more
-   failures.
+   You may encounter failures while running the test suite caused by your
+   locally installed plugins. Use your own judgment to decide if you can
+   release with these failures. When in doubt, disable the faulty plugins
+   one by one until you get no more failures. Alternatively, you can use
+   ``BZR_DISABLE_PLUGINS`` or ``BZR_PLUGIN_PATH=-site`` to disable one or
+   all plugins.
 
    Remember that PQM has just tested everything too, this step is
    particularly testing that the pyrex extensions, which are updated
@@ -373,7 +374,7 @@
       feedback.
 
       Bazaar is now available for download from
-      https://launchpad.net/bzr/2.x/2.x/ as a source tarball; packages
+      https://launchpad.net/bzr/x.y/x.y.z/ as a source tarball; packages
       for various systems will be available soon.
 
       <<release notes from this release back to the last major release>>
@@ -391,6 +392,25 @@
    releases. If you do not have a Freshmeat account yet, ask one of the
    existing admins.
 
+   The purpose here is to point users to the latest stable release while still
+   publishing announcements for development releases.
+
+   There are several kinds of modifications that could be done there via the
+   ``Administration`` box in the lower right area of the page:
+
+   * Edit the project: This is where most of the URLs proposed in the
+     ``Links`` box are edited. This should rarely change except for the URLs
+     related to the latest stable release.
+
+   * New announcement: When doing a release (beta, candidates, final), put the
+     summary of the release (you can't embed URLs there, the moderation staff
+     remove them). Users can still access the releases notes via the ``Release
+     Notes`` URL in the ``Links`` box in the upper right area of the page.
+
+   * Set direct download: When releasing a new stable release, this should
+     point to the corresponding launchpad page:
+     <https://launchpad.net/bzr/x.y/x.y.z/>
+
 #. Update `<http://en.wikipedia.org/wiki/Bazaar_(software)>`_ -- this should
    be done for final releases but not for beta releases or Release Candidates.
 

=== modified file 'doc/developers/testing.txt'
--- doc/developers/testing.txt	2010-11-08 09:58:04 +0000
+++ doc/developers/testing.txt	2010-12-16 17:45:14 +0000
@@ -857,10 +857,10 @@
 
     class TestCheckout(TestCase):
 
-    variations = multiply_scenarios(
-        VaryByRepositoryFormat(), 
-        VaryByTreeFormat(),
-        )
+        scenarios = multiply_scenarios(
+            VaryByRepositoryFormat(), 
+            VaryByTreeFormat(),
+            )
 
 The `load_tests` declaration or definition should be near the top of the
 file so its effect can be seen.
@@ -977,6 +977,25 @@
 
     self.overrideAttr(osutils, '_cached_user_encoding', 'latin-1')
 
+Temporarily changing environment variables
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+If yout test needs to temporarily change some environment variable value
+(which generally means you want it restored at the end), you can use::
+
+    self.overrideEnv('BZR_ENV_VAR', 'new_value')
+
+If you want to remove a variable from the environment, you should use the
+special ``None`` value::
+
+    self.overrideEnv('PATH', None)
+
+If you add a new feature which depends on a new environment variable, make
+sure it behaves properly when this variable is not defined (if applicable) and
+if you need to enforce a specific default value, check the
+``TestCase._cleanEnvironment`` in ``bzrlib.tests.__init__.py`` which defines a
+proper set of values for all tests.
+
 Cleaning up
 ~~~~~~~~~~~
 

=== modified file 'doc/developers/tortoise-strategy.txt'
--- doc/developers/tortoise-strategy.txt	2010-11-12 14:28:36 +0000
+++ doc/developers/tortoise-strategy.txt	2010-12-16 06:24:14 +0000
@@ -306,7 +306,7 @@
 Reuse of TSVNCache?
 ~~~~~~~~~~~~~~~~~~~
 
-The RPC mechanism and the tasks performed by the RPC server (rpc, file system
+The RPC mechanism and the tasks performed by the RPC server (RPC, file system
 crawling and watching, device notifications, caching) are very similar to
 those already implemented for TSVN and analysis of that code shows that
 it is not particularly tied to any VCS model.  As a result, consideration

=== modified file 'doc/developers/transports.txt'
--- doc/developers/transports.txt	2010-07-16 12:40:07 +0000
+++ doc/developers/transports.txt	2010-11-12 22:08:18 +0000
@@ -88,8 +88,8 @@
 Transports that hide symlinks
 -----------------------------
 
-On local, sftp and bzr+ssh transports, we can directly see symlinks as
-symlinks.  Over http (and ftp?) they're expanded by the server and we
+On local, SFTP and bzr+ssh transports, we can directly see symlinks as
+symlinks.  Over HTTP (and FTP?) they're expanded by the server and we
 cannot detect them.  This can cause problems when bzr follows relative
 paths because typically we will join the paths, and we may do this
 inconsistently with how the server, which can see the symlinks, would do.

=== modified file 'doc/developers/win32_build_setup.txt'
--- doc/developers/win32_build_setup.txt	2010-01-25 10:18:24 +0000
+++ doc/developers/win32_build_setup.txt	2010-11-12 22:36:19 +0000
@@ -129,7 +129,7 @@
 
    If you do this, you'll probably also want to install a shortcut to
    ``pageant.exe`` in Start / Programs / Startup so that it always starts when
-   you log in (though you still have to manually add your ssh keys.)
+   you log in (though you still have to manually add your SSH keys.)
 
    Note that on the Amazon EC2 machine, I'm having problems with temp files
    being created without the permission for the current user to actually read

=== modified file 'doc/en/mini-tutorial/index.txt'
--- doc/en/mini-tutorial/index.txt	2010-08-17 06:45:33 +0000
+++ doc/en/mini-tutorial/index.txt	2010-11-12 22:36:19 +0000
@@ -140,7 +140,7 @@
     Initial import
 
 
-Publishing your branch with sftp
+Publishing your branch with SFTP
 ================================
 
 There are a couple of ways to publish your branch. If you already have
@@ -164,7 +164,7 @@
 
  $ bzr branch http://www.example.com/myproject
 
-**Note**: to use sftp, you may need to install ``paramiko`` and
+**Note**: to use SFTP, you may need to install ``paramiko`` and
 ``pyCrypto``. See http://wiki.bazaar.canonical.com/InstallationFaq for details.
 
 

=== modified file 'doc/en/release-notes/bzr-0.1.txt'
--- doc/en/release-notes/bzr-0.1.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.1.txt	2010-11-12 22:08:18 +0000
@@ -13,7 +13,7 @@
 Bug Fixes
 *********
 
-* Fix problem in pulling over http from machines that do not
+* Fix problem in pulling over HTTP from machines that do not
   allow directories to be listed.
 
 * Avoid harmless warning about invalid hash cache after
@@ -22,7 +22,7 @@
 Performance
 ***********
 
-* Avoid some unnecessary http operations in branch and pull.
+* Avoid some unnecessary HTTP operations in branch and pull.
 
 
 bzr 0.1
@@ -33,7 +33,7 @@
 Notes
 *****
 
-* 'bzr branch' over http initially gives a very high estimate
+* 'bzr branch' over HTTP initially gives a very high estimate
   of completion time but it should fall as the first few
   revisions are pulled in.  branch is still slow on
   high-latency connections.
@@ -169,7 +169,7 @@
 * Fix remote access to branches containing non-compressed history.
   (Robert Collins).
 
-* Better reliability of http server tests.  (John Arbash-Meinel)
+* Better reliability of HTTP server tests.  (John Arbash-Meinel)
 
 * Merge graph maximum distance calculation fix.  (Aaron Bentley)
 
@@ -232,14 +232,14 @@
 Internals
 *********
 
-* Refactor xml packing/unpacking.
+* Refactor XML packing/unpacking.
 
 Bug Fixes
 *********
 
 * Fixed 'bzr mv' by Ollie Rutherfurd.
 
-* Fixed strange error when trying to access a nonexistent http
+* Fixed strange error when trying to access a nonexistent HTTP
   branch.
 
 * Make sure that the hashcache gets written out if it can't be
@@ -453,7 +453,7 @@
 * New syntax ``bzr status [FILE...]`` contributed by Bartosz
   Oler.  File may be in a branch other than the working directory.
 
-* ``bzr log`` and ``bzr root`` can be given an http URL instead of
+* ``bzr log`` and ``bzr root`` can be given an HTTP URL instead of
   a filename.
 
 * Commands can now be defined by external programs or scripts

=== modified file 'doc/en/release-notes/bzr-0.11.txt'
--- doc/en/release-notes/bzr-0.11.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.11.txt	2010-11-12 22:43:38 +0000
@@ -35,7 +35,7 @@
 
 * Knit files now wait to create their contents until the first data is
   added. The old code used to create an empty .knit and a .kndx with just
-  the header. However, this caused a lot of extra round trips over sftp.
+  the header. However, this caused a lot of extra round trips over SFTP.
   This can change the time for ``bzr push`` to create a new remote branch
   from 160s down to 100s. This also affects ``bzr commit`` performance when
   adding new files, ``bzr commit`` on a new kernel-like tree drops from 50s
@@ -60,7 +60,7 @@
   modules will not actually be imported if they are not used.
   (John Arbash Meinel)
 
-* Support ``bzr://`` and ``bzr+ssh://`` urls to work with the new RPC-based
+* Support ``bzr://`` and ``bzr+ssh://`` URLS to work with the new RPC-based
   transport which will be used with the upcoming high-performance smart
   server. The new command ``bzr serve`` will invoke bzr in server mode,
   which processes these requests. (Andrew Bennetts, Robert Collins, Martin
@@ -145,7 +145,7 @@
   take a ``universal_newlines=True``, which helps when checking the output
   of the command. (John Arbash Meinel)
 
-* Refactor SFTP vendors to allow easier re-use when ssh is used.
+* Refactor SFTP vendors to allow easier re-use when SSH is used.
   (Andrew Bennetts)
 
 * ``Transport.list_dir()`` and ``Transport.iter_files_recursive()`` should always

=== modified file 'doc/en/release-notes/bzr-0.13.txt'
--- doc/en/release-notes/bzr-0.13.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.13.txt	2010-11-12 22:43:38 +0000
@@ -25,12 +25,11 @@
   tree from a branch.
   (Daniel Silverstone)
 
-* urllib uses shared keep-alive connections, so http
-  operations are substantially faster.
+* urllib uses shared keep-alive connections, so HTTP  operations are substantially faster.
   (Vincent Ladeuil, #53654)
 
 * ``bzr export`` allows an optional branch parameter, to export a bzr
-  tree from some other url. For example:
+  tree from some other URL. For example:
   ``bzr export bzr.tar.gz http://bazaar-vcs.org/bzr/bzr.dev``
   (Daniel Silverstone)
 
@@ -71,7 +70,7 @@
 * New method ``get_branch_reference`` on 'BzrDir' allows the detection of
   branch references - which the smart server component needs.
 
-* New ``ChrootTransportDecorator``, accessible via the ``chroot+`` url
+* New ``ChrootTransportDecorator``, accessible via the ``chroot+`` URL
   prefix.  It disallows any access to locations above a set URL.  (Andrew
   Bennetts)
 
@@ -89,15 +88,15 @@
 
 * Suppress the traceback on invalid URLs (Vincent Ladeuil, #70803).
 
-* Give nicer error message when an http server returns a 403
+* Give nicer error message when an HTTP server returns a 403
   error code. (Vincent Ladeuil, #57644).
 
-* When a multi-range http GET request fails, try a single
+* When a multi-range HTTP GET request fails, try a single
   range one. If it fails too, forget about ranges. Remember that until
   the death of the transport and propagates that to the clones.
   (Vincent Ladeuil, #62276, #62029).
 
-* Handles user/passwords supplied in url from command
+* Handles user/passwords supplied in URL from command
   line (for the urllib implementation). Don't request already
   known passwords (Vincent Ladeuil, #42383, #44647, #48527)
 
@@ -114,7 +113,7 @@
 * mv correctly handles paths that traverse symlinks.
   (Aaron Bentley, #66964)
 
-* Give nicer looking error messages when failing to connect over ssh.
+* Give nicer looking error messages when failing to connect over SSH.
   (John Arbash Meinel, #49172)
 
 * Pushing to a remote branch does not currently update the remote working

=== modified file 'doc/en/release-notes/bzr-0.14.txt'
--- doc/en/release-notes/bzr-0.14.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.14.txt	2010-11-12 22:08:18 +0000
@@ -37,7 +37,7 @@
 
 * New connection: ``bzr+http://`` which supports tunnelling the smart
   protocol over an HTTP connection. If writing is enabled on the bzr
-  server, then you can write over the http connection.
+  server, then you can write over the HTTP connection.
   (Andrew Bennetts, John Arbash Meinel)
 
 * Aliases now support quotation marks, so they can contain whitespace
@@ -141,7 +141,7 @@
   (Kent Gibson, Jan Hudec #57637)
 
 * pycurl and urllib can detect short reads at different places. Update
-  the test suite to test more cases. Also detect http error code 416
+  the test suite to test more cases. Also detect HTTP error code 416
   which was raised for that specific bug. Also enhance the urllib
   robustness by detecting invalid ranges (and pycurl's one by detecting
   short reads during the initial GET). (Vincent Ladeuil, #73948)

=== modified file 'doc/en/release-notes/bzr-0.15.txt'
--- doc/en/release-notes/bzr-0.15.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.15.txt	2010-11-12 22:08:18 +0000
@@ -37,11 +37,11 @@
 
 * HTTP redirections are now taken into account when a branch (or a
   bundle) is accessed for the first time. A message is issued at each
-  redirection to inform the user. In the past, http redirections were
+  redirection to inform the user. In the past, HTTP redirections were
   silently followed for each request which significantly degraded the
-  performances. The http redirections are not followed anymore by
+  performances. The HTTP redirections are not followed anymore by
   default, instead a RedirectRequested exception is raised. For bzrlib
-  users needing to follow http redirections anyway,
+  users needing to follow HTTP redirections anyway,
   ``bzrlib.transport.do_catching_redirections`` provide an easy transition
   path.  (vila)
 
@@ -95,7 +95,7 @@
   the directory. So that there was a chance it would break commit,
   etc. (John Arbash Meinel, #94037)
 
-* Correctly handles mutiple permanent http redirections.
+* Correctly handles mutiple permanent HTTP redirections.
   (vila, #88780)
 
 bzr 0.15rc2
@@ -350,7 +350,7 @@
   the ``--use-existing-dir`` flag.
   (John Arbash Meinel, #30576, #45504)
 
-* Fix http proxy authentication when user and an optional
+* Fix HTTP proxy authentication when user and an optional
   password appears in the ``*_proxy`` vars. (Vincent Ladeuil,
   #83954).
 

=== modified file 'doc/en/release-notes/bzr-0.16.txt'
--- doc/en/release-notes/bzr-0.16.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.16.txt	2010-11-12 22:43:38 +0000
@@ -170,9 +170,9 @@
   server handler, and not arbitrary ``.bzr/*/smart`` URLs.  (Andrew Bennetts)
 
 * digest authentication is now supported for proxies and HTTP by the urllib
-  based http implementation. Tested against Apache 2.0.55 and Squid
+  based HTTP implementation. Tested against Apache 2.0.55 and Squid
   2.6.5. Basic and digest authentication are handled coherently for HTTP
-  and proxy: if the user is provided in the url (bzr command line for HTTP,
+  and proxy: if the user is provided in the URL (bzr command line for HTTP,
   proxy environment variables for proxies), the password is prompted for
   (only once). If the password is provided, it is taken into account. Once
   the first authentication is successful, all further authentication
@@ -186,8 +186,8 @@
 * bzrlib API compatability with 0.8 has been dropped, cleaning up some
   code paths. (Robert Collins)
 
-* Change the format of chroot urls so that they can be safely manipulated
-  by generic url utilities without causing the resulting urls to have
+* Change the format of chroot URLS so that they can be safely manipulated
+  by generic URL utilities without causing the resulting URLs to have
   escaped the chroot. A side effect of this is that creating a chroot
   requires an explicit action using a ChrootServer.
   (Robert Collins, Andrew Bennetts)
@@ -220,11 +220,11 @@
   bzrlib/transport/remote.py contains just the Transport classes that used
   to be in bzrlib/transport/smart.py.  (Andrew Bennetts)
 
-* urllib http implementation avoid roundtrips associated with
+* urllib HTTP implementation avoid roundtrips associated with
   401 (and 407) errors once the authentication succeeds.
   (Vincent Ladeuil).
 
-* urlib http now supports querying the user for a proxy password if
+* urlib HTTP now supports querying the user for a proxy password if
   needed. Realm is shown in the prompt for both HTTP and proxy
   authentication when the user is required to type a password.
   (Vincent Ladeuil).
@@ -332,7 +332,7 @@
   security hole.
   (Vincent Ladeuil)
 
-* Handle http and proxy digest authentication.
+* Handle HTTP and proxy digest authentication.
   (Vincent Ladeuil, #94034).
 
 Testing
@@ -358,8 +358,8 @@
   lightweight checkout for the tree if the ``vfs_transport_factory`` is not
   a LocalURLServer. (Robert Collins, Andrew Bennetts)
 
-* Branch implementation tests have been audited to ensure that all urls
-  passed to Branch APIs use proper urls, except when local-disk paths
+* Branch implementation tests have been audited to ensure that all URLs
+  passed to Branch APIs use proper URLs, except when local-disk paths
   are intended. This is so that tests correctly access the test transport
   which is often not equivalent to local disk in Remote* tests. As part
   of this many tests were adjusted to remove dependencies on local disk
@@ -371,7 +371,7 @@
   Andrew Bennetts, Martin Pool, Jonathan Lange)
 
 * Refactored proxy and authentication handling to simplify the
-  implementation of new auth schemes for both http and proxy.
+  implementation of new auth schemes for both HTTP and proxy.
   (Vincent Ladeuil)
 
 

=== modified file 'doc/en/release-notes/bzr-0.18.txt'
--- doc/en/release-notes/bzr-0.18.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.18.txt	2010-11-12 22:43:38 +0000
@@ -45,7 +45,7 @@
 
 * Fix detection of directory entries in the inventory. (James Westby)
 
-* Fix handling of http code 400: Bad Request When issuing too many ranges.
+* Fix handling of HTTP code 400: Bad Request When issuing too many ranges.
   (Vincent Ladeuil, #115209)
 
 * Issue a CONNECT request when connecting to an https server
@@ -132,7 +132,7 @@
 * Long log format reports deltas on merge revisions.
   (John Arbash Meinel, Kent Gibson)
 
-* Make initial push over ftp more resilient. (John Arbash Meinel)
+* Make initial push over FTP more resilient. (John Arbash Meinel)
 
 * Print a summary of changes for update just like pull does.
   (Daniel Watkins, #113990)
@@ -228,7 +228,7 @@
   deprecated in favour of ``MutableTree.smart_add``. (Robert Collins,
   Martin Pool)
 
-* New method ``external_url`` on Transport for obtaining the url to
+* New method ``external_url`` on Transport for obtaining the URL to
   hand to external processes. (Robert Collins)
 
 * Teach windows installers to build pyrex/C extensions.

=== modified file 'doc/en/release-notes/bzr-0.6.txt'
--- doc/en/release-notes/bzr-0.6.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.6.txt	2010-11-12 22:43:38 +0000
@@ -52,7 +52,7 @@
   ``gpg_signing_command`` (defaults to gpg) and record a digital signature
   of your commit. (Robert Collins)
 
-* New sftp transport, based on Paramiko.  (Robey Pointer)
+* New SFTP transport, based on Paramiko.  (Robey Pointer)
 
 * 'bzr pull' now accepts '--clobber' which will discard local changes
   and make this branch identical to the source branch. (Robert Collins)
@@ -187,9 +187,9 @@
   are returned as NoSuchFile. Other exceptions will propagate as normal.
   This allows debuging of actual errors. (Robert Collins)
 
-* bzrlib.transport.Transport now accepts *ONLY* url escaped relative paths
+* bzrlib.transport.Transport now accepts *ONLY* URL-escaped relative paths
   to apis like 'put', 'get' and 'has'. This is to provide consistent
-  behaviour - it operates on url's only. (Robert Collins)
+  behaviour - it operates on URLs only. (Robert Collins)
 
 * Transports can register using ``register_lazy_transport``, and they
   will be loaded when first used.  (Martin Pool)

=== modified file 'doc/en/release-notes/bzr-0.7.txt'
--- doc/en/release-notes/bzr-0.7.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.7.txt	2010-11-12 22:36:19 +0000
@@ -34,7 +34,7 @@
   path are no longer loaded: only the first successfully loaded one is
   used. (Robert Collins)
 
-* Use systems' external ssh command to open connections if possible.
+* Use system's external SSH command to open connections if possible.
   This gives better integration with user settings such as ProxyCommand.
   (James Henstridge)
 
@@ -80,7 +80,7 @@
 * Accept 'bzr resolved' (an alias for 'bzr resolve'), as this is
   the same as Subversion.  (Martin Pool)
 
-* New ftp transport support (on ftplib), for ftp:// and aftp://
+* New FTP transport support (on ftplib), for ftp:// and aftp://
   URLs.  (Daniel Silverstone)
 
 * Commit editor temporary files now start with ``bzr_log.``, to allow
@@ -125,7 +125,7 @@
 
 * Error when run with -OO
 
-* Fix bug in reporting http errors that don't have an http error code.
+* Fix bug in reporting HTTP errors that don't have an HTTP error code.
   (Martin Pool)
 
 * Handle more cases of pipe errors in display commands
@@ -140,7 +140,7 @@
 
 * Fix for bzr pull failing sometimes under windows
 
-* Fix for sftp transport under windows when using interactive auth
+* Fix for SFTP transport under windows when using interactive auth
 
 * Show files which are both renamed and modified as such in 'bzr
   status' output.  (Daniel Silverstone, #4503)
@@ -208,8 +208,8 @@
   (Martin Pool) (NB: TestSkipped should only be raised for correctable
   reasons - see the wiki spec ImprovingBzrTestSuite).
 
-* Test sftp with relative, absolute-in-homedir and absolute-not-in-homedir
-  paths for the transport tests. Introduce blackbox remote sftp tests that
+* Test SFTP with relative, absolute-in-homedir and absolute-not-in-homedir
+  paths for the transport tests. Introduce blackbox remote SFTP tests that
   test the same permutations. (Robert Collins, Robey Pointer)
 
 * Transport implementation tests are now independent of the local file

=== modified file 'doc/en/release-notes/bzr-0.8.txt'
--- doc/en/release-notes/bzr-0.8.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.8.txt	2010-11-12 22:36:19 +0000
@@ -115,7 +115,7 @@
 Improvements
 ************
 
-* sftp paths can now be relative, or local, according to the lftp
+* SFTP paths can now be relative, or local, according to the lftp
   convention. Paths now take the form::
 
       sftp://user:pass@host:port/~/relative/path
@@ -123,11 +123,11 @@
       sftp://user:pass@host:port/absolute/path
 
 * The FTP transport now tries to reconnect after a temporary
-  failure. ftp put is made atomic. (Matthieu Moy)
+  failure. FTP put is made atomic. (Matthieu Moy)
 
 * The FTP transport now maintains a pool of connections, and
   reuses them to avoid multiple connections to the same host (like
-  sftp did). (Daniel Silverstone)
+  SFTP did). (Daniel Silverstone)
 
 * The ``bzr_man.py`` file has been removed. To create the man page now,
   use ``./generate_docs.py man``. The new program can also create other files.

=== modified file 'doc/en/release-notes/bzr-0.9.txt'
--- doc/en/release-notes/bzr-0.9.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.9.txt	2010-11-12 22:36:19 +0000
@@ -72,7 +72,7 @@
   grained analysis of performance.
   (Robert Collins, Martin Pool).
 
-* 'bzr commit' shows a progress bar. This is useful for commits over sftp
+* 'bzr commit' shows a progress bar. This is useful for commits over SFTP
   where commit can take an appreciable time. (Robert Collins)
 
 * 'bzr add' is now less verbose in telling you what ignore globs were
@@ -81,8 +81,8 @@
   ignored). 'bzr add -v' is unchanged and will report every ignored
   file. (Robert Collins).
 
-* ftp now has a test server if medusa is installed. As part of testing,
-  ftp support has been improved, including support for supplying a
+* FTP now has a test server if medusa is installed. As part of testing,
+  FTP support has been improved, including support for supplying a
   non-standard port. (John Arbash Meinel).
 
 * 'bzr log --line' shows the revision number, and uses only the
@@ -132,11 +132,11 @@
   And for both urllib and pycurl we support multi-range requests,
   which decreases the number of round-trips. Performance results for
   ``bzr branch http://bazaar-vcs.org/bzr/bzr.dev/`` indicate
-  http branching is now 2-3x faster, and ``bzr pull`` in an existing
+  HTTP branching is now 2-3x faster, and ``bzr pull`` in an existing
   branch is as much as 4x faster.
   (Michael Ellerman, Johan Rydberg, John Arbash Meinel, #46768)
 
-* Performance improvements for sftp. Branching and pulling are now up to
+* Performance improvements for SFTP. Branching and pulling are now up to
   2x faster. Utilize paramiko.readv() support for async requests if it
   is available (paramiko > 1.6) (John Arbash Meinel)
 
@@ -158,7 +158,7 @@
 
 * Handle broken pipe under win32 correctly. (John Arbash Meinel)
 
-* sftp tests now work correctly on win32 if you have a newer paramiko
+* SFTP tests now work correctly on win32 if you have a newer paramiko
   (John Arbash Meinel)
 
 * Cleanup win32 test suite, and general cleanup of places where
@@ -189,7 +189,7 @@
 
 * Handle openbsd returning None for sys.getfilesystemencoding() (#41183)
 
-* Support ftp APPE (append) to allow Knits to be used over ftp (#42592)
+* Support FTP APPE (append) to allow Knits to be used over FTP (#42592)
 
 * Removals are only committed if they match the filespec (or if there is
   no filespec).  (#46635, Aaron Bentley)
@@ -205,7 +205,7 @@
   working with long filenames on windows. (Also helps for unicode filenames
   not generating hidden files). (John Arbash Meinel, #43801)
 
-* Restore terminal mode on C-c while reading sftp password.  (#48923,
+* Restore terminal mode on C-c while reading SFTP password.  (#48923,
   Nicholas Allen, Martin Pool)
 
 * Timestamps are rounded to 1ms, and revision entries can be recreated

=== modified file 'doc/en/release-notes/bzr-0.90.txt'
--- doc/en/release-notes/bzr-0.90.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.90.txt	2010-11-12 22:36:19 +0000
@@ -45,7 +45,7 @@
   so that we can give it the Transport we already have.
   (John Arbash Meinel, Vincent Ladeuil, #111702)
 
-* Get rid of sftp connection cache (get rid of the FTP one too).
+* Get rid of SFTP connection cache (get rid of the FTP one too).
   (Vincent Ladeuil, #43731)
 
 * bzr branch {local|remote} remote don't try to create a working tree
@@ -299,7 +299,7 @@
   are done within directories in $TMPDIR.  (Martin Pool)
 
 * The SSH_AUTH_SOCK environment variable is now reset to avoid
-  interaction with any running ssh agents.  (Jelmer Vernooij, #125955)
+  interaction with any running SSH agents.  (Jelmer Vernooij, #125955)
 
 * run_bzr_subprocess handles parameters the same way as run_bzr:
   either a string or a list of strings should be passed as the first

=== modified file 'doc/en/release-notes/bzr-0.91.txt'
--- doc/en/release-notes/bzr-0.91.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.91.txt	2010-11-12 22:43:38 +0000
@@ -151,7 +151,7 @@
 * bzr send uses default values for ranges when only half of an elipsis
   is specified ("-r..5" or "-r5..").  (#61685, Aaron Bentley)
 
-* Avoid trouble when Windows ssh calls itself 'plink' but no plink
+* Avoid trouble when Windows SSH calls itself 'plink' but no plink
   binary is present.  (Martin Albisetti, #107155)
 
 * ``bzr remove`` should remove clean subtrees.  Now it will remove (without
@@ -171,7 +171,7 @@
 * ``bzr --version`` takes care about encoding of stdout, especially
   when output is redirected. (Alexander Belchenko, #131100)
 
-* Prompt for an ftp password if none is provided.
+* Prompt for an FTP password if none is provided.
   (Vincent Ladeuil, #137044)
 
 * Reuse bound branch associated transport to avoid multiple
@@ -324,7 +324,7 @@
   This provides a hint to users of transports as to the reasonable
   minimum data to read. In principle this can take latency and
   bandwidth into account on a per-connection basis, but for now it
-  just has hard coded values based on the url. (e.g. http:// has a large
+  just has hard coded values based on the URL. (E.g., http:// has a large
   page size, file:// has a small one.) (Robert Collins)
 
 * New method on ``bzrlib.transport.Transport`` ``open_write_stream`` allows

=== modified file 'doc/en/release-notes/bzr-0.92.txt'
--- doc/en/release-notes/bzr-0.92.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-0.92.txt	2010-11-12 22:36:19 +0000
@@ -152,7 +152,7 @@
   longer throws away the profiling data if this command is run with
   ``--lsprof-file callgrind.out.ci`` say. (Ian Clatworthy)
 
-* Fallback to ftp when paramiko is not installed and sftp can't be used for
+* Fallback to FTP when paramiko is not installed and SFTP can't be used for
   ``tests/commands`` so that the test suite is still usable without
   paramiko.
   (Vincent Ladeuil, #59150)
@@ -162,7 +162,7 @@
 * Fix long standing bug in partial commit when there are renames
   left in tree. (Robert Collins, #140419)
 
-* Fix selftest semi-random noise during http related tests.
+* Fix selftest semi-random noise during HTTP related tests.
   (Vincent Ladeuil, #140614)
 
 * Fix typo in ftp.py making the reconnection fail on temporary errors.
@@ -175,7 +175,7 @@
 * Fix log against smart server branches that don't support tags.
   (James Westby, #140615)
 
-* Fix pycurl http implementation by defining error codes from
+* Fix pycurl HTTP implementation by defining error codes from
   pycurl instead of relying on an old curl definition.
   (Vincent Ladeuil, #147530)
 
@@ -289,7 +289,7 @@
   tuple containing the key information about a path for commit processing
   to complete. (Robert Collins)
 
-* New method on xml serialisers, write_inventory_to_lines, which matches the
+* New method on XML serialisers, write_inventory_to_lines, which matches the
   API used by knits for adding content. (Robert Collins)
 
 * New module ``bzrlib.bisect_multi`` with generic multiple-bisection-at-once

=== modified file 'doc/en/release-notes/bzr-1.0.txt'
--- doc/en/release-notes/bzr-1.0.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.0.txt	2010-11-12 22:43:38 +0000
@@ -43,7 +43,7 @@
 
 * Fix Makefile rules for doc generation. (Ian Clatworthy, #175207)
 
-* Give more feedback during long http downloads by making readv deliver data
+* Give more feedback during long HTTP downloads by making readv deliver data
   as it arrives for urllib, and issue more requests for pycurl. High latency
   networks are better handled by urllib, the pycurl implementation give more
   feedback but also incur more latency.
@@ -63,7 +63,7 @@
 Internals
 *********
 
-* readv urllib http implementation is now a real iterator above the
+* readv urllib HTTP implementation is now a real iterator above the
   underlying socket and deliver data as soon as it arrives. 'get' still
   wraps its output in a StringIO.
   (Vincent Ladeuil)
@@ -113,7 +113,7 @@
 Internals
 *********
 
-* New -Dhttp debug option reports http connections, requests and responses.
+* New -Dhttp debug option reports HTTP connections, requests and responses.
   (Vincent Ladeuil)
 
 * New -Dmerge debug option, which emits merge plans for merge-type=weave.
@@ -182,7 +182,7 @@
 Changes
 *******
 
-* Disable detection of plink.exe as possible ssh vendor. Plink vendor
+* Disable detection of plink.exe as possible SSH vendor. Plink vendor
   still available if user selects it explicitly with BZR_SSH environment
   variable. (Alexander Belchenko, workaround for bug #107593)
 
@@ -194,7 +194,7 @@
 ********
 
 * New ``authentication.conf`` file holding the password or other credentials
-  for remote servers. This can be used for ssh, sftp, smtp and other
+  for remote servers. This can be used for SSH, SFTP, SMTP and other
   supported transports.
   (Vincent Ladeuil)
 
@@ -274,7 +274,7 @@
 * ``commit`` is now able to invoke an external editor in a non-ascii
   directory. (Daniel Watkins, #84043)
 
-* Catch connection errors for ftp.
+* Catch connection errors for FTP.
   (Vincent Ladeuil, #164567)
 
 * ``check`` no longer reports spurious unreferenced text versions.
@@ -292,8 +292,8 @@
 * Do no use timeout in HttpServer anymore.
   (Vincent Ladeuil, #158972).
 
-* Don't catch the exceptions related to the http pipeline status before
-  retrying an http request or some programming errors may be masked.
+* Don't catch the exceptions related to the HTTP pipeline status before
+  retrying an HTTP request or some programming errors may be masked.
   (Vincent Ladeuil, #160012)
 
 * Fix ``bzr rm`` to not delete modified and ignored files.
@@ -315,7 +315,7 @@
   on them.
   (Martin Pool, #164637)
 
-* Fix typo in limiting offsets coalescing for http, leading to
+* Fix typo in limiting offsets coalescing for HTTP, leading to
   whole files being downloaded instead of parts.
   (Vincent Ladeuil, #165061)
 
@@ -330,7 +330,7 @@
   suggestion for an acceptable name is given. (Daniel Watkins, #103023)
 
 * Leave port as None in transport objects if user doesn't
-  specify a port in urls.
+  specify a port in URLs.
   (vincent Ladeuil, #150860)
 
 * Make sure Repository.fetch(self) is properly a no-op for all
@@ -388,7 +388,7 @@
 * Upgrade util/configobj to version 4.4.0.
   (Vincent Ladeuil, #151208).
 
-* Wrap medusa ftp test server as an FTPServer feature.
+* Wrap medusa FTP test server as an FTPServer feature.
   (Vincent Ladeuil, #157752)
 
 API Breaks

=== modified file 'doc/en/release-notes/bzr-1.1.txt'
--- doc/en/release-notes/bzr-1.1.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.1.txt	2010-11-12 22:43:38 +0000
@@ -108,7 +108,7 @@
   pointed to different logical drives on Windows.
   (Alexander Belchenko, #90847)
 
-* HTTP test servers are now compatible with the http protocol version 1.1.
+* HTTP test servers are now compatible with the HTTP protocol version 1.1.
   (Vincent Ladeuil, #175524)
 
 * _KnitParentsProvider.get_parent_map now handles requests for ghosts
@@ -118,7 +118,7 @@
 * ``merge --weave --uncommitted`` now works.  (Aaron Bentley)
 
 * pycurl authentication handling was broken and incomplete. Fix handling of
-  user:pass embedded in the urls.
+  user:pass embedded in the URLs.
   (Vincent Ladeuil, #177643)
 
 * Files inside non-directories are now handled like other conflict types.
@@ -140,7 +140,7 @@
   removed use characters not supported in the terminal encoding.
   (Aaron Bentley)
 
-* When dumb http servers return whole files instead of the requested ranges,
+* When dumb HTTP servers return whole files instead of the requested ranges,
   read the remaining bytes by chunks to avoid overflowing network buffers.
   (Vincent Ladeuil, #175886)
 
@@ -214,8 +214,7 @@
 * New helper method ``bzrlib.tests.split_suite_by_re`` which splits a test
   suite into two according to a regular expression. (Robert Collins)
 
-* Parametrize all http tests for the transport implementations, the http
-  protocol versions (1.0 and 1.1) and the authentication schemes.
+* Parametrize all HTTP tests for the transport implementations, the HTTP protocol versions (1.0 and 1.1) and the authentication schemes.
   (Vincent Ladeuil)
 
 * The ``exclude_pattern`` and ``random_order`` parameters to the function

=== modified file 'doc/en/release-notes/bzr-1.11.txt'
--- doc/en/release-notes/bzr-1.11.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.11.txt	2010-11-12 22:08:18 +0000
@@ -257,7 +257,7 @@
   and additionally call ``builder.record_delete`` when a delete
   against the basis occurs. (Robert Collins)
 
-* The default http handler has been changed from pycurl to urllib.
+* The default HTTP handler has been changed from pycurl to urllib.
   The default is still pycurl for https connections. (The only
   advantage of pycurl is that it checks ssl certificates.)
   (John Arbash Meinel)

=== modified file 'doc/en/release-notes/bzr-1.12.txt'
--- doc/en/release-notes/bzr-1.12.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.12.txt	2010-11-12 22:36:19 +0000
@@ -94,11 +94,11 @@
   before the optional ``[merge]`` indicator. For line format,
   the tags appear after the date. (Ian Clatworthy)
 
-* Progress bars now show the rate of activity for some sftp 
+* Progress bars now show the rate of activity for some SFTP 
   operations, and they are drawn different.  (Martin Pool, #172741)
 
 * Progress bars now show the rate of activity for urllib and pycurl based
-  http client implementations. The operations are tracked at the socket
+  HTTP client implementations. The operations are tracked at the socket
   level for better precision.
   (Vincent Ladeuil)
 

=== modified file 'doc/en/release-notes/bzr-1.13.txt'
--- doc/en/release-notes/bzr-1.13.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.13.txt	2010-11-12 22:36:19 +0000
@@ -220,7 +220,7 @@
 * Symlinks to non ascii file names are now supported.
   (Robert Collins, Vincent Ladeuil, #339055, #272444)    
 
-* Under rare circumstances (aka nobody reported a bug about it), the ftp
+* Under rare circumstances (aka nobody reported a bug about it), the FTP
   transport could revert to ascii mode. It now stays in binary mode except
   when needed.  (Vincent Ladeuil)
 

=== modified file 'doc/en/release-notes/bzr-1.15.txt'
--- doc/en/release-notes/bzr-1.15.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.15.txt	2010-11-12 22:36:19 +0000
@@ -105,7 +105,7 @@
   bzr+ssh:// clients (which have bug #354036).  Instead, the server now
   causes those clients to send the missing records.  (Andrew Bennetts)
 
-* Correctly handle http servers proposing multiple authentication schemes.
+* Correctly handle HTTP servers proposing multiple authentication schemes.
   (Vincent Ladeuil, #366107)
 
 * End-Of-Line content filters are now loaded correctly.
@@ -120,7 +120,7 @@
 * Non-recursive ``bzr ls`` now works properly when a path is specified.
   (Jelmer Vernooij, #357863)
 
-* ssh usernames (defined in ~/.ssh/config) are honoured for bzr+ssh connections.
+* SSH usernames (defined in ~/.ssh/config) are honoured for bzr+ssh connections.
   (Vincent Ladeuil, #367726)
 
 * Several bugs related to unicode symlinks have been fixed and the test suite

=== modified file 'doc/en/release-notes/bzr-1.16.txt'
--- doc/en/release-notes/bzr-1.16.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.16.txt	2010-11-12 22:36:19 +0000
@@ -189,7 +189,7 @@
   numerous bad bugs with line-ending support. (Ian Clatworthy, #362030)
 
 * Fix problem of "directory not empty" when contending for a lock over
-  sftp.  (Martin Pool, #340352)
+  SFTP.  (Martin Pool, #340352)
 
 * Fix rule handling so that eol is optional, not mandatory.
   (Ian Clatworthy, #379370)

=== modified file 'doc/en/release-notes/bzr-1.17.txt'
--- doc/en/release-notes/bzr-1.17.txt	2010-10-15 10:12:12 +0000
+++ doc/en/release-notes/bzr-1.17.txt	2010-11-12 22:08:18 +0000
@@ -119,7 +119,7 @@
   transforms.
   (Craig Hewetson, Martin Pool, #218206)
 
-* Force socket shutdown in threaded http test servers to avoid client hangs
+* Force socket shutdown in threaded HTTP test servers to avoid client hangs
   (pycurl).  (Vincent Ladeuil, #383920).
 
 * ``LRUCache`` will maintain the linked list pointers even if a nodes

=== modified file 'doc/en/release-notes/bzr-1.18.txt'
--- doc/en/release-notes/bzr-1.18.txt	2010-12-02 10:43:55 +0000
+++ doc/en/release-notes/bzr-1.18.txt	2010-12-16 06:24:14 +0000
@@ -205,7 +205,7 @@
   displayed test name is always the one that's actually running.
   (Martin Pool, #123688)
 
-* Authenticating against an ssh server now uses ``auth_none`` to determine
+* Authenticating against an SSH server now uses ``auth_none`` to determine
   if password authentication is even supported. This fixes a bug where
   users would be prompted for a launchpad password, even though launchpad
   only supports publickey authentication. (John Arbash Meinel, #375867)

=== modified file 'doc/en/release-notes/bzr-1.2.txt'
--- doc/en/release-notes/bzr-1.2.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.2.txt	2010-11-12 22:46:28 +0000
@@ -66,7 +66,7 @@
   client, and sends less data to the server to request the revisions.
   (Andrew Bennetts, Robert Collins, #178353)
 
-* The launchpad plugin now handles lp urls of the form
+* The launchpad plugin now handles lp URLs of the form
   ``lp://staging/``, ``lp://demo/``, ``lp://dev/`` to use the appropriate
   launchpad instance to do the resolution of the branch identities.
   This is primarily of use to Launchpad developers, but can also
@@ -87,7 +87,7 @@
 * The ``--coverage`` option is now global, rather specific to ``bzr
   selftest``.  (Andrew Bennetts)
 
-* The ``register-branch`` command will now use the public url of the branch
+* The ``register-branch`` command will now use the public URL of the branch
   containing the current directory, if one has been set and no explicit
   branch is provided.  (Robert Collins)
 
@@ -143,7 +143,7 @@
   more characters which should be considered valid.
   (John Arbash Meinel, #185458)
 
-* The launchpad plugin now uses the ``edge`` xmlrpc server to avoid
+* The launchpad plugin now uses the ``edge`` XML-RPC server to avoid
   interacting badly with a bug on the launchpad side. (Robert Collins)
 
 * Unknown hostnames when connecting to a ``bzr://`` URL no longer cause

=== modified file 'doc/en/release-notes/bzr-1.3.txt'
--- doc/en/release-notes/bzr-1.3.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.3.txt	2010-11-12 22:08:18 +0000
@@ -23,7 +23,7 @@
 
 * Fix a bug causing a ValueError crash in ``parse_line_delta_iter`` when
   fetching revisions from a knit to pack repository or vice versa using
-  bzr:// (including over http or ssh).
+  bzr:// (including over HTTP or SSH).
   (#208418, Andrew Bennetts, Martin Pool, Robert Collins)
 
 

=== modified file 'doc/en/release-notes/bzr-1.4.txt'
--- doc/en/release-notes/bzr-1.4.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.4.txt	2010-11-12 22:08:18 +0000
@@ -170,7 +170,7 @@
 
 * Fix a bug causing a ValueError crash in ``parse_line_delta_iter`` when
   fetching revisions from a knit to pack repository or vice versa using
-  bzr:// (including over http or ssh).
+  bzr:// (including over HTTP or SSH).
   (#208418, Andrew Bennetts, Martin Pool, Robert Collins)
 
 * Fixed ``_get_line`` in ``bzrlib.smart.medium``, which was buggy.  Also

=== modified file 'doc/en/release-notes/bzr-1.5.txt'
--- doc/en/release-notes/bzr-1.5.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.5.txt	2010-11-12 22:36:19 +0000
@@ -119,7 +119,7 @@
 * When logging the changes to a particular file, there was a bug if there
   were ghosts in the revision ancestry. (John Arbash Meinel, #209948)
 
-* xs4all's ftp server returns a temporary error when trying to list an
+* xs4all's FTP server returns a temporary error when trying to list an
   empty directory, rather than returning an empty list. Adding a
   workaround so that we don't get spurious failures.
   (John Arbash Meinel, #215522)
@@ -136,7 +136,7 @@
 
 * Improved the documentation on hooks. (Ian Clatworthy)
 
-* Update authentication docs regarding ssh agents.
+* Update authentication docs regarding SSH agents.
   (Vincent Ladeuil, #183705)
 
 Testing

=== modified file 'doc/en/release-notes/bzr-1.6.txt'
--- doc/en/release-notes/bzr-1.6.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.6.txt	2010-11-12 22:43:38 +0000
@@ -64,7 +64,7 @@
   but to support those repositories, we know always request full texts
   for Revision texts. (John Arbash Meinel, #261339)
 
-* The previous ``--1.6-rich-root`` format used an incorrect xml
+* The previous ``--1.6-rich-root`` format used an incorrect XML
   serializer, which would accidentally support fetching from a
   repository that supported subtrees, even though the local one would
   not. We deprecated that format, and introduced a new one that uses
@@ -179,7 +179,7 @@
 * ``Inventory.copy()`` was failing to set the revision property for
   the root entry. (Jelmer Vernooij)
 
-* sftp transport: added missing ``FileExists`` case to
+* SFTP transport: added missing ``FileExists`` case to
   ``_translate_io_exception`` (Christophe Troestler, #123475)
 
 * The help for ``bzr ignored`` now suggests ``bzr ls --ignored`` for
@@ -416,7 +416,7 @@
 * Fetch from a stacked branch copies all required data.
   (Aaron Bentley, #248506)
 
-* Handle urls such as ftp://user@host.com@www.host.com where the user
+* Handle URLs such as ftp://user@host.com@www.host.com where the user
   name contains an @.
   (Neil Martinsen-Burrell, #228058)
 
@@ -693,14 +693,14 @@
   get_parent_map requirements exposed a latent bug here.  (Aaron Bentley)
 
 * Issue a warning and ignore passwords declared in authentication.conf when
-  used for an ssh scheme (sftp or bzr+ssh).
+  used for an SSH scheme (sftp:// or bzr+ssh://).
   (Vincent Ladeuil, #203186)
 
-* Make both http implementations raise appropriate exceptions on 403
+* Make both HTTP implementations raise appropriate exceptions on 403
   Forbidden when POSTing smart requests.
   (Vincent Ladeuil, #230223)
 
-* Properly *title* header names in http requests instead of capitalizing
+* Properly *title* header names in HTTP requests instead of capitalizing
   them.
   (Vincent Ladeuil, #229076)
 

=== modified file 'doc/en/release-notes/bzr-1.7.txt'
--- doc/en/release-notes/bzr-1.7.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.7.txt	2010-11-12 22:46:28 +0000
@@ -57,7 +57,7 @@
 :Released: 2008-09-17
 
 A few bug fixes from 1.7rc1. The biggest change is a new
-``RemoteBranch.get_stacked_on_url`` rpc. This allows clients that are
+``RemoteBranch.get_stacked_on_url`` RPC. This allows clients that are
 trying to access a Stacked branch over the smart protocol, to properly
 connect to the stacked-on location.
 
@@ -116,7 +116,7 @@
 Improvements
 ************
 
-* A url like ``log+file:///tmp`` will log all access to that Transport
+* A URL like ``log+file:///tmp`` will log all access to that Transport
   to ``.bzr.log``, which may help in debugging or profiling.
   (Martin Pool)
 

=== modified file 'doc/en/release-notes/bzr-1.8.txt'
--- doc/en/release-notes/bzr-1.8.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.8.txt	2010-11-12 22:08:18 +0000
@@ -14,7 +14,7 @@
 display of revision logs, and merges.  The bzr testsuite now passes on OS
 X and Python 2.6, and almost completely passes on Windows.  The
 smartserver code has gained several bug fixes and performance
-improvements, and can now run server-side hooks within an http server.
+improvements, and can now run server-side hooks within an HTTP server.
 
 Bug Fixes
 *********

=== modified file 'doc/en/release-notes/bzr-1.9.txt'
--- doc/en/release-notes/bzr-1.9.txt	2010-10-08 08:15:14 +0000
+++ doc/en/release-notes/bzr-1.9.txt	2010-11-12 22:36:19 +0000
@@ -68,10 +68,10 @@
   RPC when querying the remote branch's revision graph.
   (Andrew Bennetts)
 
-* default username for bzr+ssh and sftp can be configured in
+* default username for bzr+ssh:// and sftp:// can be configured in
   authentication.conf. (Aaron Bentley)
 
-* launchpad-login now provides a default username for bzr+ssh and sftp
+* launchpad-login now provides a default username for bzr+ssh and SFTP
   URLs, allowing username-free URLs to work for everyone. (Aaron Bentley)
 
 * ``lp:`` lookups no longer include usernames, making them shareable and

=== modified file 'doc/en/release-notes/bzr-2.0.txt'
--- doc/en/release-notes/bzr-2.0.txt	2010-12-02 10:43:55 +0000
+++ doc/en/release-notes/bzr-2.0.txt	2010-12-16 20:41:47 +0000
@@ -25,6 +25,9 @@
 Bug Fixes
 *********
 
+* Avoid UnicodeDecodeError in ``bzr add`` with multiple files under a non-ascii
+  path on windows from symlink support addition. (Martin [gz], #686611)
+
 Improvements
 ************
 

=== modified file 'doc/en/release-notes/bzr-2.1.txt'
--- doc/en/release-notes/bzr-2.1.txt	2010-12-02 10:41:05 +0000
+++ doc/en/release-notes/bzr-2.1.txt	2010-12-16 20:41:47 +0000
@@ -25,6 +25,9 @@
 Bug Fixes
 *********
 
+* Avoid UnicodeDecodeError in ``bzr add`` with multiple files under a non-ascii
+  path on windows from symlink support addition. (Martin [gz], #686611)
+
 * Skip tests that needs a bzr source tree when there isn't one. This is
   needed to succesfully run the test suite for installed versions.
   (Vincent Ladeuil, #644855).
@@ -32,7 +35,7 @@
 * Skip the tests that requires respecting the chmod bits when running as root.
   (Vincent Ladeuil, #646133)
 
-* Using bzr with `lp:` urls behind an http proxy should work.
+* Using bzr with `lp:` URLs behind an HTTP proxy should work.
   (Robert Collins, #558343)
 
 Improvements
@@ -212,7 +215,7 @@
 
 * Fix plugin packaging on Windows. (Ian Clatworthy, #524162)
 
-* Fix stub sftp test server to call os.getcwdu().
+* Fix stub SFTP test server to call os.getcwdu().
   (Vincent Ladeuil, #526221, #526353)
 
 * Fixed CHM generation by moving the NEWS section template into
@@ -278,7 +281,7 @@
 Bug Fixes
 *********
 
-* Don't require testtools to use sftp.
+* Don't require testtools to use SFTP.
   (Vincent Ladeuil, #516183)
 
 * Fix "AttributeError in Inter1and2Helper" during fetch.
@@ -702,7 +705,7 @@
   (Joke de Buhr, Vincent Ladeuil, #353370, #62539)
   (John Arbash Meinel, Vincent Ladeuil, #492561)
 
-* Terminate ssh subprocesses when no references to them remain, fixing
+* Terminate SSH subprocesses when no references to them remain, fixing
   subprocess and file descriptor leaks.  (Andrew Bennetts, #426662)
   
 * The ``--hardlink`` option of ``bzr branch`` and ``bzr checkout`` now
@@ -784,7 +787,7 @@
   been changed to the equalivent ``Transport.get_bytes()``. The main
   difference is that the latter will explicitly call ``file.close()``,
   rather than expecting the garbage collector to handle it. This helps
-  with some race conditions on Windows during the test suite and sftp
+  with some race conditions on Windows during the test suite and SFTP
   tests. (John Arbash Meinel)
 
 Testing
@@ -925,7 +928,7 @@
 
 Key highlights in this release are: improved handling of
 failures-during-cleanup for commit, fixing a long-standing bug with
-``bzr+http`` and shared repositories, all ``lp:`` urls to be resolved
+``bzr+http`` and shared repositories, all ``lp:`` URLs to be resolved
 behind proxies, and a new StaticTuple datatype, allowing us to reduce
 memory consumption (50%) and garbage collector overhead (40% faster) for
 many operations.
@@ -948,7 +951,7 @@
   they do occur.  This fixes some causes of ``TooManyConcurrentRequests``
   and similar errors.  (Andrew Bennetts, #429747, #243391)
 
-* Launchpad urls can now be resolved from behind proxies.
+* Launchpad URLs can now be resolved from behind proxies.
   (Gordon Tyler, Vincent Ladeuil, #186920)
 
 * Reduce the strictness for StaticTuple, instead add a debug flag
@@ -1037,7 +1040,7 @@
 base with only bugfixes should focus on the 2.0.1 release. All bugfixes
 present in 2.0.1 are present in 2.1.0b1.
 
-Highlights include support for ``bzr+ssh://host/~/homedir`` style urls,
+Highlights include support for ``bzr+ssh://host/~/homedir`` style URLs,
 finer control over the plugin search path via extended BZR_PLUGIN_PATH
 syntax, visible warnings when extension modules fail to load, and improved
 error handling during unlocking.
@@ -1109,7 +1112,7 @@
 * Don't restrict the command name used to run the test suite.
   (Vincent Ladeuil, #419950)
 
-* ftp transports were built differently when the kerberos python module was
+* FTP transports were built differently when the kerberos python module was
   present leading to obscure failures related to ASCII/BINARY modes.
   (Vincent Ladeuil, #443041)
 
@@ -1226,7 +1229,7 @@
 * Tests that try to open a bzr dir on an arbitrary transport will now
   fail unless they have explicitly permitted the transport via
   ``self.permit_url``. The standard test factories such as ``self.get_url``
-  will permit the urls they provide automatically, so only exceptional
+  will permit the URLs they provide automatically, so only exceptional
   tests should need to do this. (Robert Collins)
 
 * The break-in test no longer cares about clean shutdown of the child,

=== modified file 'doc/en/release-notes/bzr-2.2.txt'
--- doc/en/release-notes/bzr-2.2.txt	2010-12-02 14:21:49 +0000
+++ doc/en/release-notes/bzr-2.2.txt	2010-12-24 17:47:53 +0000
@@ -25,6 +25,20 @@
 Bug Fixes
 *********
 
+* Avoid UnicodeDecodeError in ``bzr add`` with multiple files under a non-ascii
+  path on windows from symlink support addition. (Martin [gz], #686611)
+
+* Don't probe for a repository from within ``NotBranchError.__repr__``,
+  because this can cause knock-on errors at awkward times.
+  (Andrew Bennetts, #687653)
+
+* ``https`` access works again with recent versions of python2.7.
+  (Vincent Ladeuil, #693880)
+
+* RevisionTree.is_executable no longer returns None for directories and
+  symlinks.  Instead, it returns False, like other Trees and methods.
+  (Aaron Bentley, #681885)
+
 Improvements
 ************
 
@@ -62,7 +76,7 @@
   (e.g. from a merge) to the master branch (and informs the user if there
   is a conflict).  (Andrew Bennetts, #603395)
   
-* Correctly set the Content-Type header when http POSTing to comply
+* Correctly set the Content-Type header when HTTP POSTing to comply
   with stricter web frameworks. (Vincent Ladeuil, #665100)
 
 * ``NotBranchError`` no longer allows errors from calling
@@ -77,7 +91,7 @@
   root. Including the one that wasn't present in 2.1.
   (Vincent Ladeuil, #646133)
 
-* Using bzr with `lp:` urls behind an http proxy should work.
+* Using bzr with `lp:` URLs behind an HTTP proxy should work.
   (Robert Collins, #558343)
 
 * Windows installers no longer requires the Microsoft vcredist to be
@@ -618,8 +632,8 @@
   replaces the outdated ``contrib/bash/bzr`` script with a version
   using the plugin. (Martin von Gagern, #560030)
 
-* A new transport based on GIO (the gnome i/o library) provides access to
-  samba shares, webdav using gio+smb and gio+dav. It is also possible to
+* A new transport based on GIO (the Gnome I/O library) provides access to
+  Samba shares, WebDAV using gio+smb and gio+dav. It is also possible to
   use gio for some already existing transport methods as gio+file,
   gio+sftp, gio+ftp. 
   (Mattias Eriksson)
@@ -963,7 +977,7 @@
 
 Over thirty bugs have been fixed, including in the log command, exporting
 to tarballs, restarting interrupted system calls, portability of compiled
-extensions, making backups during upgrade, and locking on ftp.
+extensions, making backups during upgrade, and locking on FTP.
 
 Compatibility Breaks
 ********************
@@ -1098,7 +1112,7 @@
   (Jason Spashett, #183504)
 
 * Correctly interpret "451 Rename/move failure: Directory not empty" from
-  ftp servers while trying to take a lock.
+  FTP servers while trying to take a lock.
   (Martin Pool, #528722)
 
 * DirStateRevisionTree.kind() was returning wrong result when 'kind'

=== modified file 'doc/en/release-notes/bzr-2.3.txt'
--- doc/en/release-notes/bzr-2.3.txt	2010-12-03 22:09:12 +0000
+++ doc/en/release-notes/bzr-2.3.txt	2011-01-10 22:20:12 +0000
@@ -26,6 +26,29 @@
 .. Improvements to existing commands, especially improved performance 
    or memory usage, or better results.
 
+* A redundant parent inventories calculation was removed from
+  ``fetch.py``, as ``Repository.insert_stream`` already reports any
+  missing inventories.  This removes at least one network roundtrip when
+  pushing to a stacked branch.  (Andrew Bennetts)
+
+* ``ControlDir.sprout`` no longer opens the target repository more than
+  once.  This avoids some unnecessary IO, and removes a network roundtrip
+  when doing ``bzr branch`` to a smart server URL.  (Andrew Bennetts)
+
+* ``bzr resolve`` now accepts ``--take-this`` and ``--take-other`` actions
+  for text conflicts. This *replace* the whole file with the content
+  designated by the action. This will *ignore* all differences that would
+  have been merge cleanly otherwise. (Vincent Ladeuil, #638451)
+
+* ``bt.test_http`` was breaking ``os.environ`` by erasing the values saved by
+  ``TestCase`` leading to ``bt.test_import_tariff`` failures.
+  (Vincent Ladeuil, #690563)
+
+* ``upgrade`` now upgrades dependent branches when a shared repository is
+  specified. It also supports new options: ``--dry-run`` for showing what
+  will happen and ``--clean`` to remove the backup directory on successful
+  completion. (Ian Clatworthy, Matthew Fuller, #89830, #374734, #422450)
+
 Bug Fixes
 *********
 
@@ -41,12 +64,23 @@
 
 .. Improved or updated documentation.
 
+* Better document the rules to update the bzr freshmeat page when
+  doing a release. (Vincent Ladeuil, #690515)
+
 API Changes
 ***********
 
 .. Changes that may require updates in plugins or other code that uses
    bzrlib.
 
+* ``Branch.sprout``, ``BranchFormat.initalize`` and
+  ``ControlDir.create_branch`` now take an optional ``repository`` keyword
+  argument, and ``BranchFormat.open`` now takes an optional
+  ``found_repository`` keyword argument.  These provide the repository
+  object for new branch object to use (for cases when the caller has
+  already opened that repository).  Implementations of these APIs will
+  need to be updated to accept these arguments.  (Andrew Bennetts)
+
 Internals
 *********
 
@@ -60,6 +94,14 @@
    suite.  This can include new facilities for writing tests, fixes to 
    spurious test failures and changes to the way things should be tested.
 
+* Catch exceptions related to bug #637821 during test cleanup to avoid
+  spurious failures. (Vincent Ladeuil, #686008).
+
+* Check sphinx compatibility for tests requiring older sphinx versions.
+  (Vincent Ladeuil, #688072)
+
+* ``TestDebuntuExpansions`` was escaping the test isolation by calling the
+  wrong base class ``setUp``. (Vincent Ladeuil, #684622)
 
 bzr 2.3b4
 #########
@@ -159,6 +201,11 @@
   to 0.9.5 which will allow tests that need the fixed unicode handling to be
   written. (Martin [gz])
 
+* Introduce an ``overrideEnv()`` helper for tests that needs to change the
+  environment variables while respecting the isolation rules. Get rid of
+  TestCase._restoreEnvironment which is now useless.
+  (Vincent Ladeuil, #690563)
+
 * Printing selftest results to a non-UTF-8 console will now escape characters
   that can't be encoded rather than aborting the test run with an exception.
   (Martin [gz], #633216)
@@ -186,7 +233,7 @@
   once. It can also be used to set or delete a configuration option in any
   configuration file. (Vincent Ladeuil)
 
-* New shortcut url schemes ``ubuntu:`` and ``debianlp:`` access source
+* New shortcut URL schemes ``ubuntu:`` and ``debianlp:`` access source
   branches on Launchpad.  E.g. ``bzr branch ubuntu:foo`` gives you the source
   branch for project ``foo`` in the current distroseries for Ubuntu while
   ``bzr branch debianlp:lenny/foo`` gives you the source branch (on Launchpad)
@@ -214,14 +261,13 @@
   provided as parameters. When both are provided, ``--directory`` becomes
   the base directory for the other paths. (Vincent Ladeuil, #670851)
 
-* Correctly set the Content-Type  header when http POSTing to comply
+* Correctly set the Content-Type  header when HTTP POSTing to comply
   with stricter web frameworks. (Vincent Ladeuil, #665100)
 
 * Don't force openssh to use protocol=2, since that is now the default.
   (Neil Martinsen-Burrell, #561061)
 
-* Fix ``KeyError: 'port'`` when getting the stored password for an http
-  URL.
+* Fix ``KeyError: 'port'`` when getting the stored password for an HTTP  URL.
   (Martin Pool, #654684)
 
 * Make ``bzr tag --quiet`` really quiet. (Neil Martinsen-Burrell, #239523)
@@ -352,7 +398,7 @@
   (Marius Kruger, #400554)
 
 * When using the pycurl client module, Bazaar shows some of the text from
-  http server error messages.
+  HTTP server error messages.
   (Martin Pool, #656667)
 
 Bug Fixes
@@ -615,7 +661,7 @@
 * ``EPIPE`` can be raised during test server shutdown. This happened on
   gentoo only so far. (Vincent Ladeuil, #627277)
 
-* Errors occurring during http(s) test server starts should now be
+* Errors occurring during HTTP(S) test server starts should now be
   handled cleanly. (Vincent Ladeuil, #392402)
 
 * Fix ``AttributeError on parent.children`` when adding a file under a 

=== modified file 'doc/en/tutorials/tutorial.txt'
--- doc/en/tutorials/tutorial.txt	2010-08-13 19:08:57 +0000
+++ doc/en/tutorials/tutorial.txt	2010-11-12 22:36:19 +0000
@@ -50,10 +50,10 @@
 These revisions have other uses as well. For example, one can comment
 revisions to record what the recent set of changes meant by providing an
 optional log message. Real life log messages include things like "Fixed
-the web template to close the table" and "Added sftp suppport. Fixes #595"
+the web template to close the table" and "Added SFTP suppport. Fixes #595"
 	
 We keep these logs so that if later there is some sort of problem with
-sftp, we can figure out when the problem probably happened.
+SFTP, we can figure out when the problem probably happened.
 
 How DVCS is different
 =====================
@@ -209,7 +209,7 @@
 
 You'll usually refer to branches on your computer's filesystem just by
 giving the name of the directory containing the branch.  bzr also supports
-accessing branches over http and sftp, for example::
+accessing branches over HTTP and SFTP, for example::
 
     % bzr log http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev/
     % bzr log sftp://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev/

=== modified file 'doc/en/upgrade-guide/data_migration.txt'
--- doc/en/upgrade-guide/data_migration.txt	2009-10-02 18:12:29 +0000
+++ doc/en/upgrade-guide/data_migration.txt	2010-12-20 12:01:56 +0000
@@ -113,7 +113,7 @@
 
 In Launchpad, a project can define a *development series* and associate a
 branch with that series.  The branch then becomes the *focus of development*
-and gets special treatment and a shortcut url.  By default, if anybody
+and gets special treatment and a shortcut URL.  By default, if anybody
 branches your project's focus of development and pushes changes back to
 Launchpad, their branch will be stacked on your development focus branch.
 Also, branches can be associated with other Launchpad artifacts such as bugs
@@ -202,11 +202,15 @@
    name then **merge** your changes from the matching branch in the
    old repository.
 
-The first method will give you a branch which is identical (in terms
-of revision history) to the old branch, but it's parent branch will
-be set to the old branch, not your new trunk. If you use this method,
-you'll probably want to edit your branch.conf file to update the
-parent branch setting.
+The first method will give you a branch which is identical (in terms of
+revision history) to the old branch, but it's parent branch will be set to the
+old branch, not your new trunk. If you use this method, you'll probably update
+the ``parent_location`` configuration variable in the ``branch.conf`` file
+with::
+
+    bzr config parent_location=XXX
+
+``XXX`` being the URL to your new trunk.
 
 In contrast, the second approach sets up the parent branch correctly.
 However, it isn't ideal if you're not ready to include all the latest

=== modified file 'doc/en/upgrade-guide/index.txt'
--- doc/en/upgrade-guide/index.txt	2009-09-02 16:03:51 +0000
+++ doc/en/upgrade-guide/index.txt	2010-12-17 10:16:48 +0000
@@ -1,6 +1,6 @@
-########################
-Bazaar 2.0 Upgrade Guide
-########################
+####################
+Bazaar Upgrade Guide
+####################
 
 .. Please mark sections in included files as following:
 ..   level 1 ========

=== modified file 'doc/en/upgrade-guide/overview.txt'
--- doc/en/upgrade-guide/overview.txt	2010-08-13 19:08:57 +0000
+++ doc/en/upgrade-guide/overview.txt	2010-12-17 10:16:48 +0000
@@ -4,7 +4,7 @@
 High level upgrade process
 --------------------------
 
-In broad terms, there are 3 steps involved in upgrading to Bazaar 2.x:
+In broad terms, there are 3 steps involved in upgrading a new format:
 
 1. Upgrade the core software
 
@@ -12,34 +12,29 @@
 
 3. Migrate data to the new default format.
 
-Bazaar 2.x supports branches in earlier formats so the third step is
-strictly not required. However, the new default format in Bazaar 2.x
-is more space efficient, faster on large projects and provides a range
-of new features, so it is recommended that most projects migrate to it
-at a convenient time.
+Bazaar supports branches in earlier formats so the third step is strictly not
+required. However, when new default formats are introduced, they are more
+space efficient, faster on large projects and/or provide new features. So it
+is recommended that most projects migrate to it at a convenient time.
 
-For most users, upgrading to 2.x and migrating to the new format is
-straight forward. For projects with a large community of developers
-though, things become more complex. In these cases, careful planning
-and good communications become essential. This document provides
-general advice which aims to assist in this regard. If in doubt,
-please contact us on our mailing list or IRC channel with any
-questions or concerns you have.
+For most users, upgrading and migrating to the new format is straight
+forward. For projects with a large community of developers though, things
+become more complex. In these cases, careful planning and good communications
+become essential. This document provides general advice which aims to assist
+in this regard. If in doubt, please contact us on our mailing list or IRC
+channel with any questions or concerns you have.
 
 
 Upgrading the core software
 ---------------------------
 
-The steps required to upgrade the core software vary from operating
-system to operating system. There is nothing special about upgrading
-from Bazaar 1.x to Bazaar 2.0 compared to upgrading from Bazaar 1.x
-to Bazaar 1.y. In either case, a brief outline of the steps is given
-below.
+The steps required to upgrade the core software vary from operating system to
+operating system.  A brief outline of the steps is given below.
 
 To upgrade Bazaar on Ubuntu:
 
-1. Ensure your package manager is configured with the required
-   software sources, e.g. the official release PPA for Ubuntu:
+1. Ensure your package manager is configured with the required software
+   sources, e.g. the official stable release PPA for Ubuntu:
    https://launchpad.net/~bzr/+archive
 
 2. Use your package manager to upgrade to the latest version.

=== modified file 'doc/en/user-guide/branching_a_project.txt'
--- doc/en/user-guide/branching_a_project.txt	2010-10-08 10:50:51 +0000
+++ doc/en/user-guide/branching_a_project.txt	2010-11-12 22:36:19 +0000
@@ -43,7 +43,7 @@
 ``public_html`` within your home directory.
 
 .. note:: Access over HTTP or HTTPS is read-only by default.
-   See `Pushing over the http smart server
+   See `Pushing over the HTTP smart server
    <http_smart_server.html#pushing-over-the-http-smart-server>`_ for
    details on configuring read-write access.
 
@@ -75,7 +75,7 @@
 
 If a directory is not given, one is created based on the last part of
 the URL. Here are some examples showing a drive qualified path (M:/) and an
-sftp URL respectively::
+SFTP URL respectively::
 
   bzr branch M:/cool-trunk
   bzr branch sftp://bill@mary-laptop/cool-repo/cool-trunk

=== modified file 'doc/en/user-guide/configuring_bazaar.txt'
--- doc/en/user-guide/configuring_bazaar.txt	2010-10-13 13:59:44 +0000
+++ doc/en/user-guide/configuring_bazaar.txt	2010-11-12 22:08:18 +0000
@@ -19,7 +19,7 @@
 Using a network proxy
 ---------------------
 
-If your network requires that you use an http proxy for outbound
+If your network requires that you use an HTTP proxy for outbound
 connections, you must set the ``http_proxy`` variable.  If the proxy is
 also required for https connections, you need to set ``https_proxy`` too.
 If you need these and don't have them set, you may find that connections

=== modified file 'doc/en/user-guide/http_smart_server.txt'
--- doc/en/user-guide/http_smart_server.txt	2010-10-05 03:31:50 +0000
+++ doc/en/user-guide/http_smart_server.txt	2010-11-12 22:43:38 +0000
@@ -258,10 +258,10 @@
 .. _WSGI standard: http://www.python.org/dev/peps/pep-0333/
 
 
-Pushing over the http smart server
+Pushing over the HTTP smart server
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-It is possible to allow pushing data over the http smart server. The
+It is possible to allow pushing data over the HTTP smart server. The
 easiest way to do this, is to just supply ``readonly=False`` to the
 ``wsgi.make_app()`` call. But be careful, because the smart protocol does
 not contain any Authentication. So if you enable write support, you will
@@ -278,7 +278,7 @@
     </Location>
 
 At this time, it is not possible to allow some people to have read-only
-access and others to have read-write access to the same urls. Because at
+access and others to have read-write access to the same URLs. Because at
 the HTTP layer (which is doing the Authenticating), everything is just a
 POST request.  However, it would certainly be possible to have HTTPS
 require authentication and use a writable server, and plain HTTP allow

=== modified file 'doc/en/user-guide/organizing_your_workspace.txt'
--- doc/en/user-guide/organizing_your_workspace.txt	2009-09-09 15:30:59 +0000
+++ doc/en/user-guide/organizing_your_workspace.txt	2010-11-12 22:08:18 +0000
@@ -133,7 +133,7 @@
 As a variation, the trunk can be created as a checkout. If you have
 commit privileges on trunk, that lets you merge into trunk and the
 commit of the merge will implicitly publish your change. Alternatively,
-if the trunk URL is read-only (e.g. a http address), that prevents
+if the trunk URL is read-only (e.g. an HTTP address), that prevents
 accidental submission this way - ideal if the project workflow uses
 an automated gatekeeper like PQM, say.
 

=== modified file 'doc/en/user-guide/server.txt'
--- doc/en/user-guide/server.txt	2010-08-13 19:08:57 +0000
+++ doc/en/user-guide/server.txt	2010-11-12 22:46:28 +0000
@@ -64,7 +64,7 @@
 
 Running a Bazaar server from inetd requires an inetd.conf entry::
 
-    4155  stream  tcp  nowait  bzruser  /usr/bin/bzr /usr/bin/bzr serve --inet --directory=/srv/bzr/repo
+    4155  stream  TCP  nowait  bzruser  /usr/bin/bzr /usr/bin/bzr serve --inet --directory=/srv/bzr/repo
 
 When running client commands, the URL you supply is a `bzr://` URL relative to
 the ``--directory`` option given in inetd.conf::

=== modified file 'doc/en/user-guide/shared_repository_layouts.txt'
--- doc/en/user-guide/shared_repository_layouts.txt	2010-08-13 19:08:57 +0000
+++ doc/en/user-guide/shared_repository_layouts.txt	2010-11-12 22:08:18 +0000
@@ -237,7 +237,7 @@
 that could be changed.
 This is actually how `Launchpad`_ allows you to ``bzr checkout https://launchpad.net/bzr``.
 Effectively a ``BranchReference`` is a symlink, but it allows you to reference any other URL.
-If it is extended to support relative references, it would even work over http, sftp,
+If it is extended to support relative references, it would even work over HTTP, SFTP,
 and local paths.
 
 .. _Launchpad: https://launchpad.net

=== modified file 'doc/en/whats-new/whats-new-in-2.3.txt'
--- doc/en/whats-new/whats-new-in-2.3.txt	2010-12-02 15:48:12 +0000
+++ doc/en/whats-new/whats-new-in-2.3.txt	2010-12-20 12:01:56 +0000
@@ -45,6 +45,11 @@
   ~/.bazaar/plugins.  To use a different directory for plugins, use the
   environment variable BZR_PLUGIN_PATH.  (Neil Martinsen-Burrell, #195397)
 
+* ``bzr upgrade`` now operates recursively when run on a shared
+  repository, automatically upgrading the branches within it, and has
+  grown additional options for showing what it will do and cleaning up
+  after itself.  (Ian Clatworthy, Matthew Fuller, #89830, #374734, #422450)
+
 Launchpad integration
 *********************
 
@@ -69,6 +74,10 @@
 * ``bzr send`` uses less memory.
   (John Arbash Meinel, #614576)
 
+* Fetches involving stacked branches and branches with tags now do slightly less
+  I/O, and so does branching from an existing branch.  This also improves the
+  network performance of these operations.  (Andrew Bennetts)
+
 * Inventory entries now consume less memory (on 32-bit Ubuntu file entries
   have dropped from 68 bytes to 40, and directory entries from 120 bytes
   to 48).  This affects most operations, and depending on the size of the
@@ -131,6 +140,12 @@
   default behaviour is specified (if needed) by setting the variable to
   ``conflict``.  (Vincent Ladeuil, #323111)
 
+* ``bzr resolve --take-this`` and ``bzr resolve --take-other`` can now be
+  used for text conflicts. This will ignore the differences that were merged
+  cleanly and replace the file with its content in the current branch
+  (``--take-this``) or with its content in the merged branch
+  (``--take-other``). (Vincent Ladeuil, #638451)
+
 * ``bzr resolve`` now provides more feedback about the conflicts just
   resolved and the remaining ones. (Vincent Ladeuil)
 

=== modified file 'doc/es/mini-tutorial/index.txt'
--- doc/es/mini-tutorial/index.txt	2010-08-13 19:08:57 +0000
+++ doc/es/mini-tutorial/index.txt	2010-11-12 22:36:19 +0000
@@ -143,7 +143,7 @@
     Importación inicial
 
 
-Publicando su branch con sftp
+Publicando su branch con SFTP
 =============================
 
 Hay un par de maneras para publicar su branch. Si ya tiene un servidor
@@ -166,7 +166,7 @@
 
  $ bzr branch http://www.example.com/miproyecto
 
-**Nota:** para utilizar sftp deberá instalar ``paramiko`` y
+**Nota:** para utilizar SFTP deberá instalar ``paramiko`` y
 ``pyCrypto``. Vea http://wiki.bazaar.canonical.com/InstallationFaq para más información.
 
 

=== modified file 'doc/ru/tutorials/tutorial.txt'
--- doc/ru/tutorials/tutorial.txt	2010-08-13 19:08:57 +0000
+++ doc/ru/tutorials/tutorial.txt	2010-11-12 22:36:19 +0000
@@ -201,7 +201,7 @@
 большого количества веток для проекта среднего размера.
 
 Мы обычно обращаемся к веткам на нашем компьютере просто передав имя каталога
-содержащего ветку. bzr также поддерживает доступ к веткам через http и sftp,
+содержащего ветку. bzr также поддерживает доступ к веткам через HTTP и SFTP,
 например::
 
     % bzr log http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev/

=== modified file 'doc/ru/user-guide/branching_a_project.txt'
--- doc/ru/user-guide/branching_a_project.txt	2009-12-02 20:34:07 +0000
+++ doc/ru/user-guide/branching_a_project.txt	2010-11-12 22:36:19 +0000
@@ -59,7 +59,7 @@
 
 If a directory is not given, one is created based on the last part of
 the URL. Here are some examples showing a drive qualified path (M:/) and an
-sftp URL respectively::
+SFTP URL respectively::
 
   bzr branch M:/cool-trunk
   bzr branch sftp://bill@mary-laptop/cool-repo/cool-trunk

=== modified file 'tools/win32/bazaar.url'
--- tools/win32/bazaar.url	2006-06-29 08:41:31 +0000
+++ tools/win32/bazaar.url	2010-12-07 09:06:39 +0000
@@ -1,5 +1,5 @@
 [InternetShortcut]
-URL=http://bazaar-vcs.org/
+URL=http://bazaar.canonical.com
 Hotkey=0
 IconIndex=0
 IconFile=

=== modified file 'tools/win32/build_release.py'
--- tools/win32/build_release.py	2009-07-31 19:09:31 +0000
+++ tools/win32/build_release.py	2010-12-07 09:06:39 +0000
@@ -85,7 +85,6 @@
     bzr_dir = get_bzr_dir()
     if not os.path.isdir(bzr_dir):
         bzr_version = VERSIONS['bzr']
-        # bzr_url = 'http://bazaar-vcs.org/bzr/bzr.' + bzr_version
         bzr_url = 'lp:bzr/' + bzr_version
         print "Getting bzr release %s from %s" % (bzr_version, bzr_url)
         call_or_fail([bzr(), 'co', bzr_url, bzr_dir])

=== modified file 'tools/win32/buildout.cfg'
--- tools/win32/buildout.cfg	2009-08-20 09:30:34 +0000
+++ tools/win32/buildout.cfg	2010-12-07 09:06:39 +0000
@@ -50,7 +50,7 @@
 # on Launchpad
 # bzr-release-url = http://bazaar-vcs.org/bzr/bzr.${settings:bzr-release}
 bzr-release-url = lp:bzr/${settings:bzr-release}
-bzr-trunk-url = http://bazaar-vcs.org/bzr/bzr.dev
+bzr-trunk-url = lp:bzr
 
 bzrtools-release = 1.18.0
 bzrtools-release-tag = tag:release-${settings:bzrtools-release}

=== modified file 'tools/win32/bzr.iss.cog'
--- tools/win32/bzr.iss.cog	2009-08-05 18:56:37 +0000
+++ tools/win32/bzr.iss.cog	2010-12-07 09:06:39 +0000
@@ -71,9 +71,9 @@
 
 AppComments="Bazaar: Friendly distributed version control system"
 AppPublisher="Canonical Ltd."
-AppPublisherURL="http://www.bazaar-vcs.org"
-AppSupportURL="http://www.bazaar-vcs.org/BzrSupport"
-AppUpdatesURL="http://www.bazaar-vcs.org/WindowsDownloads"
+AppPublisherURL="http://bazaar.canonical.com"
+AppSupportURL="http://wiki.bazaar.canonical.com/BzrSupport"
+AppUpdatesURL="http://wiki.bazaar.canonical.com/WindowsDownloads"
 ; [[[cog cog.outl('AppVersion=%s' % VERSION) ]]]
 ; [[[end]]]
 
@@ -177,7 +177,7 @@
 
 [Icons]
 Name: "{group}\Documentation index"; Filename: "{app}\doc\index.html"; WorkingDir: "{app}\doc";
-Name: "{group}\Bazaar Home Page"; Filename: "{app}\bazaar.url"; Comment: "http://www.bazaar-vcs.org";
+Name: "{group}\Bazaar Home Page"; Filename: "{app}\bazaar.url"; Comment: "http://bazaar.canonical.com";
 Name: "{group}\Start Bzr in cmd shell"; Filename: "{cmd}"; Parameters: "/K start_bzr.bat"; WorkingDir: "{app}"; IconFilename: "{app}\bzr.exe"; Comment: "Open new Bzr session";
 ; NOTE: Intent is to change the log file location - the line below will need to change to reflect that.
 Name: "{group}\Open Bzr log file"; Filename: "notepad.exe"; Parameters: "{userdocs}\.bzr.log"; Comment: "Launch notepad to view the bzr log file";

